@@ -75,7 +75,6 @@ class CrispClust(QtWidgets.QDialog):
 
         self.setupui()
 
-        self.name = 'Crisp Clustering'
         self.cltype = 'k-means'
         self.min_cluster = 5
         self.max_cluster = 5
@@ -113,14 +112,14 @@ class CrispClust(QtWidgets.QDialog):
         label_6 = QtWidgets.QLabel()
 
         self.spinbox_minclusters.setMinimum(1)
-        self.spinbox_minclusters.setProperty("value", 5)
+        self.spinbox_minclusters.setProperty('value', 5)
         self.spinbox_maxclusters.setMinimum(1)
-        self.spinbox_maxclusters.setProperty("value", 5)
+        self.spinbox_maxclusters.setProperty('value', 5)
         self.spinbox_maxiterations.setMinimum(1)
         self.spinbox_maxiterations.setMaximum(1000)
-        self.spinbox_maxiterations.setProperty("value", 100)
+        self.spinbox_maxiterations.setProperty('value', 100)
         self.doublespinbox_maxerror.setDecimals(5)
-        self.doublespinbox_maxerror.setProperty("value", 1e-05)
+        self.doublespinbox_maxerror.setProperty('value', 1e-05)
         self.spinbox_repeatedruns.setMinimum(1)
 
         buttonbox.setOrientation(QtCore.Qt.Horizontal)
@@ -128,18 +127,20 @@ class CrispClust(QtWidgets.QDialog):
         self.radiobutton_random.setChecked(True)
         self.groupbox.hide()
 
-        self.setWindowTitle("Crisp Clustering")
-        label.setText("Cluster Algorithm:")
-        label_2.setText("Minimum Clusters:")
-        label_3.setText("Maximum Clusters")
-        label_4.setText("Maximum Iterations:")
-        label_5.setText("Terminate if relative change per iteration is less than:")
-        label_6.setText("Repeated Runs:")
-        self.label_7.setText("Constrain Cluster Shape (0: unconstrained, 1: spherical)")
-        self.groupbox.setTitle("Initial Guess")
-        self.radiobutton_random.setText("Random")
-        self.radiobutton_manual.setText("Manual")
-        self.radiobutton_datadriven.setText("Data Driven")
+        self.setWindowTitle('Crisp Clustering')
+        label.setText('Cluster Algorithm:')
+        label_2.setText('Minimum Clusters:')
+        label_3.setText('Maximum Clusters')
+        label_4.setText('Maximum Iterations:')
+        label_5.setText('Terminate if relative change per iteration '
+                        'is less than:')
+        label_6.setText('Repeated Runs:')
+        self.label_7.setText('Constrain Cluster Shape '
+                             '(0: unconstrained, 1: spherical)')
+        self.groupbox.setTitle('Initial Guess')
+        self.radiobutton_random.setText('Random')
+        self.radiobutton_manual.setText('Manual')
+        self.radiobutton_datadriven.setText('Data Driven')
 
         gridlayout.addWidget(label, 0, 2, 1, 1)
         gridlayout.addWidget(self.combobox_alg, 0, 4, 1, 1)
@@ -182,7 +183,7 @@ class CrispClust(QtWidgets.QDialog):
             self.label_7.hide()
             self.doublespinbox_constraincluster.hide()
 
-    def settings(self, test=False):
+    def settings(self, nodialog=False):
         """
         Entry point into item.
 
@@ -200,7 +201,7 @@ class CrispClust(QtWidgets.QDialog):
 
         self.update_vars()
 
-        if not test:
+        if not nodialog:
             temp = self.exec_()
             if temp == 0:
                 return
@@ -208,11 +209,63 @@ class CrispClust(QtWidgets.QDialog):
             self.parent.process_is_active()
         self.run()
 
-        if not test:
+        if not nodialog:
             self.parent.process_is_active(False)
             self.pbar.to_max()
         return True
 
+    def loadproj(self, projdata):
+        """
+        Loads project data into class.
+
+        Parameters
+        ----------
+        projdata : dictionary
+            Project data loaded from JSON project file.
+
+        Returns
+        -------
+        chk : bool
+            A check to see if settings was successfully run.
+
+        """
+
+        self.combobox_alg.setCurrentText(projdata['cltype'])
+        self.spinbox_minclusters.setProperty('value', projdata['min_cluster'])
+        self.spinbox_maxclusters.setProperty('value', projdata['max_cluster'])
+        self.spinbox_maxiterations.setProperty('value', projdata['max_iter'])
+        self.doublespinbox_maxerror.setProperty('value',
+                                                projdata['term_thresh'])
+        self.spinbox_repeatedruns.setProperty('value', projdata['runs'])
+        self.doublespinbox_constraincluster.setProperty('value',
+                                                        projdata['constrain'])
+
+        return False
+
+    def saveproj(self):
+        """
+        Save project data from class.
+
+
+        Returns
+        -------
+        projdata : dictionary
+            Project data to be saved to JSON project file.
+
+        """
+        self.update_vars()
+        projdata = {}
+
+        projdata['cltype'] = self.cltype
+        projdata['min_cluster'] = self.min_cluster
+        projdata['max_cluster'] = self.max_cluster
+        projdata['max_iter'] = self.max_iter
+        projdata['term_thresh'] = self.term_thresh
+        projdata['runs'] = self.runs
+        projdata['constrain'] = self.constrain
+
+        return projdata
+
     def update_vars(self):
         """
         Update the variables.
