@@ -264,7 +264,7 @@ class GraphMap(FigureCanvas):
         reference to the parent routine
     """
 
-    def __init__(self, parent):
+    def __init__(self, parent=None):
         self.figure = Figure()
 
         super().__init__(self.figure)
@@ -610,7 +610,7 @@ class ScatterPlot(QtWidgets.QDialog):
         dictionary of output datasets
     """
 
-    def __init__(self, parent):
+    def __init__(self, parent=None):
         super().__init__(parent)
         self.indata = {}
         self.outdata = {}
@@ -782,7 +782,7 @@ class ScatterPlot(QtWidgets.QDialog):
         self.map.update_graph()
         self.hist.polyi.update_plots()
 
-    def settings(self):
+    def settings(self, nodialog=False):
         """
         Run.
 
@@ -848,6 +848,42 @@ class ScatterPlot(QtWidgets.QDialog):
 
         return True
 
+    def loadproj(self, projdata):
+        """
+        Loads project data into class.
+
+        Parameters
+        ----------
+        projdata : dictionary
+            Project data loaded from JSON project file.
+
+        Returns
+        -------
+        chk : bool
+            A check to see if settings was successfully run.
+
+        """
+
+        return False
+
+    def saveproj(self):
+        """
+        Save project data from class.
+
+
+        Returns
+        -------
+        projdata : dictionary
+            Project data to be saved to JSON project file.
+
+        """
+        projdata = {}
+
+#        projdata['ftype'] = '2D Mean'
+
+        return projdata
+
+
     def update_map(self, polymask):
         """
         Update map.
