@@ -62,7 +62,7 @@ class GraphMap(FigureCanvas):
         reference to the parent routine
     """
 
-    def __init__(self, parent):
+    def __init__(self, parent=None):
         self.figure = Figure()
 
         super().__init__(self.figure)
@@ -418,7 +418,8 @@ class SuperClass(QtWidgets.QDialog):
     outdata : dictionary
         dictionary of output datasets
     """
-    def __init__(self, parent):
+
+    def __init__(self, parent=None):
         super().__init__(parent)
         self.indata = {}
         self.outdata = {}
@@ -779,8 +780,9 @@ class SuperClass(QtWidgets.QDialog):
             return False
 
         self.df.to_file(filename)
+        return True
 
-    def settings(self):
+    def settings(self, nodialog=False):
         """
         Settings.
 
@@ -816,13 +818,12 @@ class SuperClass(QtWidgets.QDialog):
 
         classifier, lbls, datall, _, _ = self.init_classifier()
 
-        rows, cols, bands = datall.shape
+        mask = self.map.data[0].data.mask
+        yout = np.zeros_like(datall[:, :, 0], dtype=int)
+        datall = datall[~mask]
 
-        datall.shape = (rows*cols, bands)
-        yout = classifier.predict(datall)
-        yout.shape = (rows, cols)
-
-        datall.shape = (rows, cols, bands)
+        yout1 = classifier.predict(datall)
+        yout[~mask] = yout1
 
         data = copy.copy(self.indata['Raster'])
         dat_out = [Data()]
@@ -850,8 +851,8 @@ class SuperClass(QtWidgets.QDialog):
         m = []
         s = []
         for i2 in lbls:
-            m.append(datall[yout == i2].mean(0))
-            s.append(datall[yout == i2].std(0))
+            m.append(datall[yout1 == i2].mean(0))
+            s.append(datall[yout1 == i2].std(0))
 
         dat_out[-1].metadata['Cluster']['center'] = np.array(m)
         dat_out[-1].metadata['Cluster']['center_std'] = np.array(s)
@@ -877,6 +878,51 @@ class SuperClass(QtWidgets.QDialog):
 
         return True
 
+    def loadproj(self, projdata):
+        """
+        Loads project data into class.
+
+        Parameters
+        ----------
+        projdata : dictionary
+            Project data loaded from JSON project file.
+
+        Returns
+        -------
+        chk : bool
+            A check to see if settings was successfully run.
+
+        """
+        self.combo_class.setCurrentText(projdata['combo_class'])
+        self.KNalgorithm.setCurrentText(projdata['KNalgorithm'])
+        self.DTcriterion.setCurrentText(projdata['DTcriterion'])
+        self.RFcriterion.setCurrentText(projdata['RFcriterion'])
+        self.SVCkernel.setCurrentText(projdata['SVCkernel'])
+#        self.df.read_json(projdata['classes'])
+
+        return False
+
+    def saveproj(self):
+        """
+        Save project data from class.
+
+        Returns
+        -------
+        projdata : dictionary
+            Project data to be saved to JSON project file.
+
+        """
+        projdata = {}
+
+        projdata['combo_class'] = self.combo_class.currentText()
+        projdata['KNalgorithm'] = self.KNalgorithm.currentText()
+        projdata['DTcriterion'] = self.DTcriterion.currentText()
+        projdata['RFcriterion'] = self.RFcriterion.currentText()
+        projdata['SVCkernel'] = self.SVCkernel.currentText()
+#        projdata['classes'] = self.df.to_json()
+
+        return projdata
+
     def init_classifier(self):
         """
         Initialise classifier.
@@ -1035,7 +1081,7 @@ def test():
     from pygmi.raster import iodefs
     app = QtWidgets.QApplication(sys.argv)
 
-    data = iodefs.get_raster(r'C:\WorkData\Change\cutdata.tif')
+    data = iodefs.get_raster(r'C:\work\WorkData\testdata.hdr')
 
     tmp = SuperClass(None)
     tmp.indata['Raster'] = data
