@@ -22,7 +22,7 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 # -----------------------------------------------------------------------------
-"""Time Domain EM. Currently just testing stuff"""
+"""Time Domain EM. Currently just testing stuff."""
 
 import sys
 import os
@@ -33,9 +33,10 @@ from matplotlib.backends.backend_qt5agg import FigureCanvas
 from matplotlib.figure import Figure
 from matplotlib.backends.backend_qt5agg import NavigationToolbar2QT
 from pymatsolver import Pardiso as Solver
-from SimPEG import (Mesh, Maps, Utils, DataMisfit, Regularization,
-                    Optimization, Inversion, InvProblem, Directives)
-import SimPEG.EM as EM
+import discretize
+from SimPEG import (maps, utils, data_misfit, regularization,
+                    optimization, inversion, inverse_problem, directives)
+import SimPEG.electromagnetics as EM
 
 sys.path.append(os.path.abspath(os.path.join(os.path.dirname(__file__),
                                              '..//..')))
@@ -44,9 +45,7 @@ from pygmi.vector.datatypes import LData
 
 
 class MyMplCanvas2(FigureCanvas):
-    """
-    MPL Canvas class.
-    """
+    """MPL Canvas class."""
 
     def __init__(self, parent=None):
         fig = Figure()
@@ -104,7 +103,7 @@ class MyMplCanvas2(FigureCanvas):
 class TDEM1D(QtWidgets.QDialog):
     """Occam 1D inversion."""
 
-    def __init__(self, parent):
+    def __init__(self, parent=None):
         super().__init__(parent)
         self.indata = {}
         self.outdata = {}
@@ -286,12 +285,12 @@ class TDEM1D(QtWidgets.QDialog):
 #        temp = np.logspace(np.log10(1.), np.log10(12.), 19)
 #        temp_pad = temp[-1] * 1.3 ** np.arange(npad)
 #        hz = np.r_[temp_pad[::-1], temp[::-1], temp, temp_pad]
-#        mesh = Mesh.CylMesh([hx, 1, hz], '00C')
+#        mesh = discretize.CylMesh([hx, 1, hz], '00C')
 #        active = mesh.vectorCCz < 0.
 
         npad = 20
         hz = [(cs, npad, -1.3), (cs, ncz*2), (cs, npad, 1.3)]
-        mesh = Mesh.CylMesh([hx, 1, hz], '00C')
+        mesh = discretize.CylMesh([hx, 1, hz], '00C')
 #        breakpoint()
 
         # Step2: Set a SurjectVertical1D mapping
@@ -299,9 +298,9 @@ class TDEM1D(QtWidgets.QDialog):
         # below subsurface
 
         active = mesh.vectorCCz < 0.
-        actmap = Maps.InjectActiveCells(mesh, active, np.log(1e-8),
+        actmap = maps.InjectActiveCells(mesh, active, np.log(1e-8),
                                         nC=mesh.nCz)
-        mapping = Maps.ExpMap(mesh) * Maps.SurjectVertical1D(mesh) * actmap
+        mapping = maps.ExpMap(mesh) * maps.SurjectVertical1D(mesh) * actmap
         sig_half = 1e-1
         sig_air = 1e-8
         sigma = np.ones(mesh.nCz)*sig_air
@@ -371,25 +370,25 @@ class TDEM1D(QtWidgets.QDialog):
 
         # Data Misfit
         survey.dobs = -dobs_sky
-        dmisfit = DataMisfit.l2_DataMisfit(survey)
+        dmisfit = data_misfit.l2_DataMisfit(survey)
         uncert = std*abs(dobs_sky) + floor
-        dmisfit.W = Utils.sdiag(1./uncert)
+        dmisfit.W = utils.sdiag(1./uncert)
 
         # Regularization
-        regmesh = Mesh.TensorMesh([mesh.hz[mapping.maps[-1].indActive]])
-        reg = Regularization.Simple(regmesh, mapping=Maps.IdentityMap(regmesh))
+        regmesh = discretize.TensorMesh([mesh.hz[mapping.maps[-1].indActive]])
+        reg = regularization.Simple(regmesh, mapping=maps.IdentityMap(regmesh))
 
         # Optimization
-        opt = Optimization.InexactGaussNewton(maxIter=5)
+        opt = optimization.InexactGaussNewton(maxIter=5)
 
         # statement of the inverse problem
-        invprob = InvProblem.BaseInvProblem(dmisfit, reg, opt)
+        invprob = inverse_problem.BaseInvProblem(dmisfit, reg, opt)
 
         # Directives and Inversion Parameters
-        target = Directives.TargetMisfit()
+        target = directives.TargetMisfit()
         # betaest = Directives.BetaEstimate_ByEig(beta0_ratio=1e0)
         invprob.beta = 20.
-        inv = Inversion.BaseInversion(invprob, directiveList=[target])
+        inv = inversion.BaseInversion(invprob, directiveList=[target])
         reg.alpha_s = 1e-1
         reg.alpha_x = 1.
         opt.LSshorten = 0.5
@@ -448,7 +447,6 @@ class TDEM1D(QtWidgets.QDialog):
         None.
 
         """
-
         self.combofid.clear()
 
         line = self.comboline.currentText()
@@ -456,17 +454,16 @@ class TDEM1D(QtWidgets.QDialog):
 
     def update_plot(self):
         """
-        Update the plot
+        Update the plot.
 
         Returns
         -------
         None.
 
         """
-
 #        self.mmc.update_line(x, pdata, rdata, depths, res, title)
 
-    def settings(self):
+    def settings(self, nodialog=False):
         """
         Entry point into item.
 
@@ -529,10 +526,44 @@ class TDEM1D(QtWidgets.QDialog):
 
         return True
 
+    def loadproj(self, projdata):
+        """
+        Load project data into class.
+
+        Parameters
+        ----------
+        projdata : dictionary
+            Project data loaded from JSON project file.
+
+        Returns
+        -------
+        chk : bool
+            A check to see if settings was successfully run.
+
+        """
+
+        return False
+
+    def saveproj(self):
+        """
+        Save project data from class.
+
+        Returns
+        -------
+        projdata : dictionary
+            Project data to be saved to JSON project file.
+
+        """
+        projdata = {}
+
+#        projdata['ftype'] = '2D Mean'
+
+        return projdata
+
 
 def tonumber(test, alttext=None):
     """
-    Checks if something is a number or matches alttext
+    Check if something is a number or matches alttext.
 
     Parameters
     ----------
@@ -560,7 +591,7 @@ def tonumber(test, alttext=None):
 
 
 def testrun():
-    """ Test routine """
+    """Test routine."""
     app = QtWidgets.QApplication(sys.argv)
 
     # Load in line data
