@@ -35,6 +35,7 @@ pygmi packages.
 
 """
 
+import json
 import pdb
 import sys
 import os
@@ -43,10 +44,16 @@ import math
 import importlib
 from PyQt5 import QtWidgets, QtCore, QtGui
 import numpy as np
+from matplotlib import rcParams
 import pygmi
 import pygmi.menu_default as menu_default
 import pygmi.misc as misc
 
+# rcParams['figure.dpi'] = 120
+# rcParams['font.size'] = 6.0
+rcParams['axes.formatter.limits'] = [-12, 12]
+rcParams['axes.formatter.useoffset'] = False
+
 QtCore.QLocale.setDefault(QtCore.QLocale.c())
 
 
@@ -270,7 +277,10 @@ class DiagramItem(QtWidgets.QGraphicsPolygonItem):
             odata = i.my_start_item.my_class.outdata
             for j in odata:
                 if j in data:
-                    data[j] = data[j] + odata[j]
+                    if isinstance(data[j], dict):
+                        data[j].update(odata[j])
+                    else:
+                        data[j] = data[j] + odata[j]
                 else:
                     data[j] = odata[j]
 
@@ -288,8 +298,7 @@ class DiagramItem(QtWidgets.QGraphicsPolygonItem):
         """
         self.scene().clearSelection()
         self.setSelected(True)
-
-        exclude = ['ProfPic', 'GenFPS', 'SceneList']
+        exclude = ['GenFPS', 'SceneList', 'RasterFileList']
 
         tmp = self.context_menu['Basic'].actions()
         if 'Raster' in self.my_class.indata:
@@ -299,8 +308,6 @@ class DiagramItem(QtWidgets.QGraphicsPolygonItem):
         for i in tmplist:
             if i not in exclude:
                 tmp += self.context_menu[i].actions()
-            if i == 'ProfPic' and 'Raster' not in tmplist:
-                tmp += self.context_menu['Raster'].actions()
         local_menu = QtWidgets.QMenu()
         local_menu.addActions(tmp)
         local_menu.exec_(event.screenPos())
@@ -347,19 +354,24 @@ class DiagramItem(QtWidgets.QGraphicsPolygonItem):
             arrow.my_end_item.remove_arrow(arrow)
             self.scene().removeItem(arrow)
 
-    def settings(self):
+    def settings(self, nodialog=False):
         """
         Routine Settings.
 
+        Parameters
+        ----------
+        nodialog : bool, optional
+            Run settings without a dialog. The default is False.
+
         Returns
         -------
         iflag : bool
             Returns a boolean reflecting success of the my_class.settings()
             method.
+
         """
-        if self.is_import is True:
-            pass
-        elif self.my_class.indata == {} and self.is_import is False:
+        # self.update_indata()
+        if self.my_class.indata == {} and self.is_import is False:
             QtWidgets.QMessageBox.warning(self.parent, 'Warning',
                                           ' You need to connect data first!',
                                           QtWidgets.QMessageBox.Ok)
@@ -367,17 +379,19 @@ class DiagramItem(QtWidgets.QGraphicsPolygonItem):
 
         self.my_class.parent.process_is_active()
         print(self.my_class_name+' busy...')
-        iflag = self.my_class.settings()
+        iflag = self.my_class.settings(nodialog)
         self.my_class.parent.process_is_active(False)
         if iflag:
             print(self.my_class_name+' finished!')
+        else:
+            print(self.my_class_name+' cancelled.')
         return iflag
 
 
 class DiagramScene(QtWidgets.QGraphicsScene):
     """Diagram Scene."""
 
-    def __init__(self, item_menu, parent):
+    def __init__(self, item_menu, parent=None):
         super().__init__(parent)
 
         self.my_item_menu = item_menu
@@ -412,21 +426,31 @@ class DiagramScene(QtWidgets.QGraphicsScene):
 
         self.selected_item_info()
 
-# now display the information about the selected data
+    # now display the information about the selected data
     def selected_item_info(self):
         """Display info about selected item."""
         tmp = self.selectedItems()
         if not tmp:
             return
 
+        if not hasattr(tmp[0], 'my_class'):
+            return
+
         text = ''
 
         if hasattr(tmp[0].my_class, 'indata'):
             idata = tmp[0].my_class.indata
 
             for i in idata:
-                text += '\nInput ' + i + ' dataset:\n'
+                text += '\nInput ' + i + ' dataset: '
                 if i in 'Raster':
+                    if hasattr(idata[i][0], 'filename'):
+                        file = idata[i][0].filename
+                    else:
+                        file = i
+                    if '.SAFE' in file:
+                        file = file.split('.SAFE')[0]+'.SAFE'
+                    text += os.path.basename(file) + '\n'
                     for j in idata[i]:
                         text += '  '+j.dataid + '\n'
 
@@ -434,14 +458,27 @@ class DiagramScene(QtWidgets.QGraphicsScene):
             odata = tmp[0].my_class.outdata
 
             for i in odata:
-                text += '\nOutput ' + i + ' dataset:\n'
+                text += '\nOutput ' + i + ' dataset: '
+                if i == 'RasterFileList':
+                    text += i + '\n'
+                    for j in odata[i]:
+                        text += os.path.basename(j) + '\n'
                 if i in ('Raster', 'Cluster'):
+                    if hasattr(odata[i][0], 'filename'):
+                        file = odata[i][0].filename
+                    else:
+                        file = i
+                    if '.SAFE' in file:
+                        file = file.split('.SAFE')[0]+'.SAFE'
+                    text += os.path.basename(file) + '\n'
                     for j in odata[i]:
                         text += '  '+j.dataid + '\n'
                 if i == 'Model3D':
+                    text += i + '\n'
                     for j in odata[i][0].lith_list:
                         text += '  '+j + '\n'
                 if i == 'MT - EDI':
+                    text += i + '\n'
                     for j in odata[i]:
                         text += '  '+j + '\n'
 
@@ -527,7 +564,7 @@ class MainWidget(QtWidgets.QMainWindow):
 
         sys.stdout = self.stdoutnew
         sys.breakpointhook = self.pdb
-#        sys.stderr = EmittingStream(textWritten=self.read_output)
+        # sys.stderr = EmittingStream(textWritten=self.read_output)
 
         self.menubar = QtWidgets.QMenuBar()
 
@@ -541,6 +578,7 @@ class MainWidget(QtWidgets.QMainWindow):
         self.textbrowser_processlog = QtWidgets.QTextBrowser()
         self.pbar = misc.ProgressBar()
 
+        self.action_run = QtWidgets.QAction(self)
         self.action_help = QtWidgets.QAction(self)
         self.action_delete = QtWidgets.QAction(self)
         self.action_bring_to_front = QtWidgets.QAction(self)
@@ -554,6 +592,7 @@ class MainWidget(QtWidgets.QMainWindow):
         self.action_linepointer.setCheckable(True)
         self.action_pointer.setChecked(True)
 
+        self.action_run.setIcon(QtGui.QIcon(ipth+'play.png'))
         self.action_delete.setIcon(QtGui.QIcon(ipth+'delete.png'))
         self.action_bring_to_front.setIcon(
             QtGui.QIcon(ipth+'bringtofront.png'))
@@ -571,7 +610,6 @@ class MainWidget(QtWidgets.QMainWindow):
                 onerror=lambda x: None):
             menus.append(modname)
 
-#        menus.pop(menus.index('pygmi.rsense.menu'))
         menus.pop(menus.index('pygmi.em.menu'))
         raster_menu = menus.pop(menus.index('pygmi.raster.menu'))
         vector_menu = menus.pop(menus.index('pygmi.vector.menu'))
@@ -601,6 +639,7 @@ class MainWidget(QtWidgets.QMainWindow):
         self.view.setScene(self.scene)
 
 # Menus
+        self.action_run.triggered.connect(self.run)
         self.action_pointer.triggered.connect(self.pointer)
         self.action_linepointer.triggered.connect(self.linepointer)
         self.action_delete.triggered.connect(self.delete_item)
@@ -608,7 +647,7 @@ class MainWidget(QtWidgets.QMainWindow):
         self.action_send_to_back.triggered.connect(self.send_to_back)
         self.action_help.triggered.connect(self.help_docs)
 
-    def  __del__(self):
+    def __del__(self):
         """
         Restore sys.stdout
 
@@ -634,10 +673,10 @@ class MainWidget(QtWidgets.QMainWindow):
         debugger.reset()
 
         # your custom stuff here
-#        debugger.do_where(None) # run the "where" command
+        # debugger.do_where(None) # run the "where" command
 
         # invoke the interactive debugging prompt
-        users_frame = sys._getframe().f_back # frame where user invoked pdb()
+        users_frame = sys._getframe().f_back  # frame where user invoked pdb()
         debugger.interaction(users_frame, None)
 
         sys.stdout = self.stdoutnew
@@ -691,6 +730,8 @@ class MainWidget(QtWidgets.QMainWindow):
         self.toolbar.addAction(self.action_pointer)
         self.toolbar.addAction(self.action_linepointer)
         self.toolbar.addSeparator()
+        self.toolbar.addAction(self.action_run)
+        self.toolbar.addSeparator()
         self.toolbar.addAction(self.action_help)
 
         self.setWindowTitle(
@@ -754,6 +795,26 @@ class MainWidget(QtWidgets.QMainWindow):
                 if item.my_class.indata == {} and item.is_import is False:
                     item.setBrush(self.scene.my_item_color)
 
+    def keyPressEvent(self, event):
+        """
+        Intercept keypress for custom key presses.
+
+        Parameters
+        ----------
+        event : TYPE
+            DESCRIPTION.
+
+        Returns
+        -------
+        None.
+
+        """
+
+        if event.key() == QtCore.Qt.Key_Delete:
+            self.delete_item()
+
+        event.accept()
+
     def get_indata(self):
         """
         Get input data from the selected item on the main interface.
@@ -788,7 +849,7 @@ class MainWidget(QtWidgets.QMainWindow):
         """Help Routine."""
         menu_default.HelpDocs(self, 'pygmi.main')
 
-    def item_insert(self, item_type, item_name, class_name):
+    def item_insert(self, item_type, item_name, class_name, runimport=True):
         """
         Item insert.
 
@@ -819,6 +880,8 @@ class MainWidget(QtWidgets.QMainWindow):
 
         if 'Import' in item_name:
             item.is_import = True
+
+        if 'Import' in item_name and runimport is True:
             iflag = item.settings()
             if iflag is False:
                 return None
@@ -953,6 +1016,190 @@ class MainWidget(QtWidgets.QMainWindow):
 
         self.showprocesslog(text)
 
+    def load(self):
+        """
+        Loads project state from JSON file.
+
+        Returns
+        -------
+        None.
+
+        """
+
+        self.process_is_active()
+        print('Project load busy...')
+
+        ifile, _ = QtWidgets.QFileDialog.getOpenFileName(
+            self, 'Open Project', '.', 'PyGMI project (*.json);;')
+        if ifile == '':
+            return False
+
+        # ifile = r'C:\Work\Workdata\jason.json'
+
+        with open(ifile, 'r') as fromdisk:
+            ilist = json.load(fromdisk)
+
+        ditems = {}
+        for key in ilist:
+            if '.Arrow' in key:
+                continue
+
+            item = ilist[key]
+            my_class = key
+            my_class = my_class.split()[0][1:]
+            my_class = my_class.rsplit('.', 1)
+
+            class_name = getattr(sys.modules[my_class[0]], my_class[1])
+            class_name = class_name(self)
+            item_name = item['my_class_name']
+            item_type = item['diagram_type']
+
+            citem = self.item_insert(item_type, item_name, class_name,
+                                     runimport=False)
+
+            citem.setX(item['x'])
+            citem.setY(item['y'])
+
+            ditems[key] = citem
+
+            citem.setBrush(QtGui.QColor(0, 255, 255, 254))
+            if hasattr(class_name, 'loadproj'):
+                chk = class_name.loadproj(item['itemdata'])
+                if chk is True:
+                    citem.setBrush(QtGui.QColor(0, 255, 0, 127))
+
+        for key in ilist:
+            if '.Arrow' not in key:
+                continue
+
+            start_item = ditems[ilist[key]['my_start_item']]
+            end_item = ditems[ilist[key]['my_end_item']]
+
+            arrow = Arrow(start_item, end_item)
+            start_item.add_arrow(arrow)
+            end_item.add_arrow(arrow)
+            arrow.setZValue(-1000.0)
+            self.scene.addItem(arrow)
+            end_item.update_indata()
+
+        self.process_is_active(False)
+
+    def save(self):
+        """
+        Saves project state to a JSON file.
+
+        Returns
+        -------
+        None.
+
+        """
+
+        ofile, _ = QtWidgets.QFileDialog.getSaveFileName(
+            self, 'Save Project', '.', 'PyGMI project (*.json);;')
+        if ofile == '':
+            return False
+
+        ilist = {}
+        for item in self.scene.items():
+            if isinstance(item, DiagramItem):
+                cname = str(item.my_class)
+                ilist[cname] = {'my_class_name': item.my_class_name,
+                                'diagram_type': item.diagram_type,
+                                'x': item.x(),
+                                'y': item.y()}
+
+                if hasattr(item.my_class, 'saveproj'):
+                    ilist[cname]['itemdata'] = item.my_class.saveproj()
+
+            if isinstance(item, Arrow):
+                sname = str(item.my_start_item.my_class)
+                ename = str(item.my_end_item.my_class)
+                ilist[str(item)] = {'my_start_item': sname,
+                                    'my_end_item': ename}
+
+        with open(ofile, 'w') as todisk:
+            json.dump(ilist, todisk, indent=4)
+
+    def run(self):
+        """
+        Run entire script.
+
+        Returns
+        -------
+        None.
+
+        """
+
+        # get all arrows
+        alist = {}
+        for item in self.scene.items():
+            if isinstance(item, Arrow):
+                alist[str(item)] = item
+
+        if not alist:
+            print('No connections. Aborting run.')
+            return
+
+        # Collect only items recieving data
+        ilist = []
+        slist = []
+        for item in self.scene.items():
+            if isinstance(item, DiagramItem):
+                getsdata = False
+                for i in item.arrows:
+                    if i.my_end_item == item:
+                        getsdata = True
+                if getsdata is True:
+                    ilist.append(item)
+                elif not item.is_import:
+                    slist.append(item)
+
+        # Get rid of arrows from an item sending data without an import.
+        for item in slist:
+            for i in item.arrows:
+                if str(i) in alist:
+                    del alist[str(i)]
+
+        # Delete data in modules.
+        for i in ilist:
+            if not i.is_import:
+                i.my_class.indata = {}
+                i.my_class.outdata = {}
+                # i.setBrush(self.scene.my_item_color)
+
+        # Update data
+        while ilist:
+            for item in ilist:
+                for i in item.arrows:
+                    sdata = i.my_start_item.my_class.outdata
+                    if i.my_end_item == item and sdata and str(i) in alist:
+                        item.update_indata()
+                        del alist[str(i)]
+            ilist2 = []
+            for item in ilist:
+                skip = False
+                for i in item.arrows:
+                    if i.my_end_item == item and str(i) in alist:
+                        skip = True
+                if not skip:
+                    item.update_indata()
+                    if item.brush().color() == item.scene().my_item_color:
+                        temp = item.settings(False)
+                    else:
+                        temp = item.settings(True)
+
+                    item.parent.scene.selected_item_info()
+
+                    if temp is True:
+                        item.setBrush(QtGui.QColor(0, 255, 0, 127))
+                    else:
+                        item.setBrush(item.scene().my_item_color)
+                    QtWidgets.QApplication.processEvents()
+
+                else:
+                    ilist2.append(item)
+            ilist = ilist2
+
     def send_to_back(self):
         """Send the selected item to the back."""
         if not self.scene.selectedItems():
@@ -1068,7 +1315,7 @@ class Startup(QtWidgets.QDialog):
 class EmittingStream(QtCore.QObject):
     """ Class to intercept stdout for later use in a textbox """
     textWritten = QtCore.pyqtSignal(str)
-#    terminal = sys.stdout
+    # terminal = sys.stdout
 
     # def __init__(self, textWritten):
     #     self.terminal = sys.stdout
@@ -1088,7 +1335,7 @@ class EmittingStream(QtCore.QObject):
         None.
 
         """
- #       self.terminal.write(text)
+        # self.terminal.write(text)
         self.textWritten.emit(str(text))
 
     def flush(self):
