@@ -24,8 +24,6 @@
 # -----------------------------------------------------------------------------
 """A set of Data Preparation routines."""
 
-from __future__ import print_function
-
 import os
 import sys
 import copy
@@ -198,8 +196,10 @@ class Metadata(QtWidgets.QDialog):
         try:
             odata.lat = float(self.dsb_lat.text())
             odata.lon = float(self.dsb_lon.text())
-            odata.east = float(self.dsb_utmx.text())
-            odata.north = float(self.dsb_utmy.text())
+            if self.dsb_utmx.text() != 'None':
+                odata.east = float(self.dsb_utmx.text())
+            if self.dsb_utmy.text() != 'None':
+                odata.north = float(self.dsb_utmy.text())
             odata.elev = float(self.dsb_elev.text())
 #            odata.utm_zone = float(self.dsb_utmzone.text())
             odata.rotation_angle = float(self.dsb_rot.text())
@@ -214,8 +214,14 @@ class Metadata(QtWidgets.QDialog):
         self.dsb_lat.setText(str(idata.lat))
         self.dsb_lon.setText(str(idata.lon))
         self.dsb_elev.setText(str(idata.elev))
-        self.dsb_utmx.setText(str(idata.east))
-        self.dsb_utmy.setText(str(idata.north))
+        if np.isinf(idata.east):
+            self.dsb_utmx.setText('None')
+        else:
+            self.dsb_utmx.setText(str(idata.east))
+        if np.isinf(idata.north):
+            self.dsb_utmy.setText('None')
+        else:
+            self.dsb_utmy.setText(str(idata.north))
         self.dsb_utmzone.setText(str(idata.utm_zone))
         self.dsb_rot.setText(str(idata.rotation_angle))
 
@@ -247,8 +253,14 @@ class Metadata(QtWidgets.QDialog):
         self.dsb_lat.setText(str(idata.lat))
         self.dsb_lon.setText(str(idata.lon))
         self.dsb_elev.setText(str(idata.elev))
-        self.dsb_utmx.setText(str(idata.east))
-        self.dsb_utmy.setText(str(idata.north))
+        if np.isinf(idata.east):
+            self.dsb_utmx.setText('None')
+        else:
+            self.dsb_utmx.setText(str(idata.east))
+        if np.isinf(idata.north):
+            self.dsb_utmy.setText('None')
+        else:
+            self.dsb_utmy.setText(str(idata.north))
         self.dsb_utmzone.setText(str(idata.utm_zone))
         self.dsb_rot.setText(str(idata.rotation_angle))
 
@@ -268,7 +280,7 @@ class MyMplCanvas(FigureCanvas):
     """
     MPL Canvas class.
 
-    This routine will also allow the pciking and movement of nodes of data.
+    This routine will also allow the picking and movement of nodes of data.
     """
 
     def __init__(self, parent=None):
@@ -365,7 +377,7 @@ class MyMplCanvas(FigureCanvas):
 class StaticShiftEDI(QtWidgets.QDialog):
     """Static shift EDI data."""
 
-    def __init__(self, parent):
+    def __init__(self, parent=None):
         super().__init__(parent)
         self.indata = {}
         self.outdata = {}
@@ -373,7 +385,7 @@ class StaticShiftEDI(QtWidgets.QDialog):
         self.parent = parent
 
         self.setWindowTitle('Remove Static Shift')
-        helpdocs = menu_default.HelpButton('pygmi.em.static')
+        helpdocs = menu_default.HelpButton('pygmi.mt.static')
 
         vbl = QtWidgets.QVBoxLayout(self)
         hbl = QtWidgets.QHBoxLayout()
@@ -503,7 +515,7 @@ class StaticShiftEDI(QtWidgets.QDialog):
         i2 = self.combobox2.currentText()
         self.mmc.update_line(self.data, i, i2)
 
-    def settings(self):
+    def settings(self, nodialog=False):
         """
         Entry point into item.
 
@@ -540,11 +552,52 @@ class StaticShiftEDI(QtWidgets.QDialog):
 
         return True
 
+    def loadproj(self, projdata):
+        """
+        Loads project data into class.
+
+        Parameters
+        ----------
+        projdata : dictionary
+            Project data loaded from JSON project file.
+
+        Returns
+        -------
+        chk : bool
+            A check to see if settings was successfully run.
+
+        """
+
+        self.shiftx.setValue(projdata['shiftx'])
+        self.shifty.setValue(projdata['shifty'])
+        self.checkbox.setChecked(projdata['checkbox'])
+
+        return False
+
+    def saveproj(self):
+        """
+        Save project data from class.
+
+
+        Returns
+        -------
+        projdata : dictionary
+            Project data to be saved to JSON project file.
+
+        """
+        projdata = {}
+
+        projdata['shiftx'] = self.shiftx.value()
+        projdata['shifty'] = self.shifty.value()
+        projdata['checkbox'] = self.checkbox.isChecked()
+
+        return projdata
+
 
 class RotateEDI(QtWidgets.QDialog):
     """Roitate EDI data."""
 
-    def __init__(self, parent):
+    def __init__(self, parent=None):
         super().__init__(parent)
         self.indata = {}
         self.outdata = {}
@@ -579,7 +632,7 @@ class RotateEDI(QtWidgets.QDialog):
         buttonbox.setCenterButtons(True)
         buttonbox.setStandardButtons(buttonbox.Cancel | buttonbox.Ok)
 
-        helpdocs = menu_default.HelpButton('pygmi.em.rotate')
+        helpdocs = menu_default.HelpButton('pygmi.mt.rotate')
 
         hbl.addWidget(label1)
         hbl.addWidget(self.combobox1)
@@ -674,7 +727,7 @@ class RotateEDI(QtWidgets.QDialog):
         i2 = self.combobox2.currentText()
         self.mmc.update_line(self.data, i, i2)
 
-    def settings(self):
+    def settings(self, nodialog=False):
         """
         Entry point into item.
 
@@ -714,12 +767,51 @@ class RotateEDI(QtWidgets.QDialog):
 
         return True
 
+    def loadproj(self, projdata):
+        """
+        Loads project data into class.
+
+        Parameters
+        ----------
+        projdata : dictionary
+            Project data loaded from JSON project file.
+
+        Returns
+        -------
+        chk : bool
+            A check to see if settings was successfully run.
+
+        """
+
+        self.spinbox.setValue(projdata['rotz'])
+        self.checkbox.setChecked(projdata['checkbox'])
+
+        return False
+
+    def saveproj(self):
+        """
+        Save project data from class.
+
+
+        Returns
+        -------
+        projdata : dictionary
+            Project data to be saved to JSON project file.
+
+        """
+        projdata = {}
+
+        projdata['rotz'] = self.spinbox.value()
+        projdata['checkbox'] = self.checkbox.isChecked()
+
+        return projdata
+
 
 class MyMplCanvasPick(FigureCanvas):
     """
     MPL Canvas class.
 
-    This routine will also allow the pciking and movement of nodes of data.
+    This routine will also allow the picking and movement of nodes of data.
     """
 
     def __init__(self, parent=None):
@@ -987,15 +1079,15 @@ class MyMplCanvasPick(FigureCanvas):
 class EditEDI(QtWidgets.QDialog):
     """Edit EDI Class."""
 
-    def __init__(self, parent):
+    def __init__(self, parent=None):
         super().__init__(parent)
         self.indata = {}
         self.outdata = {}
         self.data = None
         self.parent = parent
 
-        self.setWindowTitle('Edit EDI data')
-        helpdocs = menu_default.HelpButton('pygmi.em.edit')
+        self.setWindowTitle('Mask and Interpolate')
+        helpdocs = menu_default.HelpButton('pygmi.mt.edit')
 
         vbl = QtWidgets.QVBoxLayout(self)
         hbl = QtWidgets.QHBoxLayout()
@@ -1118,7 +1210,7 @@ class EditEDI(QtWidgets.QDialog):
         i2 = self.combobox2.currentText()
         self.mmc.update_line(self.data, i, i2)
 
-    def settings(self):
+    def settings(self, nodialog=False):
         """
         Entry point into item.
 
@@ -1154,6 +1246,40 @@ class EditEDI(QtWidgets.QDialog):
 
         return True
 
+    def loadproj(self, projdata):
+        """
+        Loads project data into class.
+
+        Parameters
+        ----------
+        projdata : dictionary
+            Project data loaded from JSON project file.
+
+        Returns
+        -------
+        chk : bool
+            A check to see if settings was successfully run.
+
+        """
+
+        return False
+
+    def saveproj(self):
+        """
+        Save project data from class.
+
+
+        Returns
+        -------
+        projdata : dictionary
+            Project data to be saved to JSON project file.
+
+        """
+        projdata = {}
+
+#        projdata['ftype'] = '2D Mean'
+
+        return projdata
 
 class MySlider(QtWidgets.QSlider):
     """
@@ -1290,7 +1416,7 @@ class MyMplCanvas2(FigureCanvas):
 class Occam1D(QtWidgets.QDialog):
     """Occam 1D inversion."""
 
-    def __init__(self, parent):
+    def __init__(self, parent=None):
         super().__init__(parent)
         self.indata = {}
         self.outdata = {}
@@ -1299,7 +1425,7 @@ class Occam1D(QtWidgets.QDialog):
         self.cursoln = 0
 
         self.setWindowTitle('Occam 1D Inversion')
-        helpdocs = menu_default.HelpButton('pygmi.em.occam1d')
+        helpdocs = menu_default.HelpButton('pygmi.mt.occam1d')
 
         sizepolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed,
                                            QtWidgets.QSizePolicy.Fixed)
@@ -1610,7 +1736,7 @@ class Occam1D(QtWidgets.QDialog):
 
         self.mmc.update_line(x, pdata, rdata, depths, res, title)
 
-    def settings(self):
+    def settings(self, nodialog=False):
         """
         Entry point into item.
 
@@ -1657,6 +1783,64 @@ class Occam1D(QtWidgets.QDialog):
 
         return True
 
+    def loadproj(self, projdata):
+        """
+        Loads project data into class.
+
+        Parameters
+        ----------
+        projdata : dictionary
+            Project data loaded from JSON project file.
+
+        Returns
+        -------
+        chk : bool
+            A check to see if settings was successfully run.
+
+        """
+        self.targetdepth.setText(projdata['tdepth'])
+        self.nlayers.setText(projdata['nlayers'])
+        self.bottomlayer.setText(projdata['blayer'])
+        self.airlayer.setText(projdata['alayer'])
+        self.z1layer.setText(projdata['z1layer'])
+        self.maxiter.setText(projdata['miter'])
+        self.targetrms.setText(projdata['trms'])
+        self.errres.setText(projdata['rerr'])
+        self.errphase.setText(projdata['perr'])
+        self.errfloorphase.setText(projdata['perrflr'])
+        self.errfloorres.setText(projdata['rerrflr'])
+        self.combomode.setCurrentText(projdata['mode'])
+
+        return False
+
+    def saveproj(self):
+        """
+        Save project data from class.
+
+
+        Returns
+        -------
+        projdata : dictionary
+            Project data to be saved to JSON project file.
+
+        """
+        projdata = {}
+
+        projdata['tdepth'] = self.targetdepth.text()
+        projdata['nlayers'] = self.nlayers.text()
+        projdata['blayer'] = self.bottomlayer.text()
+        projdata['alayer'] = self.airlayer.text()
+        projdata['z1layer'] = self.z1layer.text()
+        projdata['miter'] = self.maxiter.text()
+        projdata['trms'] = self.targetrms.text()
+        projdata['rerr'] = self.errres.text()
+        projdata['perr'] = self.errphase.text()
+        projdata['perrflr'] = self.errfloorphase.text()
+        projdata['rerrflr'] = self.errfloorres.text()
+        projdata['mode'] = self.combomode.currentText()
+
+        return projdata
+
 
 def tonumber(test, alttext=None):
     """
@@ -1687,7 +1871,7 @@ def tonumber(test, alttext=None):
     return int(test)
 
 
-def main():
+def test():
     """ main test """
     datadir = r'C:\Work\Programming\pygmi\data\MT\\'
     edi_file = datadir+r"synth02.edi"
@@ -1703,4 +1887,4 @@ def main():
     test.settings()
 
 if __name__ == "__main__":
-    main()
+    test()
