@@ -36,25 +36,25 @@ Blakely, R.J., 1996. Potential Theory in Gravity and Magnetic Applications,
 1st edn. Cambridge University Press, Cambridge, UK, 441 pp. 200-201
 """
 
-from __future__ import print_function
-
 import copy
 import tempfile
-from math import sqrt
+# from math import sqrt
 from PyQt5 import QtWidgets, QtCore
 
 import numpy as np
-from scipy.linalg import norm
+# from scipy.linalg import norm
 from osgeo import gdal
 from numba import jit, prange
 from matplotlib import cm
-import matplotlib
-matplotlib.use('Qt5Agg')
+import matplotlib as mpl
 import matplotlib.pyplot as plt
 from pygmi.raster.dataprep import gdal_to_dat
 from pygmi.raster.dataprep import data_to_gdal_mem
 from pygmi.pfmod.datatypes import LithModel
 from pygmi.misc import PTime
+from pygmi.misc import frm
+
+mpl.use('Qt5Agg')
 
 
 class GravMag():
@@ -65,7 +65,7 @@ class GravMag():
     related code is here as well, such as the inversion routines.
     """
 
-    def __init__(self, parent):
+    def __init__(self, parent=None):
 
         self.parent = parent
         self.lmod2 = LithModel()
@@ -77,7 +77,7 @@ class GravMag():
         else:
             self.pbars = None
         self.oldlithindex = None
-        self.mfname = self.parent.modelfilename
+#        self.mfname = self.parent.modelfilename
         self.tmpfiles = {}
 
         self.actionregionaltest = QtWidgets.QAction('Regional\nTest')
@@ -315,7 +315,7 @@ class GravMag():
 #            cns = plt.contour(magtmp, levels=csrange, colors='b', extent=etmp)
             plt.contour(magtmp, levels=csrange, colors='b', extent=etmp)
 #            plt.clabel(cns, inline=1, fontsize=10)
-        cbar = plt.colorbar(ims, orientation='horizontal')
+        cbar = plt.colorbar(ims, orientation='horizontal', format=frm)
         cbar.set_label('nT')
 
         axes = plt.subplot(122)
@@ -331,7 +331,7 @@ class GravMag():
             plt.contour(grvtmp, levels=csrange, colors='y', extent=etmp)
 #            cns = plt.contour(grvtmp, levels=csrange, colors='y', extent=etmp)
 #            plt.clabel(cns, inline=1, fontsize=10)
-        cbar = plt.colorbar(ims, orientation='horizontal')
+        cbar = plt.colorbar(ims, orientation='horizontal', format=frm)
         cbar.set_label('mGal')
         plt.tight_layout()
 
@@ -921,9 +921,12 @@ def calc_field(lmod, pbars=None, showtext=None, parent=None,
 #        showtext('No changes to model!')
 #        return None
 
-    if False not in tmp:
-        showtext('No changes to model!')
-        return None
+    try:
+        if False not in tmp:
+            showtext('No changes to model!')
+            return None
+    except:
+        breakpoint()
 
 # get height corrections
     tmp = np.copy(lmod.lith_index)
@@ -1056,7 +1059,8 @@ def calc_field(lmod, pbars=None, showtext=None, parent=None,
         lmod.griddata['Gravity Residual'].dataid = 'Gravity Residual'
 
     if parent is not None:
-        tmp = [i for i in set(lmod.griddata.values())]
+        # tmp = [i for i in set(lmod.griddata.values())]
+        tmp = list(set(lmod.griddata.values()))
         parent.outdata['Raster'] = tmp
     showtext('Calculation Finished')
     if pbars is not None:
