@@ -32,8 +32,7 @@ from PyQt5 import QtWidgets, QtCore
 import numpy as np
 from osgeo import osr, ogr
 import matplotlib.pyplot as plt
-import matplotlib.image as mpimg
-from pygmi.pfmod.datatypes import Data, LithModel
+from pygmi.pfmod.datatypes import LithModel
 import pygmi.pfmod.grvmag3d as grvmag3d
 import pygmi.pfmod.cubes as mvis3d
 import pygmi.menu_default as menu_default
@@ -47,20 +46,19 @@ sys.modules['datatypes'] = datatypes
 class ImportMod3D():
     """Import Data."""
 
-    def __init__(self, parent):
+    def __init__(self, parent=None):
         self.parent = parent
         self.lmod = LithModel()
 
         self.ifile = ''
-        self.name = 'Import 3D Model: '
-        self.ext = ''
+        self.filt = ''
         self.indata = {}
         self.outdata = {}
 
         if parent is not None:
             self.pbars = parent.pbar
 
-    def settings(self):
+    def settings(self, nodialog=False):
         """
         Entry point into item.
 
@@ -70,34 +68,35 @@ class ImportMod3D():
             True if successful, False otherwise.
 
         """
-        ext = ('npz (*.npz);;'
-               'Leapfrog Block Model (*.csv);;'
-               'x,y,z,label (*.csv);;'
-               'x,y,z,label (*.txt)')
 
-        filename, filt = QtWidgets.QFileDialog.getOpenFileName(
-            self.parent, 'Open File', '.', ext)
+        if not nodialog:
+            ext = ('npz (*.npz);;'
+                   'Leapfrog Block Model (*.csv);;'
+                   'x,y,z,label (*.csv);;'
+                   'x,y,z,label (*.txt)')
 
-        if filename == '':
-            return False
-        os.chdir(os.path.dirname(filename))
-        self.ifile = str(filename)
-        self.parent.modelfilename = filename.rpartition('.')[0]
+            self.ifile, self.filt = QtWidgets.QFileDialog.getOpenFileName(
+                self.parent, 'Open File', '.', ext)
+
+            if self.ifile == '':
+                return False
+        os.chdir(os.path.dirname(self.ifile))
+        # self.parent.modelfilename = self.ifile.rpartition('.')[0]
 
 # Reset Variables
         self.lmod.griddata.clear()
         self.lmod.lith_list.clear()
 
-        if filt == 'Leapfrog Block Model (*.csv)':
-            self.import_leapfrog_csv(filename)
-        elif filt in ('x,y,z,label (*.csv)', 'x,y,z,label (*.txt)'):
-            self.import_ascii_xyz_model(filename)
+        if self.filt == 'Leapfrog Block Model (*.csv)':
+            self.import_leapfrog_csv(self.ifile)
+        elif self.filt in ('x,y,z,label (*.csv)', 'x,y,z,label (*.txt)'):
+            self.import_ascii_xyz_model(self.ifile)
         else:
-            indict = np.load(filename, allow_pickle=True)
+            indict = np.load(self.ifile, allow_pickle=True)
             self.dict2lmod(indict)
 
         self.outdata['Model3D'] = [self.lmod]
-        self.lmod.name = os.path.basename(filename)
+        self.lmod.name = os.path.basename(self.ifile)
 
         for i in self.lmod.griddata:
             if self.lmod.griddata[i].dataid == '':
@@ -110,6 +109,46 @@ class ImportMod3D():
 
         return True
 
+    def loadproj(self, projdata):
+        """
+        Loads project data into class.
+
+        Parameters
+        ----------
+        projdata : dictionary
+            Project data loaded from JSON project file.
+
+        Returns
+        -------
+        chk : bool
+            A check to see if settings was successfully run.
+
+        """
+        self.ifile = projdata['ifile']
+        self.filt = projdata['filt']
+
+        chk = self.settings(True)
+
+        return chk
+
+    def saveproj(self):
+        """
+        Save project data from class.
+
+
+        Returns
+        -------
+        projdata : dictionary
+            Project data to be saved to JSON project file.
+
+        """
+        projdata = {}
+
+        projdata['ifile'] = self.ifile
+        projdata['filt'] = self.filt
+
+        return projdata
+
     def import_leapfrog_csv(self, filename):
         """
         Imports leapfrog csv block models.
@@ -356,6 +395,12 @@ class ImportMod3D():
         for i in lmod.griddata:
             lmod.griddata[i].data = np.ma.array(lmod.griddata[i].data)
 
+        if pre+'profpics' in indict:
+            lmod.profpics = indict[pre+'profpics'].item()
+
+            for i in lmod.profpics:
+                lmod.profpics[i].data = np.ma.array(lmod.profpics[i].data)
+
         # This gets rid of a legacy variable name
         for i in lmod.griddata:
             if not hasattr(lmod.griddata[i], 'dataid'):
@@ -365,7 +410,10 @@ class ImportMod3D():
                     lmod.griddata[i].dataid = lmod.griddata[i].bandid
                 del lmod.griddata[i].bandid
             if not hasattr(lmod.griddata[i], 'extent'):
-                rows, cols = lmod.griddata[i].data.shape
+                if lmod.griddata[i].data.ndim == 2:
+                    rows, cols = lmod.griddata[i].data.shape
+                elif lmod.griddata[i].data.ndim == 3:
+                    rows, cols, _ = lmod.griddata[i].data.shape
 
                 xmin = lmod.griddata[i].tlx
                 ymax = lmod.griddata[i].tly
@@ -427,10 +475,8 @@ class ImportMod3D():
 class ExportMod3D():
     """Export Data."""
 
-    def __init__(self, parent):
+    def __init__(self, parent=None):
         self.ifile = ''
-        self.name = 'Export 3D Model: '
-        self.ext = ''
         self.pbar = None
         self.parent = parent
         self.indata = {}
@@ -460,18 +506,18 @@ class ExportMod3D():
 
             os.chdir(os.path.dirname(filename))
             self.ifile = str(filename)
-            self.ext = filename[-3:]
+            ext = filename[-3:]
 
             print('Saving '+self.ifile+'...')
 
         # Pop up save dialog box
-            if self.ext == 'npz':
+            if ext == 'npz':
                 self.savemodel()
-            if self.ext == 'kmz':
+            if ext == 'kmz':
                 self.mod3dtokmz()
-            if self.ext == 'shp':
+            if ext == 'shp':
                 self.mod3dtoshp()
-            if self.ext == 'csv':
+            if ext == 'csv':
                 self.mod3dtocsv()
 
     def savemodel(self):
@@ -528,6 +574,7 @@ class ExportMod3D():
         outdict[pre+'zrange'] = self.lmod.zrange
         outdict[pre+'mlut'] = self.lmod.mlut
         outdict[pre+'griddata'] = self.lmod.griddata
+        outdict[pre+'profpics'] = self.lmod.profpics
         outdict[pre+'custprofx'] = self.lmod.custprofx
         outdict[pre+'custprofy'] = self.lmod.custprofy
 
@@ -1131,215 +1178,6 @@ class Exportkmz(QtWidgets.QDialog):
         buttonbox.rejected.connect(self.reject)
 
 
-class ImportPicture(QtWidgets.QDialog):
-    """Import picture dialog."""
-
-    def __init__(self, parent=None):
-        super().__init__(parent)
-
-        self.parent = parent
-        self.lmod = LithModel()
-
-        self.ifile = ''
-        self.name = 'Import Picture: '
-        self.ext = ''
-        self.pbar = None
-        self.indata = {}
-        self.outdata = {}
-        self.grid = None
-
-        self.dsb_picimp_west = QtWidgets.QDoubleSpinBox()
-        self.dsb_picimp_east = QtWidgets.QDoubleSpinBox()
-        self.dsb_picimp_depth = QtWidgets.QDoubleSpinBox()
-        self.rb_picimp_westeast = QtWidgets.QRadioButton('Profile is from West'
-                                                         ' to East')
-        self.rb_picimp_southnorth = QtWidgets.QRadioButton('Profile is from '
-                                                           'South to North')
-        self.dsb_picimp_maxalt = QtWidgets.QDoubleSpinBox()
-
-        self.setupui()
-
-        self.min_coord = None
-        self.max_coord = None
-        self.max_alt = None
-        self.min_alt = None
-        self.is_eastwest = None
-
-        self.lmod2var()
-
-    def setupui(self):
-        """
-        Set up UI.
-
-        Returns
-        -------
-        None.
-
-        """
-        groupbox = QtWidgets.QGroupBox('Profile Coordinates')
-        gridlayout_2 = QtWidgets.QGridLayout(self)
-        gridlayout_3 = QtWidgets.QGridLayout(groupbox)
-        buttonbox = QtWidgets.QDialogButtonBox()
-        helpdocs = menu_default.HelpButton('pygmi.pfmod.iodefs.importpicture')
-
-        label = QtWidgets.QLabel('West/South Coordinate')
-        label_2 = QtWidgets.QLabel('East/North Coordinate')
-        label_3 = QtWidgets.QLabel('Depth')
-        label_4 = QtWidgets.QLabel('Maximum Altitude')
-        label_5 = QtWidgets.QLabel('Press Cancel if you wish to connect '
-                                   'profile information from a 3D model')
-
-        buttonbox.setOrientation(QtCore.Qt.Horizontal)
-        buttonbox.setStandardButtons(buttonbox.Cancel | buttonbox.Ok)
-
-        self.dsb_picimp_west.setDecimals(6)
-        self.dsb_picimp_west.setMinimum(-999999999.0)
-        self.dsb_picimp_west.setMaximum(999999999.0)
-        self.dsb_picimp_west.setProperty('value', 0.0)
-        self.dsb_picimp_east.setDecimals(6)
-        self.dsb_picimp_east.setMinimum(-999999999.0)
-        self.dsb_picimp_east.setMaximum(999999999.0)
-        self.dsb_picimp_east.setProperty('value', 1000.0)
-        self.dsb_picimp_depth.setDecimals(6)
-        self.dsb_picimp_depth.setMinimum(0.0)
-        self.dsb_picimp_depth.setMaximum(999999999.0)
-        self.dsb_picimp_depth.setProperty('value', 1000.0)
-        self.rb_picimp_westeast.setChecked(True)
-        self.dsb_picimp_maxalt.setDecimals(6)
-        self.dsb_picimp_maxalt.setMinimum(-999999999.0)
-        self.dsb_picimp_maxalt.setMaximum(999999999.0)
-        self.dsb_picimp_maxalt.setProperty('value', 1000.0)
-
-        self.setWindowTitle('Profile Picture Importer')
-
-        gridlayout_2.addWidget(groupbox, 0, 0, 1, 2)
-        gridlayout_2.addWidget(label_5, 1, 0, 1, 2)
-        gridlayout_2.addWidget(helpdocs, 2, 0, 1, 1)
-        gridlayout_2.addWidget(buttonbox, 2, 1, 1, 1)
-
-        gridlayout_3.addWidget(self.rb_picimp_westeast, 0, 0, 1, 1)
-        gridlayout_3.addWidget(self.rb_picimp_southnorth, 1, 0, 1, 1)
-        gridlayout_3.addWidget(label, 2, 0, 1, 1)
-        gridlayout_3.addWidget(self.dsb_picimp_west, 2, 1, 1, 1)
-        gridlayout_3.addWidget(label_2, 4, 0, 1, 1)
-        gridlayout_3.addWidget(self.dsb_picimp_east, 4, 1, 1, 1)
-        gridlayout_3.addWidget(label_4, 5, 0, 1, 1)
-        gridlayout_3.addWidget(self.dsb_picimp_maxalt, 5, 1, 1, 1)
-        gridlayout_3.addWidget(label_3, 6, 0, 1, 1)
-        gridlayout_3.addWidget(self.dsb_picimp_depth, 6, 1, 1, 1)
-
-        buttonbox.accepted.connect(self.accept)
-        buttonbox.rejected.connect(self.reject)
-        self.rb_picimp_westeast.clicked.connect(self.lmod2var)
-        self.rb_picimp_southnorth.clicked.connect(self.lmod2var)
-
-    def lmod2var(self):
-        """
-        LithModel to variables.
-
-        Returns
-        -------
-        None.
-
-        """
-        self.is_eastwest = self.rb_picimp_westeast.isChecked()
-        self.min_alt, self.max_alt = self.lmod.zrange
-
-        if self.is_eastwest:
-            self.min_coord, self.max_coord = self.lmod.xrange
-        else:
-            self.min_coord, self.max_coord = self.lmod.yrange
-
-        self.update_win()
-
-    def update_var(self):
-        """
-        Update variables.
-
-        Returns
-        -------
-        None.
-
-        """
-        self.min_coord = self.dsb_picimp_west.value()
-        self.max_coord = self.dsb_picimp_east.value()
-        self.max_alt = self.dsb_picimp_maxalt.value()
-        self.min_alt = self.max_alt - self.dsb_picimp_depth.value()
-        self.is_eastwest = self.rb_picimp_westeast.isChecked()
-
-        if self.is_eastwest:
-            self.grid.dataid = r'West to East'
-        else:
-            self.grid.dataid = r'South to North'
-
-        self.grid.dataid = 'Image'
-        self.grid.nullvalue = 0
-
-        rows, cols = self.grid.data.shape
-
-        self.grid.xdim = (self.max_coord-self.min_coord)/cols
-        self.grid.ydim = (self.max_alt-self.min_alt)/rows
-        self.grid.extent = [self.min_coord, self.max_coord, self.min_alt,
-                            self.max_alt]
-
-    def update_win(self):
-        """
-        Update window values.
-
-        Returns
-        -------
-        None.
-
-        """
-        self.dsb_picimp_west.setValue(self.min_coord)
-        self.dsb_picimp_east.setValue(self.max_coord)
-        self.dsb_picimp_maxalt.setValue(self.max_alt)
-        self.dsb_picimp_depth.setValue(self.max_alt-self.min_alt)
-
-    def settings(self):
-        """
-        Load GeoTiff
-
-        Returns
-        -------
-        bool
-            True if successful, False otherwise.
-
-        """
-        if 'Model3D' in self.indata:
-            self.lmod = self.indata['Model3D'][0]
-            self.lmod2var()
-
-        temp = self.exec_()
-        if temp == 0:
-            return False
-
-        filename, _ = QtWidgets.QFileDialog.getOpenFileName(
-            self.parent, 'Open File', '.', '*.jpg *.tif *.bmp')
-
-        if filename == '':
-            return False
-        os.chdir(os.path.dirname(filename))
-
-        self.ifile = filename
-
-        data = mpimg.imread(filename)
-
-        self.grid = Data()
-        self.grid.data = data
-
-        if (self.dsb_picimp_west.value() >=
-                self.dsb_picimp_east.value()):
-            return False
-        if self.dsb_picimp_depth.value() == 0.0:
-            return False
-
-        self.update_var()
-        self.outdata['ProfPic'] = [self.grid]
-
-        return True
-
-
 class MessageCombo(QtWidgets.QDialog):
     """
     Message combo box.
