@@ -41,7 +41,7 @@ import pygmi.misc as pmisc
 class MainWidget(QtWidgets.QMainWindow):
     """MainWidget - Widget class to call the main interface."""
 
-    def __init__(self, parent):
+    def __init__(self, parent=None):
         super().__init__(parent)
 
         self.indata = {'tmp': True}
@@ -52,9 +52,9 @@ class MainWidget(QtWidgets.QMainWindow):
 
 # General
         self.txtmsg = ''
-        self.modelfilename = r'./tmp'
+        # self.modelfilename = r'./tmp'
 
-#        self.toolbar = QtWidgets.QToolBar()
+        # self.toolbar = QtWidgets.QToolBar()
         self.toolbardock = QtWidgets.QToolBar()
         self.statusbar = QtWidgets.QStatusBar()
 
@@ -97,7 +97,7 @@ class MainWidget(QtWidgets.QMainWindow):
 
     def setupui(self):
         """
-        Setup for the GUI.
+        GUI setup.
 
         Returns
         -------
@@ -134,7 +134,8 @@ class MainWidget(QtWidgets.QMainWindow):
         helpdocs.clicked.connect(self.help_docs)
         self.actionsave.triggered.connect(self.savemodel)
 
-        self.resize(self.parent.width(), self.parent.height())
+        if self.parent is not None:
+            self.resize(self.parent.width(), self.parent.height())
 
     def savemodel(self):
         """
@@ -145,12 +146,13 @@ class MainWidget(QtWidgets.QMainWindow):
         None.
 
         """
-        self.showtext('Saving Model, please do not close the interface...')
+        self.showtext('Saving model, please do not close the interface...')
         tmp = iodefs.ExportMod3D(self)
         tmp.indata = self.outdata
         tmp.run()
 
         del tmp
+        self.showtext('Model save complete!')
 
     def help_docs(self):
         """
@@ -163,7 +165,7 @@ class MainWidget(QtWidgets.QMainWindow):
         """
         menu_default.HelpDocs(self, 'pygmi.pfmod.prof')
 
-    def settings(self):
+    def settings(self, nodialog=False):
         """
         Entry point into item.
 
@@ -193,16 +195,43 @@ class MainWidget(QtWidgets.QMainWindow):
 
         self.outdata['Raster'] = datatmp
 
-        if 'ProfPic' in self.indata:
-            icnt = 0
-            for i in self.indata['ProfPic']:
-                icnt += 1
-                self.lmod1.profpics['Profile: '+str(icnt)] = i
-
         self.show()
 
         return True
 
+    def loadproj(self, projdata):
+        """
+        Load project data into class.
+
+        Parameters
+        ----------
+        projdata : dictionary
+            Project data loaded from JSON project file.
+
+        Returns
+        -------
+        chk : bool
+            A check to see if settings was successfully run.
+
+        """
+        return False
+
+    def saveproj(self):
+        """
+        Save project data from class.
+
+        Returns
+        -------
+        projdata : dictionary
+            Project data to be saved to JSON project file.
+
+        """
+        projdata = {}
+
+#        projdata['ftype'] = '2D Mean'
+
+        return projdata
+
     def data_reset(self):
         """
         Reset the data.
@@ -242,3 +271,28 @@ class MainWidget(QtWidgets.QMainWindow):
         tmp = self.textbrowser.verticalScrollBar()
         tmp.setValue(tmp.maximumHeight())
         self.repaint()
+
+
+def testfn():
+    """Main testing routine."""
+    import sys
+    from pygmi.pfmod.iodefs import ImportMod3D
+    app = QtWidgets.QApplication(sys.argv)  # Necessary to test Qt Classes
+
+    ifile = r'C:\Work\Workdata\people\Mpumi\model2.npz'
+#    ifile = r'C:\Work\Workdata\modelling\Magmodel_Upper22km_AveAll_diapir_withDeepDens_newdens.npz'
+
+    IO = ImportMod3D()
+
+    IO.ifile = ifile
+    IO.settings(True)
+
+    PF = MainWidget()
+    PF.indata = IO.outdata
+    PF.settings()
+
+    app.exec_()
+
+
+if __name__ == "__main__":
+    testfn()
