@@ -33,7 +33,8 @@ import pygmi.misc as pmisc
 
 class MextDisplay(QtWidgets.QDialog):
     """MextDisplay - Widget class to call the main interface."""
-    def __init__(self, parent):
+
+    def __init__(self, parent=None):
         super().__init__(parent)
         self.parent = parent
         self.lmod1 = parent.lmod1  # actual model
@@ -478,6 +479,9 @@ class MextDisplay(QtWidgets.QDialog):
         None.
 
         """
+
+        self.combo_dataset.currentIndexChanged.disconnect()
+
         gkeys = list(self.parent.inraster.keys())
         if 'Calculated Gravity' in gkeys:
             gkeys.remove('Calculated Gravity')
@@ -530,6 +534,9 @@ class MextDisplay(QtWidgets.QDialog):
                 tmp = self.lmod1.griddata['Other'].dataid
                 self.combo_other.setCurrentIndex(gkeys.index(tmp))
 
+        self.combo_dataset.currentIndexChanged.connect(self.get_area)
+
+
     def update_vals(self):
         """
         Update the visible model extent parameters.
