@@ -24,6 +24,7 @@
 # -----------------------------------------------------------------------------
 """Profile Display Tab Routines."""
 
+import copy
 import os
 import random
 from PyQt5 import QtWidgets, QtCore, QtGui
@@ -45,6 +46,7 @@ import pygmi.menu_default as menu_default
 from pygmi.raster.dataprep import gdal_to_dat
 from pygmi.raster.dataprep import data_to_gdal_mem
 from pygmi.raster.iodefs import get_raster
+from pygmi.misc import frm
 
 rcParams['savefig.dpi'] = 600.
 
@@ -52,7 +54,7 @@ rcParams['savefig.dpi'] = 600.
 class ProfileDisplay(QtWidgets.QWidget):
     """Widget class to call the main interface."""
 
-    def __init__(self, parent):
+    def __init__(self, parent=None):
         super().__init__(parent)
 
         self.parent = parent
@@ -298,8 +300,13 @@ class ProfileDisplay(QtWidgets.QWidget):
         """
         curline = self.sb_cprofnum.value()
 
-        cnt = len(self.lmod1.profpics)
-        if cnt == 0:
+        cnt = len(self.lmod1.custprofx)
+        if 'rotate' in self.lmod1.custprofx:
+            cnt -= 1
+        if 'adhoc' in self.lmod1.custprofx:
+            cnt -= 1
+
+        if cnt <= 0:
             return
 
         j = -1
@@ -307,10 +314,13 @@ class ProfileDisplay(QtWidgets.QWidget):
             if i == curline:
                 continue
             j += 1
-            self.lmod1.profpics[j] = self.lmod1.profpics[i]
+            if i == j:
+                continue
+            if i in self.lmod1.profpics:
+                self.lmod1.profpics[j] = self.lmod1.profpics[i]
+                del self.lmod1.profpics[i]
             self.lmod1.custprofx[j] = self.lmod1.custprofx[i]
             self.lmod1.custprofy[j] = self.lmod1.custprofy[i]
-        del self.lmod1.profpics[cnt-1]
         del self.lmod1.custprofx[cnt-1]
         del self.lmod1.custprofy[cnt-1]
 
@@ -430,6 +440,10 @@ class ProfileDisplay(QtWidgets.QWidget):
 
         gtmp = self.get_model()
 
+        if gtmp is False:
+            self.showtext('Your custom profile is not in the area')
+            return
+
         self.mmc.init_grid(gtmp, gtmpl, self.hs_sideview.value())
         self.mmc.update_line()
         self.mmc.update_line_top()
@@ -599,16 +613,13 @@ class ProfileDisplay(QtWidgets.QWidget):
                 if 'Calculated Gravity' in i:
                     data1.data = data1.data + self.lmod1.gregional
 
-                xratio = data.xdim/data1.xdim
-                yratio = data.ydim/data1.ydim
-
                 dtlx = data.extent[0]
                 d2tlx = data1.extent[0]
                 dtly = data.extent[-1]
                 d2tly = data1.extent[-1]
 
-                rxxx2 = (dtlx-d2tlx)/data1.xdim+self.rxxx*xratio
-                ryyy2 = (d2tly-dtly)/data1.ydim+self.ryyy*yratio
+                rxxx2 = (dtlx-d2tlx+self.rxxx*data.xdim)/data1.xdim
+                ryyy2 = (d2tly-dtly+self.ryyy*data.ydim)/data1.ydim
 
                 tmp = data1.data.filled(np.nan)
                 data2[i] = ndimage.map_coordinates(tmp[::-1],
@@ -896,6 +907,12 @@ class ProfileDisplay(QtWidgets.QWidget):
         y1, y2 = self.lmod1.custprofy['adhoc']
         px1, px2 = self.lmod1.custprofx['rotate']
 
+        if not(self.lmod1.xrange[0] <= x1 <= x2 <= self.lmod1.xrange[1]):
+            return False
+
+        if not(self.lmod1.yrange[0] <= y1 <= y2 <= self.lmod1.yrange[1]):
+            return False
+
         # convert units to cells
         bly = self.lmod1.yrange[0]
         tlx = self.lmod1.xrange[0]
@@ -1385,27 +1402,26 @@ class ProfileDisplay(QtWidgets.QWidget):
         tmprng2 = None
         tmpprof2 = None
         if 'Magnetic Dataset' in self.lmod1.griddata and self.viewmagnetics:
-            data2 = self.lmod1.griddata['Magnetic Dataset']
+            data2 = copy.deepcopy(self.lmod1.griddata['Magnetic Dataset'])
         elif ('Gravity Dataset' in self.lmod1.griddata and
               not self.viewmagnetics):
-            data2 = self.lmod1.griddata['Gravity Dataset']
+            data2 = copy.deepcopy(self.lmod1.griddata['Gravity Dataset'])
 
         if data2 is not None:
-            xratio = data.xdim/data2.xdim
-            yratio = data.ydim/data2.ydim
+            data2.data = np.pad(data2.data, 1, 'edge')
+            data2.data = np.ma.masked_equal(data2.data, data2.nullvalue)
 
             dtlx = data.extent[0]
             d2tlx = data2.extent[0]
             dbly = data.extent[-2]
             d2bly = data2.extent[-2]
 
-            rxxx2 = (dtlx-d2tlx)/data2.xdim+self.rxxx*xratio
-            ryyy2 = (dbly-d2bly)/data2.ydim+self.ryyy*yratio
+            rxxx2 = (dtlx-d2tlx+self.rxxx*data.xdim)/data2.xdim+1
+            ryyy2 = (dbly-d2bly+self.ryyy*data.ydim)/data2.ydim+1
 
             tmprng2 = np.linspace(px1, px2, len(rxxx2))
             tmpprof2 = ndimage.map_coordinates(data2.data[::-1],
-                                               [ryyy2-0.5,
-                                                rxxx2-0.5],
+                                               [ryyy2-0.5, rxxx2-0.5],
                                                order=1, cval=np.nan)
 
             tmprng2 = tmprng2[np.logical_not(np.isnan(tmpprof2))]
@@ -1421,8 +1437,6 @@ class ProfileDisplay(QtWidgets.QWidget):
                     extent = [tmpprof2.min(), tmpprof2.max()]
 
         if slide is True:
-#            xlim = self.mmc.axes.get_xlim()
-#            extent = [xlim[0], xlim[1]] + extent
             self.mmc.slide_plot(tmprng, tmpprof, tmprng2, tmpprof2)
             self.mmc.figure.canvas.draw()
         else:
@@ -1495,7 +1509,8 @@ class ProfileDisplay(QtWidgets.QWidget):
 
 class MyMplCanvas(FigureCanvas):
     """Matplotlib Canvas"""
-    def __init__(self, parent):
+
+    def __init__(self, parent=None):
         fig = Figure()
         super().__init__(fig)
 
@@ -1549,7 +1564,7 @@ class MyMplCanvas(FigureCanvas):
         self.lims2 = self.laxes.imshow(self.lmdata, cmap=self.cbar,
                                        aspect='equal', interpolation='none')
 
-        self.colbar = fig.colorbar(self.lims2)
+        self.colbar = fig.colorbar(self.lims2, format=frm)
 
         self.lims = self.laxes.imshow(self.cbar(self.lmdata), aspect='equal',
                                       interpolation='none')
@@ -1654,10 +1669,12 @@ class MyMplCanvas(FigureCanvas):
             height /= mdata.shape[0]
             width *= xptp/vlim.width
             height *= yptp/vlim.height
-            width *= (2*self.mywidth-1)
-            height *= (2*self.mywidth-1)
+            width *= self.mywidth
+            height *= self.mywidth
 
-            width = np.ceil(width)  # *10
+            if curaxes == self.axes:
+                width *= 10
+            width = np.ceil(width)
             height = np.ceil(height)
 
             cbit = QtGui.QBitmap(width, height)
@@ -1665,30 +1682,23 @@ class MyMplCanvas(FigureCanvas):
             self.setCursor(QtGui.QCursor(cbit))
 
         if self.press is True:
-            xdata = int((event.xdata - xmin)/dx)+1
-            ydata = int((event.ydata - ymin)/dy)+1
+            xdata = (event.xdata - xmin)/dx
+            ydata = (event.ydata - ymin)/dy
 
             if self.newline is True:
                 self.newline = False
                 self.set_mdata(xdata, ydata, mdata)
-            elif xdata != self.xold:
-                mmm = float(ydata-self.yold)/(xdata-self.xold)
-                ccc = ydata - mmm * xdata
-                x_1 = min([self.xold, xdata])
-                x_2 = max([self.xold, xdata])
-                for i in range(x_1+1, x_2+1):
-                    jold = int(mmm*(i-1)+ccc)
-                    jnew = int(mmm*i+ccc)
-                    if jold > jnew:
-                        jold, jnew = jnew, jold
-                    for j in range(jold, jnew+1):
-                        self.set_mdata(i, j, mdata)
+            else:
 
-            elif ydata != self.yold:
-                y_1 = min([self.yold, ydata])
-                y_2 = max([self.yold, ydata])
-                for j in range(y_1, y_2+1):
-                    self.set_mdata(xdata, j, mdata)
+                rrr = np.sqrt((self.xold-xdata)**2+(self.yold-ydata)**2)
+                steps = int(rrr)+1
+#                steps = int(max(abs(self.xold-xdata),
+#                                abs(self.yold-ydata)))+1
+                xxx = np.linspace(self.xold, xdata, steps)
+                yyy = np.linspace(self.yold, ydata, steps)
+
+                for i, _ in enumerate(xxx):
+                    self.set_mdata(xxx[i], yyy[i], mdata)
 
             self.xold = xdata
             self.yold = ydata
@@ -1707,10 +1717,9 @@ class MyMplCanvas(FigureCanvas):
                     yyy2 = yyy[rpix]
                     self.lmod1.lith_index[xxx2, yyy2, i] = self.curmodel
 
-#                self.lmod1.lith_index[xxx, yyy, ::-1] = mdata[:, ipdx1:ipdx2].T
-#                self.mdata = mdata
                 self.lmdata = self.lmod1.lith_index[:, :, curlayer].T
-                self.mdata[:, ipdx1:ipdx2] = self.lmod1.lith_index[xxx, yyy, ::-1].T
+                self.mdata[:, ipdx1:ipdx2] = self.lmod1.lith_index[xxx, yyy,
+                                                                   ::-1].T
             else:
                 self.lmod1.lith_index[:, :, curlayer] = mdata.T
                 self.lmdata = mdata
@@ -1722,7 +1731,8 @@ class MyMplCanvas(FigureCanvas):
 
     def set_mdata(self, xdata, ydata, mdata):
         """
-        Routine to 'draw' the line on mdata.
+        Routine to 'draw' the line on mdata. xdata and ydata are the cursor
+        centre coordinates.
 
         Parameters
         ----------
@@ -1738,11 +1748,22 @@ class MyMplCanvas(FigureCanvas):
         None.
 
         """
-        width = self.mywidth-1  # 'pen' width
-        xstart = max(0, xdata-width-1)
-        xend = min(mdata.shape[1], xdata+width)
-        ystart = max(0, ydata-width-1)
-        yend = min(mdata.shape[0], ydata+width)
+        if xdata < 0:
+            xdata = 0
+        if ydata < 0:
+            ydata = 0
+
+        hwidth = self.mywidth/2
+        xstart = max(0, xdata-hwidth)
+        xend = min(mdata.shape[1], xdata+hwidth)
+        ystart = max(0, ydata-hwidth)
+        yend = min(mdata.shape[0], ydata+hwidth)
+
+        xstart = int(round(xstart))
+        xend = int(round(xend))
+        ystart = int(round(ystart))
+        yend = int(round(yend))
+
         if xstart < xend and ystart < yend:
             mtmp = mdata[ystart:yend, xstart:xend]
             mtmp[np.logical_and(mtmp != -1, mtmp < 900)] = self.curmodel
@@ -1822,6 +1843,8 @@ class MyMplCanvas(FigureCanvas):
         self.ims2.set_visible(False)
         self.axes.set_xlim(extent[0], extent[1])
         self.axes.set_ylim(extent[2], extent[3])
+        self.axes.xaxis.set_major_formatter(frm)
+        self.axes.yaxis.set_major_formatter(frm)
 
         if dat2 is not None:
             self.ims.set_alpha(self.opac)
@@ -1890,7 +1913,10 @@ class MyMplCanvas(FigureCanvas):
         self.ylims = (bottom, top)
         self.laxes.set_xlim(self.xlims)
         self.laxes.set_ylim(self.ylims)
-#
+        self.laxes.xaxis.set_major_formatter(frm)
+        self.laxes.yaxis.set_major_formatter(frm)
+
+
         self.lims.set_visible(True)
 
         self.figure.tight_layout()
@@ -2035,6 +2061,8 @@ class MyMplCanvas(FigureCanvas):
         self.paxes.yaxis.set_label_text(self.punit)
         self.paxes.set_ylim(dmin, dmax)
         self.paxes.set_xlim(extent[0], extent[1])
+        self.paxes.xaxis.set_major_formatter(frm)
+        self.paxes.yaxis.set_major_formatter(frm)
 
         self.paxes.set_autoscalex_on(False)
         if xdat2 is not None:
@@ -2281,7 +2309,7 @@ class PlotScale(QtWidgets.QDialog):
 class RangedCopy(QtWidgets.QDialog):
     """Class to call up a dialog for ranged copying."""
 
-    def __init__(self, parent):
+    def __init__(self, parent=None):
         super().__init__(parent)
 
         self.parent = parent
@@ -2409,7 +2437,7 @@ class MyToolbar(NavigationToolbar2QT):
                    'Borehole Logs', 'Borehole Logs', 'b_logs'),
                   )
 
-    def __init__(self, parent):
+    def __init__(self, parent=None):
         super().__init__(parent.mmc, parent)
         self.parent = parent
 
@@ -2504,15 +2532,13 @@ class GaugeWidget(QtWidgets.QDial):
 class ImportPicture(QtWidgets.QDialog):
     """Import Picture dialog."""
 
-    def __init__(self, parent):
+    def __init__(self, parent=None):
         super().__init__(parent)
 
         self.parent = parent
         self.lmod = self.parent.lmod1
 
         self.ifile = ''
-        self.name = 'Add New Custom Profile: '
-        self.ext = ''
         self.pbar = None
         self.indata = {}
         self.outdata = {}
@@ -2659,7 +2685,7 @@ class ImportPicture(QtWidgets.QDialog):
         self.dsb_zmin.setValue(zmin)
         self.dsb_zmax.setValue(zmax)
 
-    def settings(self):
+    def settings(self, nodialog=False):
         """
         Settings.
 
@@ -2721,11 +2747,11 @@ class ImportPicture(QtWidgets.QDialog):
             x1a = f(y1a)
             x2a = f(y2a)
 
-            if y1 != y1a:
+            if self.lmod.xrange[0] <= x1a <= self.lmod.xrange[1]:
                 x1 = x1a
                 y1 = y1a
 
-            if y2 != y2a:
+            if self.lmod.xrange[0] <= x2a <= self.lmod.xrange[1]:
                 x2 = x2a
                 y2 = y2a
 
@@ -2739,6 +2765,11 @@ class ImportPicture(QtWidgets.QDialog):
 
         imptext = self.importfile.text()
         if imptext != '':
+            x1a = self.dsb_x1.value()
+            x2a = self.dsb_x2.value()
+            y1a = self.dsb_y1.value()
+            y2a = self.dsb_y2.value()
+
             dat = get_raster(imptext)
 
             if dat is None:
@@ -2753,24 +2784,49 @@ class ImportPicture(QtWidgets.QDialog):
             dat.data = dat2
             dat.isrgb = True
 
-            r1 = 0
-            r2 = np.sqrt((x2-x1)**2+(y2-y1)**2)
-            if x1 != x2:
-                f = interpolate.interp1d([x1, x2], [r1, r2],
-                                         fill_value='extrapolate')
-                ra = f(self.dsb_x1.value())
-                rb = f(self.dsb_x2.value())
-            else:
-                f = interpolate.interp1d([y1, y2], [r1, r2],
-                                         fill_value='extrapolate')
-                ra = f(self.dsb_y1.value())
-                rb = f(self.dsb_y2.value())
+            ra = np.sqrt((x1a-x1)**2+(y1a-y1)**2)
+            rb = np.sqrt((x2a-x1)**2+(y2a-y1)**2)
 
             dat.extent = (ra, rb, zmin, zmax)
             self.lmod.profpics[curline] = dat
 
         return curline
 
+    def loadproj(self, projdata):
+        """
+        Loads project data into class.
+
+        Parameters
+        ----------
+        projdata : dictionary
+            Project data loaded from JSON project file.
+
+        Returns
+        -------
+        chk : bool
+            A check to see if settings was successfully run.
+
+        """
+
+        return False
+
+    def saveproj(self):
+        """
+        Save project data from class.
+
+
+        Returns
+        -------
+        projdata : dictionary
+            Project data to be saved to JSON project file.
+
+        """
+        projdata = {}
+
+#        projdata['ftype'] = '2D Mean'
+
+        return projdata
+
 
 def gridmatch2(cgrv, rgrv):
     """
@@ -2844,3 +2900,17 @@ def rotate2d(pts, cntr, ang=np.pi/4):
     trans = np.array([[np.cos(ang), np.sin(ang)], [-np.sin(ang), np.cos(ang)]])
     pts2 = np.dot(pts-cntr, trans) + cntr
     return pts2
+
+
+def testfn():
+    """Main testing routine."""
+    aaa = np.arange(12.).reshape((4, 3))
+    print(aaa)
+
+    bbb = ndimage.map_coordinates(aaa, [[.5, 2], [.5, 1]], order=1)
+
+    print(bbb)
+
+
+if __name__ == "__main__":
+    testfn()
