@@ -33,7 +33,6 @@
 import copy
 from PyQt5 import QtWidgets, QtCore
 import numpy as np
-import scipy.signal as si
 
 import pygmi.menu_default as menu_default
 
@@ -57,7 +56,7 @@ class Gradients(QtWidgets.QDialog):
         Order of DR filter - see paper. Try 1 first.
     """
 
-    def __init__(self, parent):
+    def __init__(self, parent=None):
         super().__init__(parent)
 
         self.parent = parent
@@ -122,7 +121,7 @@ class Gradients(QtWidgets.QDialog):
         self.rb_dratio.clicked.connect(self.radiochange)
         self.rb_vgrad.clicked.connect(self.radiochange)
 
-    def settings(self):
+    def settings(self, nodialog=False):
         """
         Entry point into item.
 
@@ -132,9 +131,10 @@ class Gradients(QtWidgets.QDialog):
             True if successful, False otherwise.
 
         """
-        temp = self.exec_()
-        if temp == 0:
-            return False
+        if not nodialog:
+            temp = self.exec_()
+            if temp == 0:
+                return False
 
         self.azi = self.sb_azi.value()
         self.order = self.sb_order.value()
@@ -163,6 +163,64 @@ class Gradients(QtWidgets.QDialog):
 
         return True
 
+    def loadproj(self, projdata):
+        """
+        Load project data into class.
+
+        Parameters
+        ----------
+        projdata : dictionary
+            Project data loaded from JSON project file.
+
+        Returns
+        -------
+        chk : bool
+            A check to see if settings was successfully run.
+
+        """
+        self.azi = projdata['azim']
+        self.order = projdata['order']
+
+        self.sb_azi.setValue(projdata['azim'])
+        self.sb_order.setValue(projdata['order'])
+
+        if projdata['type'] == 'dratio':
+            self.rb_dratio.setChecked(True)
+        if projdata['type'] == 'ddir':
+            self.rb_dratio.setChecked(True)
+        if projdata['type'] == 'vgrad':
+            self.rb_dratio.setChecked(True)
+
+        self.radiochange()
+
+        return False
+
+    def saveproj(self):
+        """
+        Save project data from class.
+
+        Returns
+        -------
+        projdata : dictionary
+            Project data to be saved to JSON project file.
+
+        """
+        projdata = {}
+
+        self.azi = self.sb_azi.value()
+        self.order = self.sb_order.value()
+        projdata['azim'] = self.azi
+        projdata['order'] = self.order
+
+        if self.rb_dratio.isChecked():
+            projdata['type'] = 'dratio'
+        elif self.rb_ddir.isChecked():
+            projdata['type'] = 'ddir'
+        else:
+            projdata['type'] = 'vgrad'
+
+        return projdata
+
     def radiochange(self):
         """
         Check radio button state.
@@ -263,7 +321,7 @@ class Visibility2d(QtWidgets.QDialog):
         height of observer above surface
     """
 
-    def __init__(self, parent):
+    def __init__(self, parent=None):
         super().__init__(parent)
 
         self.parent = parent
@@ -317,7 +375,7 @@ class Visibility2d(QtWidgets.QDialog):
         buttonbox.accepted.connect(self.accept)
         buttonbox.rejected.connect(self.reject)
 
-    def settings(self):
+    def settings(self, nodialog=False):
         """
         Entry point into item.
 
@@ -327,9 +385,10 @@ class Visibility2d(QtWidgets.QDialog):
             True if successful, False otherwise.
 
         """
-        temp = self.exec_()
-        if temp == 0:
-            return False
+        if not nodialog:
+            temp = self.exec_()
+            if temp == 0:
+                return False
 
         self.wsize = self.sb_wsize.value()
         self.dh = self.sb_dh.value()
@@ -358,6 +417,43 @@ class Visibility2d(QtWidgets.QDialog):
 
         return True
 
+    def loadproj(self, projdata):
+        """
+        Load project data into class.
+
+        Parameters
+        ----------
+        projdata : dictionary
+            Project data loaded from JSON project file.
+
+        Returns
+        -------
+        chk : bool
+            A check to see if settings was successfully run.
+
+        """
+        self.sb_wsize.setValue(projdata['wsize'])
+        self.sb_dh.setValue(projdata['vheight'])
+
+        return False
+
+    def saveproj(self):
+        """
+        Save project data from class.
+
+        Returns
+        -------
+        projdata : dictionary
+            Project data to be saved to JSON project file.
+
+        """
+        projdata = {}
+
+        projdata['wsize'] = self.sb_wsize.value()
+        projdata['vheight'] = self.sb_dh.value()
+
+        return projdata
+
 
 def visibility2d(data, wsize, dh, piter=iter):
     """
@@ -525,207 +621,6 @@ def __visible2(dat, cp, dh):
     return num
 
 
-class Tilt1(QtWidgets.QDialog):
-    """
-    Class used to gather information via a GUI, for function tilt1.
-
-    Attributes
-    ----------
-    parent : parent
-    indata : dictionary
-        PyGMI input data in a dictionary
-    outdata :
-        PyGMI input data in a dictionary
-    azi : float
-        directional filter azimuth in degrees from East
-    smooth : int
-        size of smoothing matrix to use - must be odd input 0 for no smoothing
-    """
-
-    def __init__(self, parent):
-        super().__init__(parent)
-
-        self.parent = parent
-        self.indata = {}
-        self.outdata = {}
-        self.azi = 75
-        self.smooth = 0
-        self.pbar = self.parent.pbar
-
-        self.sb_azi = QtWidgets.QSpinBox()
-        self.sb_s = QtWidgets.QSpinBox()
-
-        self.setupui()
-
-        self.sb_s.setValue(self.smooth)
-        self.sb_azi.setValue(self.azi)
-
-    def setupui(self):
-        """
-        Set up UI.
-
-        Returns
-        -------
-        None.
-
-        """
-        gridlayout = QtWidgets.QGridLayout(self)
-        buttonbox = QtWidgets.QDialogButtonBox()
-        helpdocs = menu_default.HelpButton('pygmi.raster.cooper.tilt')
-        label = QtWidgets.QLabel('Azimuth (degrees from east)')
-        label_2 = QtWidgets.QLabel('Smoothing Matrix Size (Odd, 0 for None)')
-
-        buttonbox.setOrientation(QtCore.Qt.Horizontal)
-        buttonbox.setStandardButtons(buttonbox.Cancel | buttonbox.Ok)
-        self.sb_azi.setMinimum(-360)
-        self.sb_azi.setMaximum(360)
-        self.sb_azi.setProperty('value', 0)
-        self.sb_s.setPrefix('')
-        self.sb_s.setMinimum(0)
-        self.sb_s.setMaximum(100000)
-        self.sb_s.setSingleStep(1)
-
-        self.setWindowTitle('Tilt Angle')
-
-        gridlayout.addWidget(label_2, 0, 0, 1, 1)
-        gridlayout.addWidget(self.sb_s, 0, 1, 1, 1)
-        gridlayout.addWidget(label, 1, 0, 1, 1)
-        gridlayout.addWidget(self.sb_azi, 1, 1, 1, 1)
-        gridlayout.addWidget(helpdocs, 2, 0, 1, 1)
-        gridlayout.addWidget(buttonbox, 2, 1, 1, 1)
-
-        buttonbox.accepted.connect(self.accept)
-        buttonbox.rejected.connect(self.reject)
-
-    def settings(self):
-        """
-        Entry point into item.
-
-        Returns
-        -------
-        bool
-            True if successful, False otherwise.
-
-        """
-        temp = self.exec_()
-        if temp == 0:
-            return False
-
-        self.smooth = self.sb_s.value()
-        self.azi = self.sb_azi.value()
-
-        data = copy.deepcopy(self.indata['Raster'])
-        data2 = []
-
-        for i in self.pbar.iter(range(len(data))):
-            t1, th, t2, ta, tdx = tilt1(data[i].data, self.azi, self.smooth)
-            data2.append(copy.deepcopy(data[i]))
-            data2.append(copy.deepcopy(data[i]))
-            data2.append(copy.deepcopy(data[i]))
-            data2.append(copy.deepcopy(data[i]))
-            data2.append(copy.deepcopy(data[i]))
-            data2[-5].data = t1
-            data2[-4].data = th
-            data2[-3].data = t2
-            data2[-2].data = ta
-            data2[-1].data = tdx
-            data2[-5].dataid += ' Standard Tilt Angle'
-            data2[-4].dataid += ' Hyperbolic Tilt Angle'
-            data2[-3].dataid += ' 2nd Order Tilt Angle'
-            data2[-2].dataid += ' Tilt Based Directional Derivative'
-            data2[-1].dataid += ' Total Derivative'
-
-        for i in data2:
-            i.data.data[i.data.mask] = i.nullvalue
-
-        self.outdata['Raster'] = data2
-        return True
-
-
-def tilt1(data, azi, s):
-    """
-    Tilt angle calculations.
-
-    Parameters
-    ----------
-    data : numpy array
-        matrix of double to be filtered
-    azi : float
-        directional filter azimuth in degrees from East
-    s : int
-        size of smoothing matrix to use - must be odd input 0 for no smoothing
-
-    Returns
-    -------
-    t1 : numpy masked array
-        Standard tilt angle
-    th : numpy masked array
-        Hyperbolic tilt angle
-    t2 : numpy masked array
-        2nd order tilt angle
-    ta : numpy masked array
-        Tilt Based Directional Derivative
-    tdx : numpy masked array
-        Total Derivative
-    """
-    dmin = data.min()
-    dmax = data.max()
-    dm = 0.5*(dmin+dmax)
-    data.data[data.mask] = dm
-    data[np.isnan(data)] = dm
-    data[np.isinf(data)] = dm
-
-    if s > 0:
-        se = np.ones((s, s))/(s*s)
-        data2 = si.convolve2d(data, se, 'valid')  # smooth
-        mask = si.convolve2d(data.mask, se, 'valid')
-        data = np.ma.array(data2, mask=mask)
-
-    nr, nc = data.shape
-    dtr = np.pi/180.0
-    azi = azi*dtr
-
-    dy, dx = np.gradient(data)
-#    dx = dx.astype(np.float64)
-#    dy = dy.astype(np.float64)
-    dxtot = np.ma.sqrt(dx*dx+dy*dy)
-    nmax = np.max([nr, nc])
-    npts = int(2**nextpow2(nmax))
-    dz = vertical(data, npts, 1)
-    t1 = np.ma.arctan(dz/dxtot)
-    th = np.real(np.arctanh(np.nan_to_num(dz/dxtot)+(0+0j)))
-    tdx = np.real(np.ma.arctan(dxtot/abs(dz)))
-
-    dx1 = dx*np.cos(azi)+dy*np.sin(azi)  # Standard directional derivative
-    dx2 = dx*np.cos(azi+np.pi/2)+dy*np.sin(azi+np.pi/2)
-    dxz = np.ma.sqrt(dx2*dx2+dz*dz)
-    ta = np.ma.arctan(dx1/dxz)         # Tilt directional derivative
-
-    # 2nd order Tilt angle
-
-    ts = t1
-    if s < 3:
-        s = 3
-    se = np.ones([s, s])/(s*s)
-    ts = si.convolve2d(t1, se, 'same')
-    [dxs, dys] = np.gradient(ts)
-    dzs = vertical(ts, npts, 1)
-    dxtots = np.ma.sqrt(dxs*dxs+dys*dys)
-    t2 = np.ma.arctan(dzs/dxtots)
-
-    # Standard tilt angle, hyperbolic tilt angle, 2nd order tilt angle,
-    # Tilt Based Directional Derivative, Total Derivative
-    t1 = np.ma.array(t1)
-    th = np.ma.array(th)
-    th.mask = np.ma.getmaskarray(t1)
-    t2 = np.ma.array(t2)
-    t2.mask = np.ma.getmaskarray(t1)
-    ta = np.ma.array(ta)
-    tdx = np.ma.array(tdx)
-
-    return t1, th, t2, ta, tdx
-
-
 def nextpow2(n):
     """
     Next power of 2.
@@ -745,7 +640,7 @@ def nextpow2(n):
     return m_i
 
 
-def vertical(data, npts=None, xint=1):
+def vertical(data, npts=None, xint=1, order=1):
     """
     Vertical derivative.
 
@@ -791,7 +686,7 @@ def vertical(data, npts=None, xint=1):
         for j in range(npts):
             freqy = (j+1-cy)*wn
             freq = np.sqrt(freqx*freqx+freqy*freqy)
-            fz[i, j] = f[i, j]*freq
+            fz[i, j] = f[i, j]*freq**order
     fz = np.fft.fftshift(fz)
     fzinv = np.fft.ifft2(fz)
     dz = np.real(fzinv[rdiff:nr+rdiff, cdiff:nc+cdiff])
