@@ -24,17 +24,18 @@
 # -----------------------------------------------------------------------------
 """A set of Raster Data Preparation routines."""
 
-from __future__ import print_function
-
+import math
 import os
 import copy
 from collections import Counter
-from PyQt5 import QtWidgets, QtCore, QtGui
+from PyQt5 import QtWidgets, QtCore
 import numpy as np
 from osgeo import gdal, osr, ogr
 import pandas as pd
 from PIL import Image, ImageDraw
 import scipy.ndimage as ndimage
+from scipy.signal import tukey
+import scipy.interpolate as si
 import pygmi.menu_default as menu_default
 from pygmi.raster.datatypes import Data
 
@@ -66,16 +67,14 @@ class DataCut():
         dictionary of output datasets
     """
 
-    def __init__(self, parent):
+    def __init__(self, parent=None):
         self.ifile = ''
-        self.name = 'Cut Data:'
-        self.ext = ''
         self.pbar = parent.pbar
         self.parent = parent
         self.indata = {}
         self.outdata = {}
 
-    def settings(self):
+    def settings(self, nodialog=False):
         """
         Entry point into item.
 
@@ -91,16 +90,14 @@ class DataCut():
             print('No raster data')
             return False
 
-        ext = 'Shape file (*.shp)'
+        nodialog = False
+        if not nodialog:
+            self.ifile, _ = QtWidgets.QFileDialog.getOpenFileName(
+                self.parent, 'Open Shape File', '.', 'Shape file (*.shp)')
+            if self.ifile == '':
+                return False
 
-        filename, _ = QtWidgets.QFileDialog.getOpenFileName(
-            self.parent, 'Open Shape File', '.', ext)
-        if filename == '':
-            return False
-        os.chdir(os.path.dirname(filename))
-
-        self.ifile = str(filename)
-        self.ext = filename[-3:]
+        os.chdir(os.path.dirname(self.ifile))
         data = cut_raster(data, self.ifile)
 
         if data is None:
@@ -116,213 +113,40 @@ class DataCut():
 
         return True
 
-
-class DataGrid(QtWidgets.QDialog):
-    """
-    Grid Point Data.
-
-    This class grids point data using a nearest neighbourhood technique.
-
-    Attributes
-    ----------
-    parent : parent
-        reference to the parent routine
-    indata : dictionary
-        dictionary of input datasets
-    outdata : dictionary
-        dictionary of output datasets
-    """
-
-    def __init__(self, parent=None):
-        super().__init__(parent)
-
-        self.indata = {}
-        self.outdata = {}
-        self.parent = parent
-        self.pbar = parent.pbar
-
-#        self.dsb_dxy = QtWidgets.QDoubleSpinBox()
-#        self.dsb_null = QtWidgets.QDoubleSpinBox()
-        self.dsb_dxy = QtWidgets.QLineEdit('1.0')
-        self.dsb_null = QtWidgets.QLineEdit('0.0')
-
-        self.dataid = QtWidgets.QComboBox()
-        self.label_rows = QtWidgets.QLabel('Rows: 0')
-        self.label_cols = QtWidgets.QLabel('Columns: 0')
-
-        self.setupui()
-
-    def setupui(self):
+    def loadproj(self, projdata):
         """
-        Set up UI.
+        Load project data into class.
+
+        Parameters
+        ----------
+        projdata : dictionary
+            Project data loaded from JSON project file.
 
         Returns
         -------
-        None.
+        chk : bool
+            A check to see if settings was successfully run.
 
         """
-        gridlayout_main = QtWidgets.QGridLayout(self)
-        buttonbox = QtWidgets.QDialogButtonBox()
-        helpdocs = menu_default.HelpButton('pygmi.raster.dataprep.datagrid')
-        label_band = QtWidgets.QLabel('Column to Grid:')
-        label_dxy = QtWidgets.QLabel('Cell Size:')
-        label_null = QtWidgets.QLabel('Null Value:')
+        self.ifile = projdata['shapefile']
 
-#        self.dsb_null.setMaximum(np.finfo(np.double).max)
-#        self.dsb_null.setMinimum(np.finfo(np.double).min)
+        return False
 
-        val = QtGui.QDoubleValidator(0.0000001, 9999999999.0, 9)
-#        val.setNotation(QtGui.QDoubleValidator.StandardNotation)
-        val.setNotation(QtGui.QDoubleValidator.ScientificNotation)
-        val.setLocale(QtCore.QLocale(QtCore.QLocale.C))
-
-        self.dsb_dxy.setValidator(val)
-        self.dsb_null.setValidator(val)
-
-#        self.dsb_dxy.setMaximum(9999999999.0)
-#        self.dsb_dxy.setMinimum(0.0000001)
-#        self.dsb_dxy.setDecimals(11)
-        buttonbox.setOrientation(QtCore.Qt.Horizontal)
-        buttonbox.setCenterButtons(True)
-        buttonbox.setStandardButtons(buttonbox.Cancel | buttonbox.Ok)
-
-        self.setWindowTitle('Dataset Gridding')
-
-        gridlayout_main.addWidget(label_dxy, 0, 0, 1, 1)
-        gridlayout_main.addWidget(self.dsb_dxy, 0, 1, 1, 1)
-        gridlayout_main.addWidget(self.label_rows, 1, 0, 1, 2)
-        gridlayout_main.addWidget(self.label_cols, 2, 0, 1, 2)
-        gridlayout_main.addWidget(label_band, 3, 0, 1, 1)
-        gridlayout_main.addWidget(self.dataid, 3, 1, 1, 1)
-        gridlayout_main.addWidget(label_null, 4, 0, 1, 1)
-        gridlayout_main.addWidget(self.dsb_null, 4, 1, 1, 1)
-        gridlayout_main.addWidget(helpdocs, 5, 0, 1, 1)
-        gridlayout_main.addWidget(buttonbox, 5, 1, 1, 3)
-
-        buttonbox.accepted.connect(self.accept)
-        buttonbox.rejected.connect(self.reject)
-#        self.dsb_dxy.valueChanged.connect(self.dxy_change)
-        self.dsb_dxy.textChanged.connect(self.dxy_change)
-
-    def dxy_change(self):
+    def saveproj(self):
         """
-        When dxy is changed on the interface, this update rows and columns.
+        Save project data from class.
 
         Returns
         -------
-        None.
+        projdata : dictionary
+            Project data to be saved to JSON project file.
 
         """
-        txt = str(self.dsb_dxy.text())
-        if txt.replace('.', '', 1).isdigit():
-            dxy = float(self.dsb_dxy.text())
-        else:
-            return
-        key = list(self.indata['Line'].keys())[0]
-        data = self.indata['Line'][key]
-        data = data.dropna()
+        projdata = {}
 
-        x = data.pygmiX.values
-        y = data.pygmiY.values
-#        x = data.xdata
-#        y = data.ydata
+        projdata['shapefile'] = self.ifile
 
-        cols = round(x.ptp()/dxy)
-        rows = round(y.ptp()/dxy)
-
-        self.label_rows.setText('Rows: '+str(rows))
-        self.label_cols.setText('Columns: '+str(cols))
-
-    def settings(self):
-        """
-        Entry point into item.
-
-        Returns
-        -------
-        bool
-            True if successful, False otherwise.
-
-        """
-        tmp = []
-        if 'Line' not in self.indata:
-            print('No Point Data')
-            return False
-
-        self.dataid.clear()
-
-        key = list(self.indata['Line'].keys())[0]
-        data = self.indata['Line'][key]
-        data = data.dropna()
-
-        filt = ((data.columns != 'geometry') &
-                (data.columns != 'line') &
-                (data.columns != 'pygmiX') &
-                (data.columns != 'pygmiY'))
-
-        cols = list(data.columns[filt])
-        self.dataid.addItems(cols)
-
-        x = data.pygmiX.values
-        y = data.pygmiY.values
-
-        dx = x.ptp()/np.sqrt(x.size)
-        dy = y.ptp()/np.sqrt(y.size)
-        dxy = max(dx, dy)
-        dxy = min([x.ptp(), y.ptp(), dxy])
-
-        dxy = f'{dxy:.8f}'
-        self.dsb_dxy.setText(dxy)
-        self.dxy_change()
-
-        tmp = self.exec_()
-
-        if tmp != 1:
-            return False
-
-        self.acceptall()
-
-        return True
-
-    def acceptall(self):
-        """
-        Accept option.
-
-        Updates self.outdata, which is used as input to other modules.
-
-        Returns
-        -------
-        None.
-
-        """
-        dxy = float(self.dsb_dxy.text())
-        nullvalue = float(self.dsb_null.text())
-        key = list(self.indata['Line'].keys())[0]
-        data = self.indata['Line'][key]
-        data = data.dropna()
-        newdat = []
-
-        filt = (data[self.dataid.currentText()] != nullvalue)
-        x = data.pygmiX.values[filt]
-        y = data.pygmiY.values[filt]
-        z = data[self.dataid.currentText()].values[filt]
-
-        tmp = quickgrid(x, y, z, dxy)
-        mask = np.ma.getmaskarray(tmp)
-        gdat = tmp.data
-
-# Create dataset
-        dat = Data()
-        dat.data = np.ma.masked_invalid(gdat[::-1])
-        dat.data.mask = mask[::-1]
-        dat.nullvalue = nullvalue
-        dat.dataid = self.dataid.currentText()
-        dat.xdim = dxy
-        dat.ydim = dxy
-        dat.extent = [x.min(), x.max(), y.min(), y.max()]
-        newdat.append(dat)
-
-        self.outdata['Raster'] = newdat
-        self.outdata['Line'] = self.indata['Line']
+        return projdata
 
 
 class DataMerge(QtWidgets.QDialog):
@@ -348,6 +172,7 @@ class DataMerge(QtWidgets.QDialog):
         self.indata = {}
         self.outdata = {}
         self.parent = parent
+        self.dxy = None
 
         self.dsb_dxy = QtWidgets.QDoubleSpinBox()
         self.label_rows = QtWidgets.QLabel('Rows: 0')
@@ -372,6 +197,7 @@ class DataMerge(QtWidgets.QDialog):
         self.dsb_dxy.setMaximum(9999999999.0)
         self.dsb_dxy.setMinimum(0.00001)
         self.dsb_dxy.setDecimals(5)
+        self.dsb_dxy.setValue(40.)
         buttonbox.setOrientation(QtCore.Qt.Horizontal)
         buttonbox.setCenterButtons(True)
         buttonbox.setStandardButtons(buttonbox.Cancel | buttonbox.Ok)
@@ -418,7 +244,7 @@ class DataMerge(QtWidgets.QDialog):
         self.label_rows.setText('Rows: '+str(rows))
         self.label_cols.setText('Columns: '+str(cols))
 
-    def settings(self):
+    def settings(self, nodialog=False):
         """
         Entry point into item.
 
@@ -428,21 +254,59 @@ class DataMerge(QtWidgets.QDialog):
             True if successful, False otherwise.
 
         """
-        data = self.indata['Raster'][0]
-        dxy0 = min(data.xdim, data.ydim)
-        for data in self.indata['Raster']:
-            dxy = min(dxy0, data.xdim, data.ydim)
+        if not nodialog:
+            data = self.indata['Raster'][0]
 
-        self.dsb_dxy.setValue(dxy)
-        tmp = self.exec_()
+            if self.dxy is None:
+                dxy0 = min(data.xdim, data.ydim)
+                for data in self.indata['Raster']:
+                    self.dxy = min(dxy0, data.xdim, data.ydim)
 
-        if tmp != 1:
-            return False
+            self.dsb_dxy.setValue(self.dxy)
+
+            tmp = self.exec_()
+            if tmp != 1:
+                return False
 
         self.acceptall()
 
         return True
 
+    def loadproj(self, projdata):
+        """
+        Load project data into class.
+
+        Parameters
+        ----------
+        projdata : dictionary
+            Project data loaded from JSON project file.
+
+        Returns
+        -------
+        chk : bool
+            A check to see if settings was successfully run.
+
+        """
+        self.dxy = projdata['dxy']
+
+        return False
+
+    def saveproj(self):
+        """
+        Save project data from class.
+
+        Returns
+        -------
+        projdata : dictionary
+            Project data to be saved to JSON project file.
+
+        """
+        projdata = {}
+
+        projdata['dxy'] = self.dsb_dxy.value()
+
+        return projdata
+
     def acceptall(self):
         """
         Accept option.
@@ -455,6 +319,7 @@ class DataMerge(QtWidgets.QDialog):
 
         """
         dxy = self.dsb_dxy.value()
+        self.dxy = dxy
         data = self.indata['Raster'][0]
         orig_wkt = data.wkt
 
@@ -521,6 +386,8 @@ class DataReproj(QtWidgets.QDialog):
         self.outdata = {}
         self.parent = parent
         self.pbar = self.parent.pbar
+        self.orig_wkt = None
+        self.targ_wkt = None
 
         self.groupboxb = QtWidgets.QGroupBox()
         self.combobox_inp_epsg = QtWidgets.QComboBox()
@@ -659,7 +526,7 @@ class DataReproj(QtWidgets.QDialog):
 
         self.outdata['Raster'] = dat
 
-    def settings(self):
+    def settings(self, nodialog=False):
         """
         Entry point into item.
 
@@ -669,18 +536,60 @@ class DataReproj(QtWidgets.QDialog):
             True if successful, False otherwise.
 
         """
-        self.in_proj.set_current(self.indata['Raster'][0].wkt)
-        self.out_proj.set_current(self.indata['Raster'][0].wkt)
+        if self.orig_wkt is None:
+            self.orig_wkt = self.indata['Raster'][0].wkt
+        if self.targ_wkt is None:
+            self.targ_wkt = self.indata['Raster'][0].wkt
 
-        tmp = self.exec_()
+        self.in_proj.set_current(self.orig_wkt)
+        self.out_proj.set_current(self.targ_wkt)
 
-        if tmp != 1:
-            return False
+        if not nodialog:
+            tmp = self.exec_()
+            if tmp != 1:
+                return False
 
         self.acceptall()
 
         return True
 
+    def loadproj(self, projdata):
+        """
+        Load project data into class.
+
+        Parameters
+        ----------
+        projdata : dictionary
+            Project data loaded from JSON project file.
+
+        Returns
+        -------
+        chk : bool
+            A check to see if settings was successfully run.
+
+        """
+        self.orig_wkt = projdata['orig_wkt']
+        self.targ_wkt = projdata['targ_wkt']
+
+        return False
+
+    def saveproj(self):
+        """
+        Save project data from class.
+
+        Returns
+        -------
+        projdata : dictionary
+            Project data to be saved to JSON project file.
+
+        """
+        projdata = {}
+
+        projdata['orig_wkt'] = self.in_proj.wkt
+        projdata['targ_wkt'] = self.out_proj.wkt
+
+        return projdata
+
 
 class GetProf():
     """
@@ -706,16 +615,14 @@ class GetProf():
         dictionary of output datasets
     """
 
-    def __init__(self, parent):
+    def __init__(self, parent=None):
         self.ifile = ''
-        self.name = 'Get Profile: '
-        self.ext = ''
         self.pbar = parent.pbar
         self.parent = parent
         self.indata = {}
         self.outdata = {}
 
-    def settings(self):
+    def settings(self, nodialog=False):
         """
         Entry point into item.
 
@@ -733,14 +640,14 @@ class GetProf():
 
         ext = 'Shape file (*.shp)'
 
-        filename, _ = QtWidgets.QFileDialog.getOpenFileName(
-            self.parent, 'Open Shape File', '.', ext)
-        if filename == '':
-            return False
-        os.chdir(os.path.dirname(filename))
+        nodialog = False
+        if not nodialog:
+            self.ifile, _ = QtWidgets.QFileDialog.getOpenFileName(
+                self.parent, 'Open Shape File', '.', ext)
+            if self.ifile == '':
+                return False
 
-        self.ifile = str(filename)
-        self.ext = filename[-3:]
+        os.chdir(os.path.dirname(self.ifile))
 
         shapef = ogr.Open(self.ifile)
         if shapef is None:
@@ -801,6 +708,41 @@ class GetProf():
 
         return True
 
+    def loadproj(self, projdata):
+        """
+        Load project data into class.
+
+        Parameters
+        ----------
+        projdata : dictionary
+            Project data loaded from JSON project file.
+
+        Returns
+        -------
+        chk : bool
+            A check to see if settings was successfully run.
+
+        """
+        self.ifile = projdata['shapefile']
+
+        return False
+
+    def saveproj(self):
+        """
+        Save project data from class.
+
+        Returns
+        -------
+        projdata : dictionary
+            Project data to be saved to JSON project file.
+
+        """
+        projdata = {}
+
+        projdata['shapefile'] = self.ifile
+
+        return projdata
+
 
 class GroupProj(QtWidgets.QWidget):
     """
@@ -1169,8 +1111,6 @@ class RTP(QtWidgets.QDialog):
     """
     Perform Reduction to the Pole on Magnetic data.
 
-    This class grids point data using a nearest neighbourhood technique.
-
     Attributes
     ----------
     parent : parent
@@ -1215,6 +1155,9 @@ class RTP(QtWidgets.QDialog):
         self.dsb_inc.setMinimum(-90.0)
         self.dsb_dec.setMaximum(360.0)
         self.dsb_dec.setMinimum(-360.0)
+        self.dsb_inc.setValue(-62.5)
+        self.dsb_dec.setValue(-16.75)
+
         buttonbox.setOrientation(QtCore.Qt.Horizontal)
         buttonbox.setCenterButtons(True)
         buttonbox.setStandardButtons(buttonbox.Cancel | buttonbox.Ok)
@@ -1234,7 +1177,7 @@ class RTP(QtWidgets.QDialog):
         buttonbox.accepted.connect(self.accept)
         buttonbox.rejected.connect(self.reject)
 
-    def settings(self):
+    def settings(self, nodialog=False):
         """
         Entry point into item.
 
@@ -1251,19 +1194,58 @@ class RTP(QtWidgets.QDialog):
         for i in self.indata['Raster']:
             tmp.append(i.dataid)
 
+        self.dataid.clear()
         self.dataid.addItems(tmp)
 
-        self.dsb_inc.setValue(-62.5)
-        self.dsb_dec.setValue(-16.75)
-        tmp = self.exec_()
+        if not nodialog:
+            tmp = self.exec_()
 
-        if tmp != 1:
-            return False
+            if tmp != 1:
+                return False
 
         self.acceptall()
 
         return True
 
+    def loadproj(self, projdata):
+        """
+        Load project data into class.
+
+        Parameters
+        ----------
+        projdata : dictionary
+            Project data loaded from JSON project file.
+
+        Returns
+        -------
+        chk : bool
+            A check to see if settings was successfully run.
+
+        """
+        self.dataid.setCurrentText(projdata['band'])
+        self.dsb_inc.setValue(projdata['inc'])
+        self.dsb_dec.setValue(projdata['dec'])
+
+        return False
+
+    def saveproj(self):
+        """
+        Save project data from class.
+
+        Returns
+        -------
+        projdata : dictionary
+            Project data to be saved to JSON project file.
+
+        """
+        projdata = {}
+
+        projdata['band'] = self.dataid.currentText()
+        projdata['inc'] = self.dsb_inc.value()
+        projdata['dec'] = self.dsb_dec.value()
+
+        return projdata
+
     def acceptall(self):
         """
         Accept option.
@@ -1288,6 +1270,372 @@ class RTP(QtWidgets.QDialog):
         self.outdata['Raster'] = newdat
 
 
+class Continuation(QtWidgets.QDialog):
+    """
+    Perform upward and downward contiuation on potential field data.
+
+    Attributes
+    ----------
+    parent : parent
+        reference to the parent routine
+    indata : dictionary
+        dictionary of input datasets
+    outdata : dictionary
+        dictionary of output datasets
+    """
+
+    def __init__(self, parent=None):
+        super().__init__(parent)
+
+        self.indata = {}
+        self.outdata = {}
+        self.parent = parent
+        self.pbar = self.parent.pbar
+
+        self.dataid = QtWidgets.QComboBox()
+        self.continuation = QtWidgets.QComboBox()
+        self.dsb_height = QtWidgets.QDoubleSpinBox()
+
+        self.setupui()
+
+    def setupui(self):
+        """
+        Set up UI.
+
+        Returns
+        -------
+        None.
+
+        """
+        gridlayout_main = QtWidgets.QGridLayout(self)
+        buttonbox = QtWidgets.QDialogButtonBox()
+        helpdocs = menu_default.HelpButton('pygmi.raster.dataprep.cont')
+        label_band = QtWidgets.QLabel('Band to perform continuation:')
+        label_cont = QtWidgets.QLabel('Continuation type:')
+        label_height = QtWidgets.QLabel('Continuation distance:')
+
+        self.dsb_height.setMaximum(1000000.0)
+        self.dsb_height.setMinimum(0.0)
+        self.dsb_height.setValue(0.0)
+        self.continuation.clear()
+        self.continuation.addItems(['Upward', 'Downward'])
+
+        buttonbox.setOrientation(QtCore.Qt.Horizontal)
+        buttonbox.setCenterButtons(True)
+        buttonbox.setStandardButtons(buttonbox.Cancel | buttonbox.Ok)
+
+        self.setWindowTitle('Continuation')
+
+        gridlayout_main.addWidget(label_band, 0, 0, 1, 1)
+        gridlayout_main.addWidget(self.dataid, 0, 1, 1, 1)
+
+        gridlayout_main.addWidget(label_cont, 1, 0, 1, 1)
+        gridlayout_main.addWidget(self.continuation, 1, 1, 1, 1)
+        gridlayout_main.addWidget(label_height, 2, 0, 1, 1)
+        gridlayout_main.addWidget(self.dsb_height, 2, 1, 1, 1)
+        gridlayout_main.addWidget(helpdocs, 3, 0, 1, 1)
+        gridlayout_main.addWidget(buttonbox, 3, 1, 1, 3)
+
+        buttonbox.accepted.connect(self.accept)
+        buttonbox.rejected.connect(self.reject)
+
+    def settings(self, nodialog=False):
+        """
+        Entry point into item.
+
+        Returns
+        -------
+        bool
+            True if successful, False otherwise.
+
+        """
+        tmp = []
+        if 'Raster' not in self.indata:
+            return False
+
+        for i in self.indata['Raster']:
+            tmp.append(i.dataid)
+
+        self.dataid.clear()
+        self.dataid.addItems(tmp)
+
+        if not nodialog:
+            tmp = self.exec_()
+
+            if tmp != 1:
+                return False
+
+        self.acceptall()
+
+        return True
+
+    def loadproj(self, projdata):
+        """
+        Load project data into class.
+
+        Parameters
+        ----------
+        projdata : dictionary
+            Project data loaded from JSON project file.
+
+        Returns
+        -------
+        chk : bool
+            A check to see if settings was successfully run.
+
+        """
+        self.dataid.setCurrentText(projdata['band'])
+        self.continuation.setCurrenText(projdata['ctype'])
+        self.dsb_height.setValue(projdata['height'])
+
+        return False
+
+    def saveproj(self):
+        """
+        Save project data from class.
+
+        Returns
+        -------
+        projdata : dictionary
+            Project data to be saved to JSON project file.
+
+        """
+        projdata = {}
+
+        projdata['band'] = self.dataid.currentText()
+        projdata['ctype'] = self.continuation.currentText()
+        projdata['height'] = self.dsb_height.value()
+
+        return projdata
+
+    def acceptall(self):
+        """
+        Accept option.
+
+        Updates self.outdata, which is used as input to other modules.
+
+        Returns
+        -------
+        None.
+
+        """
+        h = self.dsb_height.value()
+        ctype = self.continuation.currentText()
+
+        # Get data
+        for i in self.indata['Raster']:
+            if i.dataid == self.dataid.currentText():
+                data = i
+                break
+
+        if ctype == 'Downward':
+            dat = taylorcont(data, h)
+        else:
+            dat = fftcont(data, h)
+
+        self.outdata['Raster'] = [dat]
+
+
+def fftprep(data):
+    """
+    FFT preparation.
+
+    Parameters
+    ----------
+    data : TYPE
+        DESCRIPTION.
+    dxy : TYPE
+        DESCRIPTION.
+
+    Returns
+    -------
+    None.
+
+    """
+    datamedian = np.ma.median(data.data)
+    ndat = data.data - datamedian
+
+    nr, nc = data.data.shape
+    cdiff = nc//2
+    rdiff = nr//2
+
+    # Section to pad data
+
+    nr, nc = data.data.shape
+
+    z1 = np.zeros((nr+2*rdiff, nc+2*cdiff))-999
+    x1, y1 = np.mgrid[0: nr+2*rdiff, 0: nc+2*cdiff]
+    z1[rdiff:-rdiff, cdiff:-cdiff] = ndat.filled(-999)
+
+    z1[0] = 0
+    z1[-1] = 0
+    z1[:, 0] = 0
+    z1[:, -1] = 0
+
+    x = x1.flatten()
+    y = y1.flatten()
+    z = z1.flatten()
+
+    x = x[z != -999]
+    y = y[z != -999]
+    z = z[z != -999]
+
+    points = np.transpose([x, y])
+
+    zfin = si.griddata(points, z, (x1, y1), method='linear')
+
+    nr, nc = zfin.shape
+    zfin *= tukey(nc)
+    zfin *= tukey(nr)[:, np.newaxis]
+
+    return zfin, rdiff, cdiff, datamedian
+
+
+def fft_getkxy(fftmod, xdim, ydim):
+    """
+    Get KX and KY.
+
+    Parameters
+    ----------
+    fftmod : TYPE
+        DESCRIPTION.
+    dxy : TYPE
+        DESCRIPTION.
+
+    Returns
+    -------
+    None.
+
+    """
+    ny, nx = fftmod.shape
+    kx = np.fft.fftfreq(nx, xdim)*2*np.pi
+    ky = np.fft.fftfreq(ny, ydim)*2*np.pi
+
+    KX, KY = np.meshgrid(kx, ky)
+    KY = -KY
+    return KX, KY
+
+
+def verticalp(data, order=1):
+    """
+    Vertical derivative.
+
+    Parameters
+    ----------
+    data : numpy array
+        Input data.
+    npts : int, optional
+        Number of points. The default is None.
+    xint : float, optional
+        X interval. The default is 1.
+
+    Returns
+    -------
+    dz : numpy array
+        Output data
+
+    """
+    xdim = data.xdim
+    ydim = data.ydim
+
+    ndat, rdiff, cdiff, _ = fftprep(data)
+    fftmod = np.fft.fft2(ndat)
+
+    KX, KY = fft_getkxy(fftmod, xdim, ydim)
+
+    k = np.sqrt(KX**2+KY**2)
+    filt = k**order
+
+    zout = np.real(np.fft.ifft2(fftmod*filt))
+    zout = zout[rdiff:-rdiff, cdiff:-cdiff]
+
+    return zout
+
+
+def fftcont(data, h):
+    """
+    Continuation.
+
+    Parameters
+    ----------
+    data : PyGMI Data
+        PyGMI raster data.
+    h : float
+        Height.
+
+    Returns
+    -------
+    dat : PyGMI Data
+        PyGMI raster data.
+
+    """
+    xdim = data.xdim
+    ydim = data.ydim
+
+    ndat, rdiff, cdiff, datamedian = fftprep(data)
+    fftmod = np.fft.fft2(ndat)
+
+    ny, nx = fftmod.shape
+
+    KX, KY = fft_getkxy(fftmod, xdim, ydim)
+    k = np.sqrt(KX**2+KY**2)
+
+    filt = np.exp(-np.abs(k)*h)
+
+    zout = np.real(np.fft.ifft2(fftmod*filt))
+    zout = zout[rdiff:-rdiff, cdiff:-cdiff]
+
+    zout = zout + datamedian
+
+    zout[data.data.mask] = data.data.fill_value
+
+    dat = Data()
+    dat.data = np.ma.masked_invalid(zout)
+    dat.data.mask = np.ma.getmaskarray(data.data)
+    dat.nullvalue = data.data.fill_value
+    dat.dataid = 'Upward_'+str(h)+'_'+data.dataid
+    dat.extent = data.extent
+    dat.xdim = data.xdim
+    dat.ydim = data.ydim
+
+    return dat
+
+
+def taylorcont(data, h):
+    """
+    Continuation.
+
+    Parameters
+    ----------
+    data : PyGMI Data
+        PyGMI raster data.
+    h : float
+        Height.
+
+    Returns
+    -------
+    dat : PyGMI Data
+        PyGMI raster data.
+
+    """
+    dz = verticalp(data, order=1)
+    dz2 = verticalp(data, order=2)
+    dz3 = verticalp(data, order=3)
+    zout = (data.data + h*dz + h**2*dz2/math.factorial(2) +
+            h**3*dz3/math.factorial(3))
+
+    dat = Data()
+    dat.data = np.ma.masked_invalid(zout)
+    dat.data.mask = np.ma.getmaskarray(data.data)
+    dat.nullvalue = data.data.fill_value
+    dat.dataid = 'Downward_'+str(h)+'_'+data.dataid
+    dat.extent = data.extent
+    dat.xdim = data.xdim
+    dat.ydim = data.ydim
+
+    return dat
+
+
 def rtp(data, I_deg, D_deg):
     """
     Reduction to th epole.
@@ -1307,34 +1655,29 @@ def rtp(data, I_deg, D_deg):
         PyGMI raster data.
 
     """
-    datamedian = np.ma.median(data.data)
-    ndat = data.data - datamedian
-    ndat.data[ndat.mask] = 0
+    xdim = data.xdim
+    ydim = data.ydim
 
+    ndat, rdiff, cdiff, datamedian = fftprep(data)
     fftmod = np.fft.fft2(ndat)
 
     ny, nx = fftmod.shape
-    nyqx = 1/(2*data.xdim)
-    nyqy = 1/(2*data.ydim)
-
-    kx = np.linspace(-nyqx, nyqx, nx)
-    ky = np.linspace(-nyqy, nyqy, ny)
-
-    KX, KY = np.meshgrid(kx, ky)
+    KX, KY = fft_getkxy(fftmod, xdim, ydim)
 
     I = np.deg2rad(I_deg)
     D = np.deg2rad(D_deg)
     alpha = np.arctan2(KY, KX)
 
-    filt = 1/(np.sin(I)+1j*np.cos(I)*np.cos(D-alpha))**2
+    filt = 1/(np.sin(I)+1j*np.cos(I)*np.sin(D+alpha))**2
 
-    zrtp = np.fft.ifft2(fftmod*filt)
-    zrtp = zrtp.real + datamedian
-    zrtp[data.data.mask] = data.data.fill_value
+    zout = np.real(np.fft.ifft2(fftmod*filt))
+    zout = zout[rdiff:-rdiff, cdiff:-cdiff]
+    zout = zout + datamedian
+
+    zout[data.data.mask] = data.data.fill_value
 
-# Create dataset
     dat = Data()
-    dat.data = np.ma.masked_invalid(zrtp)
+    dat.data = np.ma.masked_invalid(zout)
     dat.data.mask = np.ma.getmaskarray(data.data)
     dat.nullvalue = data.data.fill_value
     dat.dataid = 'RTP_'+data.dataid
@@ -1401,7 +1744,7 @@ def cluster_to_raster(indata):
 
     for i in indata['Cluster']:
         indata['Raster'].append(i)
-        indata['Raster'][-1].data += 1
+        indata['Raster'][-1].data = indata['Raster'][-1].data + 1
 
     return indata
 
@@ -1720,6 +2063,7 @@ def merge(dat):
         dat = check_dataid(dat)
         return dat
 
+    print('Merging data...')
     mrg = DataMerge()
     mrg.indata['Raster'] = dat
     data = dat[0]
@@ -1794,83 +2138,97 @@ def trim_raster(olddata):
     return olddata
 
 
-def quickgrid(x, y, z, dxy, numits=4):
-    """
-    Do a quick grid.
+def testrtp():
+    """Main RTP testing routine."""
+    import matplotlib.pyplot as plt
+    from matplotlib import cm
+    from pygmi.pfmod.grvmag3d import quick_model, calc_field
+    from IPython import get_ipython
+    get_ipython().run_line_magic('matplotlib', 'inline')
 
-    Parameters
-    ----------
-    x : numpy array
-        array of x coordinates
-    y : numpy array
-        array of y coordinates
-    z : numpy array
-        array of z values - this is the column being gridded
-    dxy : float
-        cell size for the grid, in both the x and y direction.
-    numits : int
-        number of iterations. By default its 4. If this is negative, a maximum
-        numits will be calculated and used.
+# quick model
+    finc = -57
+    fdec = 50
 
-    Returns
-    -------
-    newz : numpy array
-        M x N array of z values
-    """
+    lmod = quick_model(numx=300, numy=300, numz=30, finc=finc, fdec=fdec)
+    lmod.lith_index[100:200, 100:200, 0:10] = 1
+#    lmod.lith_index[:, :, 10] = 1
+    lmod.mht = 100
+    calc_field(lmod, magcalc=True)
 
-    print('Creating Grid')
-    x = x.flatten()
-    y = y.flatten()
-    z = z.flatten()
+# Calculate the field
 
-    xmin = x.min()
-    xmax = x.max()
-    ymin = y.min()
-    ymax = y.max()
-    newmask = np.array([1])
-    j = -1
-    rows = int((ymax-ymin)/dxy)+1
-    cols = int((xmax-xmin)/dxy)+1
+    magval = lmod.griddata['Calculated Magnetics'].data
+    plt.imshow(magval, cmap=cm.jet)
+    plt.show()
 
-    if numits < 1:
-        numits = int(max(np.log2(cols), np.log2(rows)))
+    dat2 = rtp(lmod.griddata['Calculated Magnetics'], finc, fdec)
+    plt.imshow(dat2.data, cmap=cm.jet)
+    plt.show()
 
-    while np.max(newmask) > 0 and j < (numits-1):
-        j += 1
-        jj = 2**j
-        dxy2 = dxy*jj
-        rows = int((ymax-ymin)/dxy2)+1
-        cols = int((xmax-xmin)/dxy2)+1
 
-        newz = np.zeros([rows, cols])
-        zdiv = np.zeros([rows, cols])
+def testdown():
+    """Main continuation testing routine."""
+    import matplotlib.pyplot as plt
+    from pygmi.pfmod.grvmag3d import quick_model, calc_field
+    from IPython import get_ipython
+    get_ipython().run_line_magic('matplotlib', 'inline')
 
-        xindex = ((x-xmin)/dxy2).astype(int)
-        yindex = ((y-ymin)/dxy2).astype(int)
+    h = 4
+    dxy = 1
+    magcalc = True
 
-        for i in range(z.size):
-            newz[yindex[i], xindex[i]] += z[i]
-            zdiv[yindex[i], xindex[i]] += 1
+# quick model
+    lmod = quick_model(numx=100, numy=100, numz=10, dxy=dxy, d_z=1)
+    lmod.lith_index[45:55, :, 1] = 1
+    lmod.lith_index[45:50, :, 0] = 1
+    lmod.ght = 10
+    lmod.mht = 10
+    calc_field(lmod, magcalc=magcalc)
+    if magcalc:
+        z = lmod.griddata['Calculated Magnetics']
+        z.data = z.data + 5
+    else:
+        z = lmod.griddata['Calculated Gravity']
 
-        filt = zdiv > 0
-        newz[filt] = newz[filt]/zdiv[filt]
+# Calculate the field
+    lmod = quick_model(numx=100, numy=100, numz=10, dxy=dxy, d_z=1)
+    lmod.lith_index[45:55, :, 1] = 1
+    lmod.lith_index[45:50, :, 0] = 1
+    lmod.ght = 10 - h
+    lmod.mht = 10 - h
+    calc_field(lmod, magcalc=magcalc)
+    if magcalc:
+        downz0 = lmod.griddata['Calculated Magnetics']
+        downz0.data = downz0.data + 5
+    else:
+        downz0 = lmod.griddata['Calculated Gravity']
 
-        if j == 0:
-            newmask = np.ones([rows, cols])
-            for i in range(z.size):
-                newmask[yindex[i], xindex[i]] = 0
-            zfin = newz
-        else:
-            xx, yy = newmask.nonzero()
-            xx2 = xx//jj
-            yy2 = yy//jj
-            zfin[xx, yy] = newz[xx2, yy2]
-            newmask[xx, yy] = np.logical_not(zdiv[xx2, yy2])
+    downz0, z = z, downz0
+    # h = -h
 
-        print('Iteration done: '+str(j+1)+' of '+str(numits))
+    dz = verticalp(z, order=1)
+    dz2 = verticalp(z, order=2)
+    dz3 = verticalp(z, order=3)
 
-    print('Finished!')
+# normal downward
+    zdownn = fftcont(z, h)
 
-    newz = np.ma.array(zfin)
-    newz.mask = newmask
-    return newz
+# downward, taylor
+    h = -h
+    zdown = (z.data + h*dz + h**2*dz2/math.factorial(2) +
+             h**3*dz3/math.factorial(3))
+
+# Plotting
+    # plt.plot(dz3[50])
+    # plt.show()
+
+#    plt.plot(z[50], 'r-.')
+    plt.plot(downz0.data[50], 'r.')
+    plt.plot(zdown[50], 'b')
+    plt.plot(zdownn[50], 'k')
+    plt.show()
+
+
+if __name__ == "__main__":
+    testdown()
