@@ -80,37 +80,31 @@ class Data():
     ----------
     data : numpy masked array
         array to contain raster data
-    tlx : float
-        Top Left X coordinate of raster grid
-    tly : float
-        Top Left Y coordinate of raster grid
+    extent : tuple
+        Extent of data as (left, right, bottom, top)
     xdim : float
         x-dimension of grid cell
     ydim : float
         y-dimension of grid cell
-    nrofbands : int
-        number of raster bands
     dataid : str
         band name or id
-    rows : int
-        number of rows for each raster grid/band
-    cols : int
-        number of columns for each raster grid/band
     nullvalue : float
         grid null or nodata value
-    norm : dictionary
-        normalized data
-    gtr : tuple
-        projection information
     wkt : str
         projection information
     units : str
         description of units to be used with color bars
+    isrgb : bool
+        Flag to signify an RGB image.
+    metadata : dictionary
+        Miscellaneous metadata for file.
+    filename : str
+        Filename of file.
     """
 
     def __init__(self):
         self.data = np.ma.array([])
-        self.extent = (0, 1, -1, 0)  # left, right, bottom, top
+        self.extent = (0, 1, -1, 0)
         self.xdim = 1.0
         self.ydim = 1.0
         self.dataid = ''
@@ -119,6 +113,7 @@ class Data():
         self.units = ''
         self.isrgb = False
         self.metadata = {'Cluster': {}}
+        self.filename = ''
 
     def get_gtr(self):
         """
