@@ -61,7 +61,7 @@ class EquationEditor(QtWidgets.QDialog):
         self.indata = {}
         self.outdata = {}
         self.parent = parent
-        self.equation = ''
+        self.equation = None
         self.bands = {}
 
         self.combobox = QtWidgets.QComboBox()
@@ -72,10 +72,6 @@ class EquationEditor(QtWidgets.QDialog):
 
         self.setupui()
 
-#    def textchanged(self):
-#        """ Text Changed """
-#        self.equation = self.textbrowser.toPlainText()
-
     def setupui(self):
         """
         Set up UI.
@@ -110,16 +106,20 @@ class EquationEditor(QtWidgets.QDialog):
                'band is assigned to each variable.</p>'
                '<h2>Examples</h2>'
                '<p>Sum:</p>'
-               '<p>    i1 + 1000</p>'
+               '<pre>    i1 + 1000</pre>'
+               '<p>Mosaic two bands into one:</p>'
+               '<pre>    mosaic(i0, i1)</pre>'
                '<p>Threshold between values 1 and 98, substituting -999 as a '
                'value:</p>'
-               '<p>    where((i1 &gt; 1) &amp; (i1 &lt; 98) , i1, -999)</p>'
+               '<pre>    where((i1 &gt; 1) &amp; (i1 &lt; 98) , i1, -999)'
+               '</pre>'
                '<p>Replacing the value 0 with a nodata or null value:</p>'
-               '<p>    where(iall!=0, iall, nodata)</p>'
+               '<pre>    where(iall!=0, iall, nodata)</pre>'
                '<h2>Commands</h2>'
                '<ul>'
                ' <li> Logical operators: &amp;, |, ~</li>'
-               ' <li> Comparison operators: &lt;, &lt;=, ==, !=, &gt;=, &gt;</li>'
+               ' <li> Comparison operators: &lt;, &lt;=, ==, !=, &gt;=, &gt;'
+               '</li>'
                ' <li> Arithmetic operators: +, -, *, /, **, %, <<, >></li>'
                ' <li> where(bool, number1, number2) : number1 if the bool '
                'condition is true, number2 otherwise.</li>'
@@ -155,7 +155,7 @@ class EquationEditor(QtWidgets.QDialog):
         if txt != '':
             self.label.setText(': '+self.bands[txt])
 
-    def eq_fix(self, indata, equation):
+    def eq_fix(self, indata):
         """
         Corrects names in equation to variable names.
 
@@ -163,8 +163,6 @@ class EquationEditor(QtWidgets.QDialog):
         ----------
         indata : PyGMI Data
             PyGMI raster dataset.
-        equation : str
-            Equation written as a string.
 
         Returns
         -------
@@ -172,14 +170,72 @@ class EquationEditor(QtWidgets.QDialog):
             Corrected equation.
 
         """
-        neweq = str(equation)
+        neweq = str(self.equation)
         neweq = neweq.replace('ln', 'log')
         neweq = neweq.replace('^', '**')
         neweq = neweq.replace('nodata', str(indata[0].nullvalue))
 
         return neweq
 
-    def settings(self, equation=None):
+    def mosaic(self, eq, localdict):
+        """
+        Mosaics data into a single band dataset.
+
+        Parameters
+        ----------
+        eq : str
+            Equation with mosaic command.
+        localdict : dictionary
+            Dictionary of data.
+
+        Returns
+        -------
+        findat : numpy array
+            Mosaiced array.
+
+        """
+        idx = eq.index('mosaic(')+7
+        eq2 = eq[idx:]
+        idx = eq2.index(')')
+        eq2 = eq2[:idx]
+        eq2 = eq2.replace(' ', '')
+        eq3 = eq2.split(',')
+
+        localdict_list = list(localdict.keys())
+
+        # Check for problems
+        if 'iall' in eq:
+            return None
+
+        if len(eq3) < 2:
+            return None
+
+        eq4 = []
+        mask = []
+        for i in eq3:
+            usedbands = []
+            for j in localdict_list:
+                if j in i:
+                    usedbands.append(j)
+            mask1 = None
+            for j in usedbands:
+                if mask1 is None:
+                    mask1 = localdict[j].mask
+                else:
+                    mask1 = np.logical_or(mask1, localdict[j].mask)
+
+            mask.append(mask1)
+            try:
+                eq4.append(ne.evaluate(i, localdict))
+            except Exception:
+                return None
+            eq4[-1] = np.ma.array(eq4[-1], mask=mask[-1])
+
+        master = np.ma.mean(eq4, 0)
+
+        return master
+
+    def settings(self, nodialog=False):
         """
         Entry point into item.
 
@@ -221,23 +277,23 @@ class EquationEditor(QtWidgets.QDialog):
         localdict_list = list(localdict.keys())
         localdict['iall'] = np.ma.array(bandsall)
 
-        if equation is None:
+        if not nodialog:
             temp = self.exec_()
 
             if temp == 0:
                 return False
 
-            equation = self.textbrowser.toPlainText()
+            self.equation = self.textbrowser.toPlainText()
 
-        if equation == '':
+        if self.equation == '':
             return False
 
-        if 'iall' in equation:
+        if 'iall' in self.equation:
             usedbands = localdict_list
         else:
             usedbands = []
             for i in localdict_list:
-                if i in equation:
+                if i in self.equation:
                     usedbands.append(i)
 
         mask = None
@@ -247,16 +303,29 @@ class EquationEditor(QtWidgets.QDialog):
             else:
                 mask = np.logical_or(mask, localdict[i].mask)
 
-        neweq = self.eq_fix(indata, equation)
+        neweq = self.eq_fix(indata)
 
-        try:
-            findat = ne.evaluate(neweq, localdict)
-        except Exception:
-            QtWidgets.QMessageBox.warning(
-                self.parent, 'Error',
-                ' Nothing processed! Your equation most likely had an error.',
-                QtWidgets.QMessageBox.Ok)
-            return False
+        if 'mosaic' in neweq:
+            findat = self.mosaic(neweq, localdict)
+            if findat is None:
+                QtWidgets.QMessageBox.warning(
+                    self.parent, 'Error',
+                    'Nothing processed! '
+                    'Your equation most likely had an error.',
+                    QtWidgets.QMessageBox.Ok)
+                return False
+            mask = findat.mask
+
+        else:
+            try:
+                findat = ne.evaluate(neweq, localdict)
+            except Exception:
+                QtWidgets.QMessageBox.warning(
+                    self.parent, 'Error',
+                    'Nothing processed! '
+                    'Your equation most likely had an error.',
+                    QtWidgets.QMessageBox.Ok)
+                return False
 
         outdata = []
 
@@ -284,12 +353,48 @@ class EquationEditor(QtWidgets.QDialog):
             outdatai.data = np.ma.fix_invalid(outdatai.data)
 
         if len(outdata) == 1:
-            outdata[0].dataid = equation
+            outdata[0].dataid = self.equation
 
         self.outdata[intype] = outdata
 
         return True
 
+    def loadproj(self, projdata):
+        """
+        Load project data into class.
+
+        Parameters
+        ----------
+        projdata : dictionary
+            Project data loaded from JSON project file.
+
+        Returns
+        -------
+        chk : bool
+            A check to see if settings was successfully run.
+
+        """
+        self.equation = projdata['equation']
+        self.textbrowser.setText(self.equation)
+
+        return False
+
+    def saveproj(self):
+        """
+        Save project data from class.
+
+        Returns
+        -------
+        projdata : dictionary
+            Project data to be saved to JSON project file.
+
+        """
+        projdata = {}
+
+        projdata['equation'] = self.equation
+
+        return projdata
+
 
 def hmode(data):
     """
