@@ -237,12 +237,18 @@ class ModestImage(mi.AxesImage):
             pseudo = self._full_res[(rows-y1):(rows-y0):sy, x0:x1:sx]
             mask = np.ma.getmaskarray(pseudo)
 
+            if self.htype == '90% Linear, 10% Compact':
+                pseudo = histcomp(pseudo, perc=10.)
+
             if self.htype == '95% Linear, 5% Compact':
                 pseudo = histcomp(pseudo)
 
             if self.htype == '98% Linear, 2% Compact':
                 pseudo = histcomp(pseudo, perc=2.)
 
+            if self.htype == '99% Linear, 1% Compact':
+                pseudo = histcomp(pseudo, perc=1.)
+
             if self.htype == 'Histogram Equalization':
                 pseudo = histeq(pseudo)
 
@@ -266,6 +272,12 @@ class ModestImage(mi.AxesImage):
             if self.htype == '98% Linear, 2% Compact':
                 pseudo = histcomp(pseudo, perc=2.)
 
+            if self.htype == '99% Linear, 1% Compact':
+                pseudo = histcomp(pseudo, perc=1.)
+
+            if self.htype == '90% Linear, 10% Compact':
+                pseudo = histcomp(pseudo, perc=10.)
+
             if self.htype == 'Histogram Equalization':
                 pseudo = histeq(pseudo)
 
@@ -275,6 +287,12 @@ class ModestImage(mi.AxesImage):
             if self.hstype == '98% Linear, 2% Compact':
                 sun = histcomp(sun, perc=2.)
 
+            if self.hstype == '99% Linear, 1% Compact':
+                sun = histcomp(sun, perc=1.)
+
+            if self.hstype == '90% Linear, 10% Compact':
+                sun = histcomp(sun, perc=10.)
+
             if self.hstype == 'Histogram Equalization':
                 sun = histeq(sun)
 
@@ -314,6 +332,16 @@ class ModestImage(mi.AxesImage):
                 green = histcomp(green, perc=2.)
                 blue = histcomp(blue, perc=2.)
 
+            if self.htype == '99% Linear, 1% Compact':
+                red = histcomp(red, perc=1.)
+                green = histcomp(green, perc=1.)
+                blue = histcomp(blue, perc=1.)
+
+            if self.htype == '90% Linear, 10% Compact':
+                red = histcomp(red, perc=10.)
+                green = histcomp(green, perc=10.)
+                blue = histcomp(blue, perc=10.)
+
             if self.htype == 'Histogram Equalization':
                 red = histeq(red)
                 green = histeq(green)
@@ -429,7 +457,7 @@ def imshow(axes, X, cmap=None, norm=None, aspect=None,
 
     Returns
     -------
-    im : ModestImage
+    im : pygmi.raster.ginterp.ModestImage
         ModestImage output.
 
     """
@@ -529,7 +557,7 @@ class MyMplCanvas(FigureCanvas):
         k value for cmyk mode
     """
 
-    def __init__(self, parent):
+    def __init__(self, parent=None):
         fig = Figure()
         super().__init__(fig)
 
@@ -1067,7 +1095,8 @@ class MySunCanvas(FigureCanvas):
     axes: matplotlib axes instance
         axes on which the sun is drawn
     """
-    def __init__(self, parent):
+
+    def __init__(self, parent=None):
         fig = Figure()
         super().__init__(fig)
 
@@ -1121,6 +1150,7 @@ class PlotInterp(QtWidgets.QDialog):
     self.msc : pygmi.raster.ginterp.MySunCanvas, FigureCanvas
         small canvas containing the sunshading control
     """
+
     def __init__(self, parent=None):
         super().__init__(parent)
 
@@ -1218,12 +1248,16 @@ class PlotInterp(QtWidgets.QDialog):
         self.cbox_dtype.addItems(['Single Color Map', 'Contour', 'RGB Ternary',
                                   'CMY Ternary', 'Sunshade'])
         self.cbox_htype.addItems(['Linear',
+                                  '90% Linear, 10% Compact',
                                   '95% Linear, 5% Compact',
                                   '98% Linear, 2% Compact',
+                                  '99% Linear, 1% Compact',
                                   'Histogram Equalization'])
         self.cbox_hstype.addItems(['Linear',
+                                   '90% Linear, 10% Compact',
                                    '95% Linear, 5% Compact',
                                    '98% Linear, 2% Compact',
+                                   '99% Linear, 1% Compact',
                                    'Histogram Equalization'])
 
         self.setWindowTitle('Raster Data Interpretation')
@@ -1610,6 +1644,12 @@ class PlotInterp(QtWidgets.QDialog):
             if htype == '98% Linear, 2% Compact':
                 pseudo = histcomp(pseudo, perc=2.)
 
+            if htype == '99% Linear, 1% Compact':
+                pseudo = histcomp(pseudo, perc=1.)
+
+            if htype == '90% Linear, 10% Compact':
+                pseudo = histcomp(pseudo, perc=10.)
+
             if htype == 'Histogram Equalization':
                 pseudo = histeq(pseudo)
 
@@ -1625,21 +1665,33 @@ class PlotInterp(QtWidgets.QDialog):
             pseudo = self.mmc.image._full_res[0]
             sun = self.mmc.image._full_res[1]
 
+            if htype == '90% Linear, 10% Compact':
+                pseudo = histcomp(pseudo, perc=10.)
+
             if htype == '95% Linear, 5% Compact':
                 pseudo = histcomp(pseudo)
 
             if htype == '98% Linear, 2% Compact':
                 pseudo = histcomp(pseudo, perc=2.)
 
+            if htype == '99% Linear, 1% Compact':
+                pseudo = histcomp(pseudo, perc=1.)
+
             if htype == 'Histogram Equalization':
                 pseudo = histeq(pseudo)
 
+            if hstype == '90% Linear, 10% Compact':
+                sun = histcomp(sun, perc=10.)
+
             if hstype == '95% Linear, 5% Compact':
                 sun = histcomp(sun)
 
             if hstype == '98% Linear, 2% Compact':
                 sun = histcomp(pseudo, perc=2.)
 
+            if hstype == '99% Linear, 1% Compact':
+                sun = histcomp(pseudo, perc=1.)
+
             if hstype == 'Histogram Equalization':
                 sun = histeq(sun)
 
@@ -1676,6 +1728,16 @@ class PlotInterp(QtWidgets.QDialog):
                 green = histcomp(green, perc=2.)
                 blue = histcomp(blue, perc=2.)
 
+            if htype == '99% Linear, 1% Compact':
+                red = histcomp(red, perc=1.)
+                green = histcomp(green, perc=1.)
+                blue = histcomp(blue, perc=1.)
+
+            if htype == '90% Linear, 10% Compact':
+                red = histcomp(red, perc=10.)
+                green = histcomp(green, perc=10.)
+                blue = histcomp(blue, perc=10.)
+
             if htype == 'Histogram Equalization':
                 red = histeq(red)
                 green = histeq(green)
@@ -1713,6 +1775,12 @@ class PlotInterp(QtWidgets.QDialog):
             if htype == '98% Linear, 2% Compact':
                 pseudo = histcomp(pseudo, perc=2.)
 
+            if htype == '99% Linear, 1% Compact':
+                pseudo = histcomp(pseudo, perc=1.)
+
+            if htype == '90% Linear, 10% Compact':
+                pseudo = histcomp(pseudo, perc=10.)
+
             if htype == 'Histogram Equalization':
                 pseudo = histeq(pseudo)
 
@@ -1749,7 +1817,7 @@ class PlotInterp(QtWidgets.QDialog):
 
             mask = img[:, :, 3]
 
-        export = iodefs.ExportData(self.parent)
+        # export = iodefs.ExportData(self.parent)
 
         os.chdir(os.path.dirname(filename))
 
@@ -1777,32 +1845,7 @@ class PlotInterp(QtWidgets.QDialog):
         newimg[2].nullvalue = 0
         newimg[3].nullvalue = 0
 
-#        imgshape0 = img.shape[0]
-#        imgshape1 = img.shape[1]
-#
-#        newimg[0].xdim = (newimg[0].xdim*newimg[0].cols)/imgshape1
-#        newimg[1].xdim = (newimg[1].xdim*newimg[1].cols)/imgshape1
-#        newimg[2].xdim = (newimg[2].xdim*newimg[2].cols)/imgshape1
-#        newimg[3].xdim = (newimg[3].xdim*newimg[3].cols)/imgshape1
-#
-#        newimg[0].ydim = (newimg[0].ydim*newimg[0].rows)/imgshape0
-#        newimg[1].ydim = (newimg[1].ydim*newimg[1].rows)/imgshape0
-#        newimg[2].ydim = (newimg[2].ydim*newimg[2].rows)/imgshape0
-#        newimg[3].ydim = (newimg[3].ydim*newimg[3].rows)/imgshape0
-#
-#        newimg[0].cols = imgshape1
-#        newimg[1].cols = imgshape1
-#        newimg[2].cols = imgshape1
-#        newimg[3].cols = imgshape1
-#
-#        newimg[0].rows = imgshape0
-#        newimg[1].rows = imgshape0
-#        newimg[2].rows = imgshape0
-#        newimg[3].rows = imgshape0
-
-        export.ifile = str(filename)
-        export.ext = filename[-3:]
-        export.export_gdal(newimg, 'GTiff')
+        iodefs.export_gdal(str(filename), newimg, 'GTiff')
 
 # Section for colorbars
         if 'Ternary' not in dtype:
@@ -1907,7 +1950,7 @@ class PlotInterp(QtWidgets.QDialog):
                                           'Save to GeoTiff is complete!',
                                           QtWidgets.QMessageBox.Ok)
 
-    def settings(self):
+    def settings(self, nodialog=False):
         """
         Settings.
 
@@ -1921,6 +1964,9 @@ class PlotInterp(QtWidgets.QDialog):
 
         """
 
+        if nodialog:
+            return True
+
         if 'Raster' not in self.indata:
             return False
         if self.indata['Raster'][0].isrgb:
@@ -1934,6 +1980,41 @@ class PlotInterp(QtWidgets.QDialog):
         self.msc.init_graph()
         return True
 
+    def loadproj(self, projdata):
+        """
+        Loads project data into class.
+
+        Parameters
+        ----------
+        projdata : dictionary
+            Project data loaded from JSON project file.
+
+        Returns
+        -------
+        chk : bool
+            A check to see if settings was successfully run.
+
+        """
+
+        return False
+
+    def saveproj(self):
+        """
+        Save project data from class.
+
+
+        Returns
+        -------
+        projdata : dictionary
+            Project data to be saved to JSON project file.
+
+        """
+        projdata = {}
+
+#        projdata['ftype'] = '2D Mean'
+
+        return projdata
+
 
 def aspect2(data):
     """
