@@ -36,13 +36,13 @@ menu. The following are supported:
 
 import numpy as np
 from PyQt5 import QtWidgets, QtCore
-import matplotlib.cm as cm
+from matplotlib import cm
 from matplotlib.backends.backend_qt5agg import FigureCanvas
 from matplotlib.figure import Figure
 from matplotlib.backends.backend_qt5agg import NavigationToolbar2QT
 import matplotlib.colors as mcolors
-from matplotlib.ticker import MaxNLocator
-from mpl_toolkits.mplot3d import axes3d
+from pygmi.raster.modest_image import imshow
+from pygmi.misc import frm
 
 
 class MyMplCanvas(FigureCanvas):
@@ -55,6 +55,7 @@ class MyMplCanvas(FigureCanvas):
     parent : parent
         reference to the parent routine
     """
+
     def __init__(self, parent=None):
         fig = Figure()
         self.axes = fig.add_subplot(111)
@@ -62,7 +63,7 @@ class MyMplCanvas(FigureCanvas):
 
     def update_pcolor(self, data1, dmat):
         """
-        Update the correlation coefficient plot
+        Update the correlation coefficient plot.
 
         Parameters
         ----------
@@ -114,53 +115,19 @@ class MyMplCanvas(FigureCanvas):
         """
         self.figure.clear()
         self.axes = self.figure.add_subplot(111)
-        self.axes.tick_params(axis='x', rotation=90)
-        self.axes.tick_params(axis='y', rotation=0)
-        self.axes.ticklabel_format(style='plain')
 
-        extent = data1.extent
+        rdata = imshow(self.axes, data1.data, extent=data1.extent, cmap=cm.jet,
+                       interpolation='nearest')
 
-        carray = data1.data.compressed()
-        ichk = np.array_equal(carray, carray.astype(int))
-
-        rdata = self.axes.imshow(data1.data, extent=extent, cmap=cm.jet,
-                                 interpolation='nearest')
-
-        if ichk and not data1.isrgb:
-            vals = np.unique(data1.data)
-            vals = vals.compressed()
-            bnds = (vals - 0.5).tolist() + [vals.max() + .5]
-            cbar = self.axes.figure.colorbar(rdata, boundaries=bnds,)
-#                                             values=vals, ticks=vals)
-            cbar.set_label(data1.units)
-        elif not data1.isrgb:
-            cbar = self.figure.colorbar(rdata)
+        if not data1.isrgb:
+            cbar = self.figure.colorbar(rdata, format=frm)
             cbar.set_label(data1.units)
 
         self.axes.set_xlabel('Eastings')
         self.axes.set_ylabel('Northings')
 
-        self.figure.tight_layout()
-        self.figure.canvas.draw()
-
-    def update_rgb(self, data1):
-        """
-        Update the RGB plot.
-
-        Parameters
-        ----------
-        data1 : PyGMI raster Data
-            raster dataset to be used
-
-        Returns
-        -------
-        None.
-
-        """
-        self.figure.clear()
-        self.axes = self.figure.add_subplot(111)
-
-        self.axes.imshow(data1.data)
+        self.axes.xaxis.set_major_formatter(frm)
+        self.axes.yaxis.set_major_formatter(frm)
 
         self.figure.tight_layout()
         self.figure.canvas.draw()
@@ -200,9 +167,12 @@ class MyMplCanvas(FigureCanvas):
         hbin = self.axes.hexbin(x, y, bins='log')
         self.axes.axis([xmin, xmax, ymin, ymax])
         self.axes.set_title('Hexbin Plot')
-        cbar = self.figure.colorbar(hbin)
+        cbar = self.figure.colorbar(hbin, format=frm)
         cbar.set_label('log10(N)')
 
+        self.axes.xaxis.set_major_formatter(frm)
+        self.axes.yaxis.set_major_formatter(frm)
+
         self.figure.tight_layout()
         self.figure.canvas.draw()
 
@@ -220,7 +190,6 @@ class MyMplCanvas(FigureCanvas):
         None.
 
         """
-
         rows, cols = data.data.shape
 
         dtlx = data.extent[0]
@@ -245,18 +214,21 @@ class MyMplCanvas(FigureCanvas):
 
         self.figure.clear()
         self.axes = self.figure.add_subplot(111, projection='3d')
-        ax1 = self.axes
 
-        surf = ax1.plot_surface(x, y, z, cmap=cmap, linewidth=0.1, norm=norml,
-                                vmin=z.min(), vmax=z.max(), shade=False,
-                                antialiased=False)
+        surf = self.axes.plot_surface(x, y, z, cmap=cmap, linewidth=0.1,
+                                      norm=norml, vmin=z.min(), vmax=z.max(),
+                                      shade=False, antialiased=False)
 
-        self.figure.colorbar(surf)
+        self.figure.colorbar(surf, format=frm)
 
-        ax1.set_title('')
-        ax1.set_xlabel('X')
-        ax1.set_ylabel('Y')
-        ax1.set_zlabel('Z')
+        self.axes.xaxis.set_major_formatter(frm)
+        self.axes.yaxis.set_major_formatter(frm)
+        self.axes.zaxis.set_major_formatter(frm)
+
+        self.axes.set_title('')
+        self.axes.set_xlabel('X')
+        self.axes.set_ylabel('Y')
+        self.axes.set_zlabel('Z')
 
         self.figure.canvas.draw()
 
@@ -283,6 +255,9 @@ class MyMplCanvas(FigureCanvas):
         self.axes.set_xlabel('Data Value', fontsize=8)
         self.axes.set_ylabel('Counts', fontsize=8)
 
+        self.axes.xaxis.set_major_formatter(frm)
+        self.axes.yaxis.set_major_formatter(frm)
+
         self.figure.tight_layout()
         self.figure.canvas.draw()
 
@@ -296,7 +271,8 @@ class GraphWindow(QtWidgets.QDialog):
     parent : parent
         reference to the parent routine
     """
-    def __init__(self, parent):
+
+    def __init__(self, parent=None):
         super().__init__(parent)
         self.parent = parent
 
@@ -339,7 +315,7 @@ class GraphWindow(QtWidgets.QDialog):
 
 class PlotCCoef(GraphWindow):
     """
-    Plot 2D Correlation Coeffiecients
+    Plot 2D Correlation Coeffiecients.
 
     Attributes
     ----------
@@ -356,7 +332,8 @@ class PlotCCoef(GraphWindow):
     indata : dictionary
         dictionary of input datasets
     """
-    def __init__(self, parent):
+
+    def __init__(self, parent=None):
         super().__init__(parent)
         self.label1.hide()
         self.combobox1.hide()
@@ -404,7 +381,7 @@ class PlotCCoef(GraphWindow):
 
 def check_bands(data):
     """
-    Checks that band sizes are the same.
+    Check that band sizes are the same.
 
     Parameters
     ----------
@@ -443,7 +420,6 @@ def corr2d(dat1, dat2):
     out : numpy array
         array of correlation coefficients
     """
-
     out = None
     if dat1.shape == dat2.shape:
         # These line are to avoid warnings due to powers of large fill values
@@ -477,7 +453,8 @@ class PlotRaster(GraphWindow):
     indata : dictionary
         dictionary of input datasets
     """
-    def __init__(self, parent):
+
+    def __init__(self, parent=None):
         super().__init__(parent)
         self.label2.hide()
         self.combobox2.hide()
@@ -497,9 +474,6 @@ class PlotRaster(GraphWindow):
         if 'Raster' in self.indata:
             data = self.indata['Raster']
             self.mmc.update_raster(data[i])
-        elif 'ProfPic' in self.indata:
-            data = self.indata['ProfPic']
-            self.mmc.update_rgb(data[i])
 
     def run(self):
         """
@@ -515,12 +489,10 @@ class PlotRaster(GraphWindow):
             data = self.indata['Raster']
         elif 'Cluster' in self.indata:
             data = self.indata['Cluster']
-        elif 'ProfPic' in self.indata:
-            data = self.indata['ProfPic']
 
         for i in data:
             self.combobox1.addItem(i.dataid)
-        self.change_band()
+#        self.change_band()
 
 
 class PlotSurface(GraphWindow):
@@ -538,7 +510,8 @@ class PlotSurface(GraphWindow):
     indata : dictionary
         dictionary of input datasets
     """
-    def __init__(self, parent):
+
+    def __init__(self, parent=None):
         super().__init__(parent)
         self.label2.hide()
         self.combobox2.hide()
@@ -588,7 +561,8 @@ class PlotScatter(GraphWindow):
     indata : dictionary
         dictionary of input datasets
     """
-    def __init__(self, parent):
+
+    def __init__(self, parent=None):
         super().__init__(parent)
 
         self.indata = {}
@@ -617,7 +591,6 @@ class PlotScatter(GraphWindow):
                                           QtWidgets.QMessageBox.Ok)
             return
 
-
         self.mmc.update_hexbin(x, y)
 
     def run(self):
@@ -643,7 +616,7 @@ class PlotScatter(GraphWindow):
 
 class PlotHist(GraphWindow):
     """
-    Plot Hist Class
+    Plot Hist Class.
 
     Attributes
     ----------
@@ -656,7 +629,8 @@ class PlotHist(GraphWindow):
     indata : dictionary
         dictionary of input datasets
     """
-    def __init__(self, parent):
+
+    def __init__(self, parent=None):
         super().__init__(parent)
         self.label2.hide()
         self.combobox2.hide()
