@@ -33,20 +33,20 @@ from osgeo import gdal, osr, ogr
 from shapely.geometry.polygon import Polygon
 import matplotlib.pyplot as plt
 from matplotlib.figure import Figure
-import matplotlib.animation as manimation
 from matplotlib.backends.backend_qt5agg import FigureCanvasQTAgg as \
     FigureCanvas
 from matplotlib.backends.backend_qt5agg import NavigationToolbar2QT as \
     NavigationToolbar
-import pygmi.menu_default as menu_default
+# import pygmi.menu_default as menu_default
 from pygmi.raster.datatypes import Data
+from pygmi.misc import frm
 
 
 class CreateSceneList(QtWidgets.QDialog):
     """
-    Import Line Data.
+    Create Scene List.
 
-    This class imports ASCII point data.
+    This class creates a list of scenes for use in change detection.
 
     Attributes
     ----------
@@ -62,15 +62,17 @@ class CreateSceneList(QtWidgets.QDialog):
         input file name. Used in main.py
     """
 
-    def __init__(self, parent):
+    def __init__(self, parent=None):
         super().__init__(parent)
 
-        self.name = 'Create Scene List: '
         self.parent = parent
         self.indata = {'tmp': True}
         self.outdata = {}
         self.ifile = ''
-        self.piter = self.parent.pbar.iter
+        if parent is not None:
+            self.piter = self.parent.pbar.iter
+        else:
+            self.piter = iter
 
         self.shapefile = QtWidgets.QLineEdit('')
         self.scenefile = QtWidgets.QLineEdit('')
@@ -89,7 +91,7 @@ class CreateSceneList(QtWidgets.QDialog):
         """
         gridlayout_main = QtWidgets.QGridLayout(self)
         buttonbox = QtWidgets.QDialogButtonBox()
-        helpdocs = menu_default.HelpButton('pygmi.grav.iodefs.importpointdata')
+        # helpdocs = menu_default.HelpButton('pygmi.grav.iodefs.importpointdata')
         pb_shape = QtWidgets.QPushButton('Load Shapefile')
         pb_scene = QtWidgets.QPushButton('Set Scene Directory')
 
@@ -115,7 +117,7 @@ class CreateSceneList(QtWidgets.QDialog):
         pb_shape.pressed.connect(self.get_shape)
         pb_scene.pressed.connect(self.get_scene)
 
-    def settings(self, test=False):
+    def settings(self, nodialog=False):
         """
         Entry point into item.
 
@@ -126,7 +128,7 @@ class CreateSceneList(QtWidgets.QDialog):
 
         """
 
-        if not test:
+        if not nodialog:
             tmp = self.exec_()
 
             if tmp != 1:
@@ -148,8 +150,6 @@ class CreateSceneList(QtWidgets.QDialog):
         subfiles = list(subfiles)
         dtime = []
         flist = []
-
-        print('Loading in information...')
         nodates = False
         for ifile in self.piter(subfiles):
             dataset = gdal.Open(str(ifile), gdal.GA_ReadOnly)
@@ -162,8 +162,8 @@ class CreateSceneList(QtWidgets.QDialog):
 
             coords = [[dxlim[0], dylim[0]],
                       [dxlim[0], dylim[1]],
-                      [dxlim[1], dylim[0]],
                       [dxlim[1], dylim[1]],
+                      [dxlim[1], dylim[0]],
                       [dxlim[0], dylim[0]]]
 
             coords2 = Polygon(coords)
@@ -210,6 +210,47 @@ class CreateSceneList(QtWidgets.QDialog):
 
         return True
 
+    def loadproj(self, projdata):
+        """
+        Load project data into class.
+
+        Parameters
+        ----------
+        projdata : dictionary
+            Project data loaded from JSON project file.
+
+        Returns
+        -------
+        chk : bool
+            A check to see if settings was successfully run.
+
+        """
+        self.shapefile.setText(projdata['shapefile'])
+        self.scenefile.setText(projdata['scenefile'])
+        self.isrecursive.setChecked(projdata['recursive'])
+
+        chk = self.settings(True)
+
+        return chk
+
+    def saveproj(self):
+        """
+        Save project data from class.
+
+        Returns
+        -------
+        projdata : dictionary
+            Project data to be saved to JSON project file.
+
+        """
+        projdata = {}
+
+        projdata['shapefile'] = self.shapefile.text()
+        projdata['scenefile'] = self.scenefile.text()
+        projdata['recursive'] = self.isrecursive.isChecked()
+
+        return projdata
+
     def get_shape(self, filename=''):
         """
         Get shape filename.
@@ -260,7 +301,7 @@ class CreateSceneList(QtWidgets.QDialog):
 
 class LoadSceneList():
     """
-    Load scene list
+    Load scene list.
 
     Attributes
     ----------
@@ -280,14 +321,12 @@ class LoadSceneList():
 
     def __init__(self, parent=None):
         self.ifile = ''
-        self.name = 'Import Scene List Data: '
-        self.ext = ''
         self.pbar = None
         self.parent = parent
         self.indata = {}
         self.outdata = {}
 
-    def settings(self):
+    def settings(self, nodialog=False):
         """
         Entry point into item.
 
@@ -297,21 +336,60 @@ class LoadSceneList():
             True if successful, False otherwise.
 
         """
-        ext = 'Scene List File (*.xlsx)'
+        if not nodialog:
+            ext = 'Scene List File (*.xlsx)'
 
-        filename, _ = QtWidgets.QFileDialog.getOpenFileName(
-            self.parent, 'Open Scene List Spreadsheet', '.', ext)
-        if filename == '':
-            return False
+            self.ifile, _ = QtWidgets.QFileDialog.getOpenFileName(
+                self.parent, 'Open Scene List Spreadsheet', '.', ext)
+            if self.ifile == '':
+                return False
 
-        df = pd.read_excel(filename)
+        df = pd.read_excel(self.ifile)
 
         self.outdata['SceneList'] = df
         return True
 
+    def loadproj(self, projdata):
+        """
+        Load project data into class.
+
+        Parameters
+        ----------
+        projdata : dictionary
+            Project data loaded from JSON project file.
+
+        Returns
+        -------
+        chk : bool
+            A check to see if settings was successfully run.
+
+        """
+        self.ifile = projdata['ifile']
+
+        chk = self.settings(True)
+
+        return chk
+
+    def saveproj(self):
+        """
+        Save project data from class.
+
+        Returns
+        -------
+        projdata : dictionary
+            Project data to be saved to JSON project file.
+
+        """
+        projdata = {}
+
+        projdata['ifile'] = self.ifile
+
+        return projdata
+
 
 class MyMplCanvas(FigureCanvas):
     """Simple canvas with a sine plot."""
+
     def __init__(self, parent=None, width=10, height=8, dpi=100,
                  bands=(0, 1, 2)):
         self.fig = Figure(figsize=(width, height), dpi=dpi)
@@ -399,7 +477,7 @@ class MyMplCanvas(FigureCanvas):
 #        breakpoint()
         if self.manip == 'NDWI':
             if self.cbar is None:
-                self.cbar = self.figure.colorbar(self.im1)
+                self.cbar = self.figure.colorbar(self.im1, format=frm)
             green = np.ma.masked_equal(dat[2].data, 0)
             nir = np.ma.masked_equal(dat[4].data, 0)
             green = green.astype(float)
@@ -409,7 +487,7 @@ class MyMplCanvas(FigureCanvas):
             self.im1.set_cmap(plt.cm.PiYG_r)
         elif self.manip == 'NDVI':
             if self.cbar is None:
-                self.cbar = self.figure.colorbar(self.im1)
+                self.cbar = self.figure.colorbar(self.im1, format=frm)
             red = np.ma.masked_equal(dat[3].data, 0)
             nir = np.ma.masked_equal(dat[4].data, 0)
             red = red.astype(float)
@@ -448,6 +526,8 @@ class MyMplCanvas(FigureCanvas):
         self.im1.set_data(dtmp)
         self.im1.set_extent(extent)
         self.fig.suptitle(dates)
+        self.ax1.xaxis.set_major_formatter(frm)
+        self.ax1.yaxis.set_major_formatter(frm)
 
         self.fig.canvas.draw()
 
@@ -469,7 +549,7 @@ class MyMplCanvas(FigureCanvas):
 
     def redraw(self, event):
         """
-        Redraw event
+        Redraw event.
 
         Parameters
         ----------
@@ -486,11 +566,11 @@ class MyMplCanvas(FigureCanvas):
 
 
 class SceneViewer(QtWidgets.QDialog):
-    """ Application Window """
-    def __init__(self, parent):
+    """Application Window."""
+
+    def __init__(self, parent=None):
         super().__init__(parent)
 
-        self.name = 'Create Scene List: '
         self.parent = parent
         self.indata = {}
         self.outdata = {}
@@ -553,7 +633,7 @@ class SceneViewer(QtWidgets.QDialog):
         self.button3.clicked.connect(self.nextscene)
         self.manip.currentIndexChanged.connect(self.manip_change)
 
-    def settings(self, test=False):
+    def settings(self, nodialog=False):
         """
         Entry point into item.
 
@@ -580,12 +660,46 @@ class SceneViewer(QtWidgets.QDialog):
 
         self.canvas.compute_initial_figure(dat, dates, points)
 
-        if not test:
+        if not nodialog:
             tmp = self.exec_()
 
             if tmp != 1:
                 return tmp
 
+    def loadproj(self, projdata):
+        """
+        Load project data into class.
+
+        Parameters
+        ----------
+        projdata : dictionary
+            Project data loaded from JSON project file.
+
+        Returns
+        -------
+        chk : bool
+            A check to see if settings was successfully run.
+
+        """
+
+        return False
+
+    def saveproj(self):
+        """
+        Save project data from class.
+
+        Returns
+        -------
+        projdata : dictionary
+            Project data to be saved to JSON project file.
+
+        """
+        projdata = {}
+
+#        projdata['ftype'] = '2D Mean'
+
+        return projdata
+
     def manip_change(self, event):
         """
         Change manipulation.
@@ -764,7 +878,7 @@ class SceneViewer(QtWidgets.QDialog):
         """
 
         datall = {}
-        ifile = ifile[:]
+        ifile = str(ifile)
 
         dataset = gdal.Open(ifile, gdal.GA_ReadOnly)
 
@@ -838,7 +952,6 @@ class SceneViewer(QtWidgets.QDialog):
                     nval = 1e+20
                 nval = float(nval)
 
-            dat.nrofbands = 1  # dataset.RasterCount
             dat.nullvalue = nval
             dat.xdim = xdim
             dat.ydim = ydim
@@ -913,3 +1026,26 @@ def get_shape_coords(sfile, todegrees=False):
         ddpoints = np.array(points)
 
     return ddpoints
+
+
+def testfn():
+    """Main testing routine."""
+    import sys
+    import matplotlib.pyplot as plt
+#    sfile = r'C:\Work\Workdata\change\PlanetaryPolygon.shp'
+    sfile = r'C:\Work\Workdata\change\fl35.shp'
+    pdir = r'C:\Work\Workdata\change\Planet'
+
+    APP = QtWidgets.QApplication(sys.argv)  # Necessary to test Qt Classes
+
+    CSL = CreateSceneList(None)
+    CSL.isrecursive.setChecked(True)
+    CSL.shapefile.setText(sfile)
+    CSL.scenefile.setText(pdir)
+    CSL.settings(True)
+
+    plt.show()
+    breakpoint()
+
+if __name__ == "__main__":
+    testfn()
\ No newline at end of file
