@@ -45,7 +45,7 @@ import scipy.spatial.distance as sdist
 class MyMplCanvas(FigureCanvas):
     """Canvas for the actual plot."""
 
-    def __init__(self, parent):
+    def __init__(self, parent=None):
         fig = Figure()
         super().__init__(fig)
 
@@ -127,8 +127,6 @@ class BeachBall(QtWidgets.QDialog):
         super().__init__(parent)
 
         self.ifile = ''
-        self.name = 'Beachball: '
-        self.ext = ''
         self.pbar = None
         self.parent = parent
         self.indata = {}
@@ -274,7 +272,6 @@ class BeachBall(QtWidgets.QDialog):
         os.chdir(os.path.dirname(filename))
 
         self.ifile = str(filename)
-        self.ext = filename[-3:]
 
         indata = self.mmc.data
 
@@ -406,7 +403,7 @@ class BeachBall(QtWidgets.QDialog):
         self.mmc.pwidth = self.dsb_dist.value()
         self.mmc.init_graph()
 
-    def settings(self):
+    def settings(self, nodialog=False):
         """
         Run.
 
@@ -425,6 +422,39 @@ class BeachBall(QtWidgets.QDialog):
         self.mmc.init_graph()
         return True
 
+    def loadproj(self, projdata):
+        """
+        Load project data into class.
+
+        Parameters
+        ----------
+        projdata : dictionary
+            Project data loaded from JSON project file.
+
+        Returns
+        -------
+        chk : bool
+            A check to see if settings was successfully run.
+
+        """
+        return False
+
+    def saveproj(self):
+        """
+        Save project data from class.
+
+        Returns
+        -------
+        projdata : dictionary
+            Project data to be saved to JSON project file.
+
+        """
+        projdata = {}
+
+#        projdata['ftype'] = '2D Mean'
+
+        return projdata
+
 
 def beachball(fm, centerx, centery, diam, isgeog):
     """
