@@ -46,7 +46,7 @@ class DeleteRecord():
 
         self.settings()
 
-    def settings(self):
+    def settings(self, nodialog=False):
         """
         Entry point into item.
 
@@ -67,6 +67,41 @@ class DeleteRecord():
 
         return True
 
+    def loadproj(self, projdata):
+        """
+        Loads project data into class.
+
+        Parameters
+        ----------
+        projdata : dictionary
+            Project data loaded from JSON project file.
+
+        Returns
+        -------
+        chk : bool
+            A check to see if settings was successfully run.
+
+        """
+
+        return False
+
+    def saveproj(self):
+        """
+        Save project data from class.
+
+
+        Returns
+        -------
+        projdata : dictionary
+            Project data to be saved to JSON project file.
+
+        """
+        projdata = {}
+
+#        projdata['ftype'] = '2D Mean'
+
+        return projdata
+
     def delrec(self, ifile):
         """
         Delete record.
@@ -124,14 +159,13 @@ class Quarry():
         self.parent = parent
         self.indata = {}
         self.outdata = {}
-        self.name = 'Quarry: '
         self.pbar = None
 
         self.events = []
         self.day = [10, 16]  # daytime start at 6am and ends at 7pm
         self.day = [9, 19]  # daytime start at 6am and ends at 7pm
 
-    def settings(self):
+    def settings(self, nodialog=False):
         """
         Entry point into item.
 
@@ -142,6 +176,8 @@ class Quarry():
 
         """
         print('Delete quarry events starting')
+        print('Daytime defined from 9am to 7pm')
+        print('Events radius: .2 degrees')
 
         if 'Seis' not in self.indata:
             return False
@@ -151,7 +187,7 @@ class Quarry():
         alist = []
         for i in data:
             if '1' in i:
-#                alist.append(i['1'])
+                # alist.append(i['1'])
                 alist.append(i)
 
         if not alist:
@@ -160,12 +196,50 @@ class Quarry():
 
         self.events = alist
 
-#        data = self.calcrq2()
+        # data = self.calcrq2()
         data = self.calcrq2b()
-        self.outdata['Seis'] = data
+        if data is not None:
+            self.outdata['Seis'] = data
+        else:
+            return False
 
         return True
 
+    def loadproj(self, projdata):
+        """
+        Loads project data into class.
+
+        Parameters
+        ----------
+        projdata : dictionary
+            Project data loaded from JSON project file.
+
+        Returns
+        -------
+        chk : bool
+            A check to see if settings was successfully run.
+
+        """
+
+        return False
+
+    def saveproj(self):
+        """
+        Save project data from class.
+
+
+        Returns
+        -------
+        projdata : dictionary
+            Project data to be saved to JSON project file.
+
+        """
+        projdata = {}
+
+        # projdata['ftype'] = '2D Mean'
+
+        return projdata
+
     def calcrq2(self):
         """
         Calculate the Rq value.
@@ -193,14 +267,14 @@ class Quarry():
 
         day = self.day
         ehour = np.array(hour)
-#        ehourall = ehour.copy()
+        # ehourall = ehour.copy()
         hour = np.logical_and(ehour >= day[0], ehour <= day[1])
 
         lon = np.array(lon)
         lat = np.array(lat)
         ld = day[1]-day[0]  # number of daylight hours
         ln = 24-ld  # number of nightime hours
-#        rdist = 0.2  # max distance for event to qualify. In degrees
+        # rdist = 0.2  # max distance for event to qualify. In degrees
         stayinloop = True
         N = 50
 
@@ -210,30 +284,30 @@ class Quarry():
         nrange = list(range(nmin, nmax+nstep, nstep))
         rperc = self.randrq(nmax, nstep, nrange, day)
 
-#        print('Calculating clusters')
-#
-#        # use DBscan to identify cluster centers and numbers of clusters.
-#        # eps is max distance between samples
-#
-#        X = np.transpose([lon, lat])
-#        db = DBSCAN(eps=0.01, min_samples=10).fit(X)
-#        labels = db.labels_  # noisy samples are -1
-#
-#        print('now calculate means')
-#        clusters = []
-#        for i in np.unique(labels):
-#            if i == -1:
-#                continue
-#            lontmp = lon[labels == i].mean()
-#            lattmp = lat[labels == i].mean()
-#            clusters.append([lontmp, lattmp])
-#
-#        clusters = np.array(clusters)
+        # print('Calculating clusters')
+
+        # # use DBscan to identify cluster centers and numbers of clusters.
+        # # eps is max distance between samples
+
+        # X = np.transpose([lon, lat])
+        # db = DBSCAN(eps=0.01, min_samples=10).fit(X)
+        # labels = db.labels_  # noisy samples are -1
+
+        # print('now calculate means')
+        # clusters = []
+        # for i in np.unique(labels):
+        #     if i == -1:
+        #         continue
+        #     lontmp = lon[labels == i].mean()
+        #     lattmp = lat[labels == i].mean()
+        #     clusters.append([lontmp, lattmp])
+
+        # clusters = np.array(clusters)
         print('Calculating Rq values')
 
         while stayinloop:
             lls = np.transpose([lat, lon])
-#            lls2 = lls[hour]
+            # lls2 = lls[hour]
             cnt = lls.shape[0]
             nd = []
             rstot = []
@@ -284,7 +358,7 @@ class Quarry():
         # plt.hist(ehour, 24)
         # plt.show()
 
-#        return newevents.tolist()
+        # return newevents.tolist()
         return newevents
 
     def calcrq2b(self):
@@ -317,7 +391,7 @@ class Quarry():
         day = self.day
 
         ehour = np.array(hour)
-#        ehourall = ehour.copy()
+        # ehourall = ehour.copy()
         hour = np.logical_and(ehour >= day[0], ehour <= day[1])
 
         lon = np.array(lon)
@@ -327,9 +401,9 @@ class Quarry():
         rdist = 0.2  # max distance for event to qualify. In degrees
         N = 50
 
-#        rperc = self.randrqb(N, day, ehourall.shape[0])
+        # rperc = self.randrqb(N, day, ehourall.shape[0])
         rperc = 3.0
-#        rperc = 1.97435897
+        # rperc = 1.97435897
 
         print('Calculating Rq values')
 
@@ -351,17 +425,20 @@ class Quarry():
             rstot.append(rs[hrs])
             nd.append(hrs)
 
+        if len(nd) == 0:
+            print('Not enough events within .2 degrees. Aborting.')
+            return None
         nd = np.sum(nd, 1)
         nn = (N-nd).astype(float)
         nn[nn == 0] = 0.00001
         rq = (nd*ln)/(nn*ld)
 
-        rstot = np.array(rstot)
+        rstot = np.array(rstot, dtype=object)
 
-#        plt.xlabel('R')
-#        plt.ylabel('Event Counts')
-#        plt.hist(rq[nn != 0.00001], 50)
-#        plt.show()
+        # plt.xlabel('R')
+        # plt.ylabel('Event Counts')
+        # plt.hist(rq[nn != 0.00001], 50)
+        # plt.show()
 
         filt = (rq-rperc) > 0
 
@@ -377,20 +454,20 @@ class Quarry():
         ehour = np.delete(ehour, maxel)
         newevents = np.delete(newevents, maxel)
 
-#        ttt.since_last_call('Total')
+        # ttt.since_last_call('Total')
         print('Completed!')
 
-#        print('New total number of events:', ehour.size)
-#
-#        plt.xlabel('Hours')
-#        plt.ylabel('Event Counts')
-#        plt.hist(ehourall, 24)
-#        plt.show()
-#
-#        plt.xlabel('Hours')
-#        plt.ylabel('Event Counts')
-#        plt.hist(ehour, 24)
-#        plt.show()
+        # print('New total number of events:', ehour.size)
+
+        # plt.xlabel('Hours')
+        # plt.ylabel('Event Counts')
+        # plt.hist(ehourall, 24)
+        # plt.show()
+
+        # plt.xlabel('Hours')
+        # plt.ylabel('Event Counts')
+        # plt.hist(ehour, 24)
+        # plt.show()
 
         return newevents.tolist()
 
@@ -417,7 +494,7 @@ class Quarry():
         """
         rperc = [1.97435897, 1.64253394, 1.46153846, 1.41025641, 1.35737179,
                  1.3234714, 1.28444936, 1.26923077]
-#        rperc[0] = 2.5
+        # rperc[0] = 2.5
 
         print('Calculating random Rq values for calibration')
         rperc = []
@@ -460,30 +537,30 @@ class Quarry():
 
         """
         print('Calculating random Rq values for calibration')
-#        nd = 0
+        # nd = 0
         elist = [50, 100, 150, 200]
-#        elist = [150]
+        # elist = [150]
 
         for N in elist:
             rqmean = []
             for ld in range(1, 24):
                 day = (0, ld)
-    #            ld = day[1]-day[0]
+                # ld = day[1]-day[0]
                 ln = 24-ld
 
                 ln_over_ld = ln/ld
 
-    #            print(str(N))
+                # print(str(N))
 
- #               print('random '+str(N)+' dat hours '+str(ld))
+                # print('random '+str(N)+' dat hours '+str(ld))
 
                 tmp = np.random.rand(1000000, N)
                 tmp *= 24
 
-#                tmp2 = tmp.flatten()[:num]
-#                plt.title('random '+str(N)+' dat hours '+str(ld))
-#                plt.hist(tmp2, 24)
-#                plt.show()
+                # tmp2 = tmp.flatten()[:num]
+                # plt.title('random '+str(N)+' dat hours '+str(ld))
+                # plt.hist(tmp2, 24)
+                # plt.show()
 
                 tmp = np.logical_and(tmp >= day[0], tmp <= day[1])
 
@@ -491,21 +568,21 @@ class Quarry():
                 nn = (N-nd).astype(float)
 
 
-#                nd = nd[nn!=0]
-#                nn = nn[nn!=0]
+                # nd = nd[nn!=0]
+                # nn = nn[nn!=0]
 
-#                nn[nn == 0] = 0.00001
+                # nn[nn == 0] = 0.00001
 
-    #            rq = (nd*ln)/(nn*ld)
-    #            rq = ln_over_ld*nd/nn
+                # rq = (nd*ln)/(nn*ld)
+                # rq = ln_over_ld*nd/nn
                 rq = nd/nn
                 rperc = np.percentile(rq, 99)
                 rperc = rperc*ln_over_ld
 
-#                print(rperc)
-#                print(np.mean(rq))
-#                rqmean.append(np.mean(rq))
-#                rqmean.append(np.median(rq))
+                # print(rperc)
+                # print(np.mean(rq))
+                # rqmean.append(np.mean(rq))
+                # rqmean.append(np.median(rq))
                 rqmean.append(rperc)
 
             plt.plot(rqmean)
@@ -564,11 +641,11 @@ def import_for_plots(ifile, dind='R'):
                             datd[newkey] = []
                         datd[newkey].append(tmp[j.split('_of_')[1]])
 
-#                        time = tmp['hour']+tmp['minutes']/60.+tmp['seconds']/3600.
-#                        newkey = '1_M'+tmp[j]+'_time'
-#                        if newkey not in datd:
-#                            datd[newkey] = []
-#                        datd[newkey].append(time)
+                        # time = tmp['hour']+tmp['minutes']/60.+tmp['seconds']/3600.
+                        # newkey = '1_M'+tmp[j]+'_time'
+                        # if newkey not in datd:
+                        #     datd[newkey] = []
+                        # datd[newkey].append(time)
 
                         newkey = '1_M'+tmp[j]+'_year'
                         if newkey not in datd:
@@ -586,115 +663,16 @@ def import_for_plots(ifile, dind='R'):
     return datd
 
 
-#def gearth_plot(ifile):
-#    """Plot with google earth background."""
-#    datd = import_for_plots(ifile, 'R')
-#
-#    extent = [16, 33, -22, -35]
-##    extent = [29, 29.05, -26, -26.05]
-#    request = cimgt.GoogleTiles(style='satellite')
-#
-#    plt.figure(figsize=(9, 7))
-#    ax = plt.axes(projection=ccrs.PlateCarree())
-#    ax.set_extent(extent, crs=ccrs.PlateCarree())
-#
-#    # https://wiki.openstreetmap.org/wiki/Zoom_levels
-#    ax.add_image(request, 6)
-##    ax.add_image(request, 14)
-#
-#    ax.gridlines(draw_labels=True)
-#
-#    filt1 = np.equal(datd['1_longitude'], None)
-#    filt2 = np.equal(datd['1_latitude'], None)
-#    filt = np.logical_or(filt1, filt2)
-#    filt1 = np.isnan(datd['1_longitude'])
-#    filt2 = np.isnan(datd['1_latitude'])
-#    filtb = np.logical_or(filt1, filt2)
-#    filt = np.logical_or(filt, filtb)
-#
-#    lat1 = np.array(datd['1_latitude'])[~filt].astype(float)
-#    lon1 = np.array(datd['1_longitude'])[~filt].astype(float)
-#
-#    X = np.transpose([lon1, lat1])
-#    db = DBSCAN(eps=0.05, min_samples=10).fit(X)
-#
-#    filt = (db.labels_ != -1)
-#    plt.scatter(lon1[filt], lat1[filt], s=1, c=db.labels_[filt],
-#                cmap=plt.cm.jet)
-#    plt.colorbar()
-#
-#    plt.show()
-#
-#def test():
-#    """ test for google earth stuff """
-#    import matplotlib as mpl
-#    glookup = np.array([156412, 78206, 39103, 19551, 9776, 4888, 2444, 1222,
-#                        610.984, 305.492, 152.746, 76.373, 38.187, 19.093,
-#                        9.547, 4.773, 2.387, 1.193, 0.596, 0.298])
-#
-#
-##    extent = [16, 33, -22, -35]
-#    extent = [227800, 540000, 7110000, 6950000]
-#    extent = [227800, 540000, 6950000, 7110000]
-##    extent = [0, 100, 100, 0]
-#
-##    extent = [29, 29.05, -26, -26.05]
-#    request = cimgt.GoogleTiles(style='satellite')
-##    request = cimgt.GoogleTiles(style='street')
-##    custproj = ccrs.PlateCarree()
-#    custproj = ccrs.epsg(32736)
-##    custproj = ccrs.epsg(3857)
-#
-#    fig = plt.figure(figsize=(9, 7))
-#    ax = plt.axes(projection=custproj)
-#    ax.set_extent(extent, crs=custproj)
-#
-#    xrange = extent[1]-extent[0]
-#    yrange = abs(extent[2]-extent[3])
-#    width = xrange/(fig.get_figwidth()*fig.get_dpi())
-#    height = yrange/(fig.get_figheight()*fig.get_dpi())
-#    mindim = min(width, height)
-#
-#    pchk1 = np.abs(glookup-mindim)
-#    pchk2 = np.min(pchk1)
-#    pchk = np.nonzero(pchk1 == pchk2)
-#    pchk = int(pchk[0][0])
-#
-#    # https://wiki.openstreetmap.org/wiki/Zoom_levels
-#    ax.add_image(request, pchk)
-##    ax.add_image(request, 9)
-#
-#    plt.xticks([227800, 300000, 400000, 500000, 540000])
-#    plt.yticks([6950000, 7000000, 7050000, 7100000, 7110000])
-#    plt.grid(True)
-#
-#    plt.plot(400000, 7050000, 'o')
-#    plt.show()
-#
-##    imgs = [obj for obj in ax.get_children() if isinstance(obj, mpl.image.AxesImage)]
-##
-##    image = imgs[0].get_array()[::-1]
-##
-##    plt.imshow(image)
-##    plt.show()
-#    lims2 = ax.get_images()[0]
-#
-#    lims2.set_alpha(0)
-#
-#    plt.show()
-
-
 def main():
     """Routine for testing."""
-    ifile = r'C:\Work\Programming\pygmi\data\seismology\pygmi.out'
-
-#    gearth_plot(ifile)
-#    test()
+    ifile = r'C:\Work\Workdata\review\seismology\pygmi.out'
+    # ifile = r'C:\Work\Workdata\review\seismology\collect.out'
 
     quarry = Quarry()
 
     dat = iodefs.ImportSeisan()
-    dat.settings(ifile)
+    dat.ifile = ifile
+    dat.settings(True)
 
     quarry.indata = dat.outdata
     quarry.settings()
