@@ -133,14 +133,12 @@ class ImportSeisan():
 
     def __init__(self, parent=None):
         self.ifile = ''
-        self.name = 'Import Seisan Data'
-        self.ext = ''
         self.pbar = None
         self.parent = parent
         self.indata = {}
         self.outdata = {}
 
-    def settings(self, filename=None):
+    def settings(self, nodialog=False):
         """
         Entry point into item.
 
@@ -150,21 +148,18 @@ class ImportSeisan():
             True if successful, False otherwise.
 
         """
-        ext = \
-            'Seisan Format (*.out);;' +\
-            'All Files (*.*)'
-        if filename is None:
-            filename, _ = QtWidgets.QFileDialog.getOpenFileName(
+        if not nodialog:
+            ext = \
+                'SEISAN Format (*.out);;' +\
+                'All Files (*.*)'
+            self.ifile, _ = QtWidgets.QFileDialog.getOpenFileName(
                 self.parent, 'Open File', '.', ext)
-        if filename == '':
-            return False
+            if self.ifile == '':
+                return False
 
-        os.chdir(os.path.dirname(filename))
+        os.chdir(os.path.dirname(self.ifile))
 
-        self.ifile = str(filename)
-        self.ext = filename[-3:]
-
-        with open(filename) as pntfile:
+        with open(self.ifile) as pntfile:
             ltmp = pntfile.readlines()
 
         if len(ltmp[0]) < 80:
@@ -231,8 +226,8 @@ class ImportSeisan():
                 file_errors.append(errs)
                 continue
 
-            if ltype == '1'and (np.isnan(tmp.latitude) or
-                                np.isnan(tmp.longitude)):
+            if ltype == '1' and (np.isnan(tmp.latitude) or
+                                 np.isnan(tmp.longitude)):
                 errs = ['Warning: Incomplete data on line: '+str(iii+1), i]
                 file_errors.append(errs)
 
@@ -289,12 +284,12 @@ class ImportSeisan():
             if has_errors is False:
                 print('Warning: Problem with file')
                 print('Process will continue, but please '
-                               'see warnings in '+filename+'.log')
+                      'see warnings in '+self.ifile+'.log')
             else:
                 print('Error: Problem with file')
                 print('Process stopping, please see errors '
-                               'in '+filename+'.log')
-            fout = open(filename+'.log', 'w')
+                      'in '+self.ifile+'.log')
+            fout = open(self.ifile+'.log', 'w')
             for i in file_errors:
                 fout.write(i[0]+'\n')
                 fout.write(i[1]+'\n')
@@ -310,6 +305,44 @@ class ImportSeisan():
         self.outdata['Seis'] = dat
         return True
 
+    def loadproj(self, projdata):
+        """
+        Loads project data into class.
+
+        Parameters
+        ----------
+        projdata : dictionary
+            Project data loaded from JSON project file.
+
+        Returns
+        -------
+        chk : bool
+            A check to see if settings was successfully run.
+
+        """
+        self.ifile = projdata['ifile']
+
+        chk = self.settings(True)
+
+        return chk
+
+    def saveproj(self):
+        """
+        Save project data from class.
+
+
+        Returns
+        -------
+        projdata : dictionary
+            Project data to be saved to JSON project file.
+
+        """
+        projdata = {}
+
+        projdata['ifile'] = self.ifile
+
+        return projdata
+
 
 def read_record_type_1(i):
     """
@@ -751,14 +784,12 @@ class ImportGenericFPS():
 
     def __init__(self, parent=None):
         self.ifile = ''
-        self.name = 'Import Generic FPS: '
-        self.ext = ''
         self.pbar = None
         self.parent = parent
         self.indata = {}
         self.outdata = {}
 
-    def settings(self):
+    def settings(self, nodialog=False):
         """
         Entry point into item.
 
@@ -768,27 +799,26 @@ class ImportGenericFPS():
             True if successful, False otherwise.
 
         """
-        QtWidgets.QMessageBox.information(self.parent, 'File Format',
-                                          'The file should have the following '
-                                          'columns: longitude, latitude, '
-                                          'depth, strike, dip, rake, '
-                                          'magnitude.')
+        if not nodialog:
+            QtWidgets.QMessageBox.information(self.parent, 'File Format',
+                                              'The file should have the '
+                                              'following columns: '
+                                              'longitude, latitude, '
+                                              'depth, strike, dip, rake, '
+                                              'magnitude.')
 
-        ext = ('Comma Delimeted Text (*.csv);;'
-               'All Files (*.*)')
+            ext = ('Comma Delimited Text (*.csv);;'
+                   'All Files (*.*)')
 
-        filename, _ = QtWidgets.QFileDialog.getOpenFileName(
-            self.parent, 'Open File', '.', ext)
-        if filename == '':
-            return False
-        os.chdir(os.path.dirname(filename))
-
-        self.ifile = str(filename)
-        self.ext = filename[-3:]
+            self.ifile, _ = QtWidgets.QFileDialog.getOpenFileName(
+                self.parent, 'Open File', '.', ext)
+            if self.ifile == '':
+                return False
+        os.chdir(os.path.dirname(self.ifile))
 
         dlim = ','
 
-        with open(filename) as pntfile:
+        with open(self.ifile) as pntfile:
             ltmp = pntfile.readline()
 
         isheader = any(c.isalpha() for c in ltmp)
@@ -801,7 +831,7 @@ class ImportGenericFPS():
             ltmp = [str(c) for c in range(len(ltmp))]
 
         try:
-            datatmp = np.loadtxt(filename, delimiter=dlim, skiprows=srows)
+            datatmp = np.loadtxt(self.ifile, delimiter=dlim, skiprows=srows)
         except ValueError:
             QtWidgets.QMessageBox.critical(self.parent, 'Import Error',
                                            'There was a problem loading the '
@@ -835,14 +865,50 @@ class ImportGenericFPS():
 
         return True
 
+    def loadproj(self, projdata):
+        """
+        Loads project data into class.
+
+        Parameters
+        ----------
+        projdata : dictionary
+            Project data loaded from JSON project file.
+
+        Returns
+        -------
+        chk : bool
+            A check to see if settings was successfully run.
+
+        """
+        self.ifile = projdata['ifile']
+
+        chk = self.settings(True)
+
+        return chk
+
+    def saveproj(self):
+        """
+        Save project data from class.
+
+
+        Returns
+        -------
+        projdata : dictionary
+            Project data to be saved to JSON project file.
+
+        """
+        projdata = {}
+
+        projdata['ifile'] = self.ifile
+
+        return projdata
+
 
 class ExportSeisan():
     """Export Seisan Data."""
 
-    def __init__(self, parent):
+    def __init__(self, parent=None):
         self.ifile = ''
-        self.name = 'Export Seisan Data '
-        self.ext = ''
         self.pbar = None
         self.parent = parent
         self.indata = {}
@@ -861,7 +927,7 @@ class ExportSeisan():
         """
         if 'Seis' not in self.indata:
             print(
-                'Error: You need to have a Seisan data first!')
+                'Error: You need to have a SEISAN data first!')
             return
 
         data = self.indata['Seis']
@@ -874,7 +940,6 @@ class ExportSeisan():
             return
 
         os.chdir(os.path.dirname(filename))
-        self.ext = filename[-3:]
 
         self.fobj = open(filename, 'w')
 
@@ -1347,10 +1412,8 @@ class ExportSeisan():
 class ExportCSV():
     """Export Seisan Data."""
 
-    def __init__(self, parent):
+    def __init__(self, parent=None):
         self.ifile = ''
-        self.name = 'Export CSV Data '
-        self.ext = ''
         self.pbar = None
         self.parent = parent
         self.indata = {}
@@ -1369,7 +1432,7 @@ class ExportCSV():
         """
         if 'Seis' not in self.indata:
             print(
-                'Error: You need to have a Seisan data first!')
+                'Error: You need to have a SEISAN data first!')
             return
 
         data = self.indata['Seis']
@@ -1380,7 +1443,6 @@ class ExportCSV():
         if filename == '':
             return
         os.chdir(os.path.dirname(filename))
-        self.ext = filename[-3:]
 
         self.fobj = open(filename, 'w')
 
@@ -1893,10 +1955,8 @@ class ExportCSV():
 class ExportSummaryCSV():
     """Export Seisan Data."""
 
-    def __init__(self, parent):
+    def __init__(self, parent=None):
         self.ifile = ''
-        self.name = 'Export Summary CSV Data '
-        self.ext = ''
         self.pbar = None
         self.parent = parent
         self.indata = {}
@@ -1914,7 +1974,7 @@ class ExportSummaryCSV():
 
         """
         if 'Seis' not in self.indata:
-            print('Error: You need to have a Seisan data first!')
+            print('Error: You need to have a SEISAN data first!')
             return
 
         data = self.indata['Seis']
@@ -1925,7 +1985,6 @@ class ExportSummaryCSV():
         if filename == '':
             return
         os.chdir(os.path.dirname(filename))
-        self.ext = filename[-3:]
 
         head = ["Year", "Month", "Day", "Hour", "Minute", "Second",
                 "Latitude", "Longitude", "Depth", "Ml", "Mw", "Md", "Mb",
@@ -2083,7 +2142,7 @@ class FilterSeisan(QtWidgets.QDialog):
         gridlayout_main = QtWidgets.QGridLayout(self)
         buttonbox = QtWidgets.QDialogButtonBox()
         helpdocs = menu_default.HelpButton('pygmi.raster.dataprep.datagrid')
-#        label_dind = QtWidgets.QLabel('Distance Indicator:')
+        # label_dind = QtWidgets.QLabel('Distance Indicator:')
         label_rectype = QtWidgets.QLabel('Record Type:')
         label_recdesc = QtWidgets.QLabel('Description:')
         label_from = QtWidgets.QLabel('From')
@@ -2277,7 +2336,7 @@ class FilterSeisan(QtWidgets.QDialog):
 
         self.datlimits = datd
 
-    def settings(self):
+    def settings(self, nodialog=False):
         """
         Entry point into item.
 
@@ -2329,15 +2388,68 @@ class FilterSeisan(QtWidgets.QDialog):
         self.rectype.setCurrentText('1')
         self.rectype_init('1')
 
-        tmp = self.exec_()
+        if not nodialog:
+            tmp = self.exec_()
 
-        if tmp != 1:
-            return False
+            if tmp != 1:
+                return False
 
         self.acceptall()
 
         return True
 
+    def loadproj(self, projdata):
+        """
+        Load project data into class.
+
+        Parameters
+        ----------
+        projdata : dictionary
+            Project data loaded from JSON project file.
+
+        Returns
+        -------
+        chk : bool
+            A check to see if settings was successfully run.
+
+        """
+        self.dsb_from.setValue(projdata['from'])
+        self.dsb_to.setValue(projdata['to'])
+        self.rectype.setCurrentText(projdata['rectype'])
+        self.recdesc.setCurrentText(projdata['recdesc'])
+        self.dind_L.setChecked(projdata['L'])
+        self.dind_R.setChecked(projdata['R'])
+        self.dind_D.setChecked(projdata['D'])
+        self.rinc.setChecked(projdata['rinc'])
+        self.rexc.setChecked(projdata['rexc'])
+        self.dind_click(None)
+
+        return False
+
+    def saveproj(self):
+        """
+        Save project data from class.
+
+        Returns
+        -------
+        projdata : dictionary
+            Project data to be saved to JSON project file.
+
+        """
+        projdata = {}
+
+        projdata['from'] = self.dsb_from.value()
+        projdata['to'] = self.dsb_to.value()
+        projdata['rectype'] = self.rectype.currentText()
+        projdata['recdesc'] = self.recdesc.currentText()
+        projdata['L'] = self.dind_L.isChecked()
+        projdata['R'] = self.dind_R.isChecked()
+        projdata['D'] = self.dind_D.isChecked()
+        projdata['rinc'] = self.rinc.isChecked()
+        projdata['rexc'] = self.rexc.isChecked()
+
+        return projdata
+
     def acceptall(self):
         """
         Accept option.
