@@ -75,8 +75,6 @@ class SIMP():
     def __init__(self, parent=None):
         # PyGMI variables
         self.ifile = ''
-        self.name = 'Import Data: '
-        self.ext = ''
         self.pbar = None
         self.parent = parent
         self.indata = {}
@@ -120,7 +118,7 @@ class SIMP():
         self.parent = parent
         self.event = {}
 
-    def settings(self):
+    def settings(self, nodialog=False):
         """
         Entry point into item.
 
@@ -131,7 +129,7 @@ class SIMP():
 
         """
         self.parent.clearprocesslog()
-        print('Import Bulletin to Seisan Format')
+        print('Import Bulletin to SEISAN Format')
 
         ext = 'Scanned Bulletin Text File (*.txt)'
 
@@ -143,8 +141,6 @@ class SIMP():
         os.chdir(os.path.dirname(filename))
 
         self.ifile = str(filename)
-        self.ext = filename[-3:]
-
         ifile = self.ifile
 
         print('Input File: '+ifile)
@@ -212,6 +208,41 @@ class SIMP():
 
         return True
 
+    def loadproj(self, projdata):
+        """
+        Loads project data into class.
+
+        Parameters
+        ----------
+        projdata : dictionary
+            Project data loaded from JSON project file.
+
+        Returns
+        -------
+        chk : bool
+            A check to see if settings was successfully run.
+
+        """
+
+        return False
+
+    def saveproj(self):
+        """
+        Save project data from class.
+
+
+        Returns
+        -------
+        projdata : dictionary
+            Project data to be saved to JSON project file.
+
+        """
+        projdata = {}
+
+#        projdata['ftype'] = '2D Mean'
+
+        return projdata
+
     def reset_vars(self, mon, mondec):
         """
         Use to reset the header variables to their defaults.
