@@ -29,18 +29,18 @@ import numpy as np
 from PyQt5 import QtWidgets, QtCore
 from scipy.stats import median_absolute_deviation
 import matplotlib.collections as mc
-from matplotlib.cm import Set1
-from matplotlib.cm import jet
+from matplotlib.cm import Set1, jet
 from matplotlib.backends.backend_qt5agg import FigureCanvas
 from matplotlib.figure import Figure
 from matplotlib.backends.backend_qt5agg import NavigationToolbar2QT
 from pandas.api.types import is_numeric_dtype
+from pygmi.misc import frm
 
 
 class GraphWindow(QtWidgets.QDialog):
     """Graph Window - Main QT Dialog class for graphs."""
 
-    def __init__(self, parent):
+    def __init__(self, parent=None):
         super().__init__(parent)
         self.parent = parent
 
@@ -96,7 +96,7 @@ class MyMplCanvas(FigureCanvas):
     """
     MPL Canvas class.
 
-    This routine will also allow the pciking and movement of nodes of data.
+    This routine will also allow the picking and movement of nodes of data.
     """
 
     def __init__(self, parent=None):
@@ -221,6 +221,10 @@ class MyMplCanvas(FigureCanvas):
         self.background = self.figure.canvas.copy_from_bbox(ax1.bbox)
 
         self.line, = ax1.plot(r, data, '.-', picker=5)
+
+        self.axes.xaxis.set_major_formatter(frm)
+        self.axes.yaxis.set_major_formatter(frm)
+
         self.figure.tight_layout()
         self.figure.canvas.draw()
 
@@ -259,9 +263,12 @@ class MyMplCanvas(FigureCanvas):
             return
 #            scat = ax1.scatter(xdata, ydata)
 
-        self.figure.colorbar(scat, ax=ax1)
+        self.figure.colorbar(scat, ax=ax1, format=frm)
 #        data.plot(ival, cmap=jet, ax=ax1)
 
+        self.axes.xaxis.set_major_formatter(frm)
+        self.axes.yaxis.set_major_formatter(frm)
+
         self.figure.tight_layout()
         self.figure.canvas.draw()
 
@@ -354,10 +361,13 @@ class MyMplCanvas(FigureCanvas):
             ax1.plot(x, y, 'c')
             ax1.plot(qx, qy, 'k')
 
+        self.axes.xaxis.set_major_formatter(frm)
+        self.axes.yaxis.set_major_formatter(frm)
+
         self.figure.tight_layout()
         self.figure.canvas.draw()
 
-    def update_vector(self, data):
+    def update_vector(self, data, col):
         """
         Update the plot from vactor data.
 
@@ -402,8 +412,14 @@ class MyMplCanvas(FigureCanvas):
             self.axes.axis('equal')
 
         elif 'Point' in data:
-            self.axes.plot(data['Point'].geometry.x,
-                           data['Point'].geometry.y, 'go')
+            self.axes.scatter(data['Point'].geometry.x,
+                              data['Point'].geometry.y,
+                              c=data['Point'][col])
+            # self.axes.plot(data['Point'].geometry.x,
+            #                data['Point'].geometry.y, 'go')
+
+        self.axes.xaxis.set_major_formatter(frm)
+        self.axes.yaxis.set_major_formatter(frm)
 
         self.figure.canvas.draw()
 
@@ -507,7 +523,7 @@ class MyMplCanvas(FigureCanvas):
 class PlotPoints(GraphWindow):
     """Plot Points2 Class."""
 
-    def __init__(self, parent):
+    def __init__(self, parent=None):
         super().__init__(parent)
         self.indata = {}
         self.parent = parent
@@ -568,7 +584,7 @@ class PlotPoints(GraphWindow):
 class PlotLines(GraphWindow):
     """Plot Lines Class."""
 
-    def __init__(self, parent):
+    def __init__(self, parent=None):
         super().__init__(parent)
         self.indata = {}
         self.parent = parent
@@ -656,7 +672,7 @@ class PlotLines(GraphWindow):
 class PlotLineMap(GraphWindow):
     """Plot Lines2 Class."""
 
-    def __init__(self, parent):
+    def __init__(self, parent=None):
         super().__init__(parent)
         self.indata = {}
         self.parent = parent
@@ -724,7 +740,7 @@ class PlotLineMap(GraphWindow):
 class PlotRose(GraphWindow):
     """Plot Rose Class."""
 
-    def __init__(self, parent):
+    def __init__(self, parent=None):
         super().__init__(parent)
         self.indata = {}
         self.parent = parent
@@ -750,6 +766,9 @@ class PlotRose(GraphWindow):
         i = self.combobox1.currentIndex()
         if 'LineString' in data:
             self.mmc.update_rose(data, i, self.spinbox.value())
+        else:
+            print('No line type data.')
+            return
 
     def run(self):
         """
@@ -770,17 +789,34 @@ class PlotRose(GraphWindow):
 class PlotVector(GraphWindow):
     """Plot Vector Class."""
 
-    def __init__(self, parent):
+    def __init__(self, parent=None):
         super().__init__(parent)
         self.indata = {}
         self.parent = parent
-        self.combobox1.hide()
         self.label1.hide()
         self.combobox2.hide()
         self.label2.hide()
         self.spinbox.hide()
         self.label3.hide()
 
+    def change_band(self):
+        """
+        Combo box to choose band.
+
+        Returns
+        -------
+        None.
+
+        """
+#        key = list(self.indata['Vector'].keys())[0]
+        data = self.indata['Vector']
+#        data = data.dropna()
+        i = self.combobox1.currentText()
+
+#        self.mmc.update_map(data.pygmiX, data.pygmiY, data[i])
+
+        self.mmc.update_vector(data, i)
+
     def run(self):
         """
         Run.
@@ -790,9 +826,27 @@ class PlotVector(GraphWindow):
         None.
 
         """
-        self.show()
+
         data = self.indata['Vector']
-        self.mmc.update_vector(data)
+        key = list(data.keys())[0]
+        data = data[key]
+        data = data.select_dtypes(include='number')
+
+        filt = ((data.columns != 'geometry') &
+                (data.columns != 'line') &
+                (data.columns != 'pygmiX') &
+                (data.columns != 'pygmiY'))
+
+        cols = list(data.columns[filt])
+        if len(cols) > 0:
+            self.combobox1.addItems(cols)
+            self.combobox1.setCurrentIndex(0)
+        else:
+            self.combobox1.hide()
+
+        self.show()
+
+        self.change_band()
 
 
 def histogram(x, y=None, xmin=None, xmax=None, bins=10):
